<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
<xsl:stylesheet xmlns:xs="http://www.w3.org/2001/XMLSchema"
                xmlns:xsd="http://www.w3.org/2001/XMLSchema"
                xmlns:saxon="http://saxon.sf.net/"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:schold="http://www.ascc.net/xml/schematron"
                xmlns:iso="http://purl.oclc.org/dsdl/schematron"
                xmlns:xhtml="http://www.w3.org/1999/xhtml"
                xmlns:hl7="urn:hl7-org:v3"
                xmlns:cda="urn:hl7-org:v3"
                xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
                xmlns:hl7v2="urn:hl7-org:v2xml"
                xmlns:lab="urn:oid:1.3.6.1.4.1.19376.1.3.2"
                xmlns:sdtc="urn:hl7-org:sdtc"
                xmlns:hl7nl="urn:hl7-nl:v3"
                xmlns:nfu="urn:urn:nictiz-nl:v3/nfu"
                xmlns:pharm="urn:ihe:pharm:medication"
                version="2.0"><!--Implementers: please note that overriding process-prolog or process-root is 
    the preferred method for meta-stylesheets to use where possible. -->
   <xsl:param name="archiveDirParameter"/>
   <xsl:param name="archiveNameParameter"/>
   <xsl:param name="fileNameParameter"/>
   <xsl:param name="fileDirParameter"/>
   <xsl:variable name="document-uri">
      <xsl:value-of select="document-uri(/)"/>
   </xsl:variable>

   <!--PHASES-->


   <!--PROLOG-->
   <xsl:output xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
               method="xml"
               omit-xml-declaration="no"
               standalone="yes"
               indent="yes"/>

   <!--XSD TYPES FOR XSLT2-->


   <!--KEYS AND FUNCTIONS-->


   <!--DEFAULT RULES-->


   <!--MODE: SCHEMATRON-SELECT-FULL-PATH-->
   <!--This mode can be used to generate an ugly though full XPath for locators-->
   <xsl:template match="*" mode="schematron-select-full-path">
      <xsl:apply-templates select="." mode="schematron-get-full-path"/>
   </xsl:template>

   <!--MODE: SCHEMATRON-FULL-PATH-->
   <!--This mode can be used to generate an ugly though full XPath for locators-->
   <xsl:template match="*" mode="schematron-get-full-path">
      <xsl:apply-templates select="parent::*" mode="schematron-get-full-path"/>
      <xsl:text>/</xsl:text>
      <xsl:choose>
         <xsl:when test="namespace-uri()=''">
            <xsl:value-of select="name()"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:text>*:</xsl:text>
            <xsl:value-of select="local-name()"/>
            <xsl:text>[namespace-uri()='</xsl:text>
            <xsl:value-of select="namespace-uri()"/>
            <xsl:text>']</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="preceding"
                    select="count(preceding-sibling::*[local-name()=local-name(current())                                   and namespace-uri() = namespace-uri(current())])"/>
      <xsl:text>[</xsl:text>
      <xsl:value-of select="1+ $preceding"/>
      <xsl:text>]</xsl:text>
   </xsl:template>
   <xsl:template match="@*" mode="schematron-get-full-path">
      <xsl:apply-templates select="parent::*" mode="schematron-get-full-path"/>
      <xsl:text>/</xsl:text>
      <xsl:choose>
         <xsl:when test="namespace-uri()=''">@<xsl:value-of select="name()"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:text>@*[local-name()='</xsl:text>
            <xsl:value-of select="local-name()"/>
            <xsl:text>' and namespace-uri()='</xsl:text>
            <xsl:value-of select="namespace-uri()"/>
            <xsl:text>']</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
   </xsl:template>

   <!--MODE: SCHEMATRON-FULL-PATH-2-->
   <!--This mode can be used to generate prefixed XPath for humans-->
   <xsl:template match="node() | @*" mode="schematron-get-full-path-2">
      <xsl:for-each select="ancestor-or-self::*">
         <xsl:text>/</xsl:text>
         <xsl:value-of select="name(.)"/>
         <xsl:if test="preceding-sibling::*[name(.)=name(current())]">
            <xsl:text>[</xsl:text>
            <xsl:value-of select="count(preceding-sibling::*[name(.)=name(current())])+1"/>
            <xsl:text>]</xsl:text>
         </xsl:if>
      </xsl:for-each>
      <xsl:if test="not(self::*)">
         <xsl:text/>/@<xsl:value-of select="name(.)"/>
      </xsl:if>
   </xsl:template>
   <!--MODE: SCHEMATRON-FULL-PATH-3-->
   <!--This mode can be used to generate prefixed XPath for humans 
	(Top-level element has index)-->
   <xsl:template match="node() | @*" mode="schematron-get-full-path-3">
      <xsl:for-each select="ancestor-or-self::*">
         <xsl:text>/</xsl:text>
         <xsl:value-of select="name(.)"/>
         <xsl:if test="parent::*">
            <xsl:text>[</xsl:text>
            <xsl:value-of select="count(preceding-sibling::*[name(.)=name(current())])+1"/>
            <xsl:text>]</xsl:text>
         </xsl:if>
      </xsl:for-each>
      <xsl:if test="not(self::*)">
         <xsl:text/>/@<xsl:value-of select="name(.)"/>
      </xsl:if>
   </xsl:template>

   <!--MODE: GENERATE-ID-FROM-PATH -->
   <xsl:template match="/" mode="generate-id-from-path"/>
   <xsl:template match="text()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.text-', 1+count(preceding-sibling::text()), '-')"/>
   </xsl:template>
   <xsl:template match="comment()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.comment-', 1+count(preceding-sibling::comment()), '-')"/>
   </xsl:template>
   <xsl:template match="processing-instruction()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.processing-instruction-', 1+count(preceding-sibling::processing-instruction()), '-')"/>
   </xsl:template>
   <xsl:template match="@*" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.@', name())"/>
   </xsl:template>
   <xsl:template match="*" mode="generate-id-from-path" priority="-0.5">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:text>.</xsl:text>
      <xsl:value-of select="concat('.',name(),'-',1+count(preceding-sibling::*[name()=name(current())]),'-')"/>
   </xsl:template>

   <!--MODE: GENERATE-ID-2 -->
   <xsl:template match="/" mode="generate-id-2">U</xsl:template>
   <xsl:template match="*" mode="generate-id-2" priority="2">
      <xsl:text>U</xsl:text>
      <xsl:number level="multiple" count="*"/>
   </xsl:template>
   <xsl:template match="node()" mode="generate-id-2">
      <xsl:text>U.</xsl:text>
      <xsl:number level="multiple" count="*"/>
      <xsl:text>n</xsl:text>
      <xsl:number count="node()"/>
   </xsl:template>
   <xsl:template match="@*" mode="generate-id-2">
      <xsl:text>U.</xsl:text>
      <xsl:number level="multiple" count="*"/>
      <xsl:text>_</xsl:text>
      <xsl:value-of select="string-length(local-name(.))"/>
      <xsl:text>_</xsl:text>
      <xsl:value-of select="translate(name(),':','.')"/>
   </xsl:template>
   <!--Strip characters-->
   <xsl:template match="text()" priority="-1"/>

   <!--SCHEMA SETUP-->
   <xsl:template match="/">
      <svrl:schematron-output xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                              title=" Schematron file for ORL_O22 - Verzenden aanvraagbevestiging "
                              schemaVersion="">
         <xsl:comment>
            <xsl:value-of select="$archiveDirParameter"/>   
		 <xsl:value-of select="$archiveNameParameter"/>  
		 <xsl:value-of select="$fileNameParameter"/>  
		 <xsl:value-of select="$fileDirParameter"/>
         </xsl:comment>
         <svrl:ns-prefix-in-attribute-values uri="urn:hl7-org:v3" prefix="hl7"/>
         <svrl:ns-prefix-in-attribute-values uri="urn:hl7-org:v3" prefix="cda"/>
         <svrl:ns-prefix-in-attribute-values uri="http://www.w3.org/2001/XMLSchema-instance" prefix="xsi"/>
         <svrl:ns-prefix-in-attribute-values uri="http://www.w3.org/2001/XMLSchema" prefix="xs"/>
         <svrl:ns-prefix-in-attribute-values uri="urn:hl7-org:v2xml" prefix="hl7v2"/>
         <svrl:ns-prefix-in-attribute-values uri="http://www.w3.org/XML/1998/namespace" prefix="xml"/>
         <svrl:ns-prefix-in-attribute-values uri="urn:oid:1.3.6.1.4.1.19376.1.3.2" prefix="lab"/>
         <svrl:ns-prefix-in-attribute-values uri="urn:hl7-org:sdtc" prefix="sdtc"/>
         <svrl:ns-prefix-in-attribute-values uri="urn:hl7-nl:v3" prefix="hl7nl"/>
         <svrl:ns-prefix-in-attribute-values uri="urn:urn:nictiz-nl:v3/nfu" prefix="nfu"/>
         <svrl:ns-prefix-in-attribute-values uri="urn:ihe:pharm:medication" prefix="pharm"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M12"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="name">ORL_O22_Lab2Lab</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M13"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">template-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701</xsl:attribute>
            <xsl:attribute name="name">Lab2Lab Aanvraagbevestigingbericht (ORL^O22)</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M14"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">template-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701-closed</xsl:attribute>
            <xsl:attribute name="name">Lab2Lab Aanvraagbevestigingbericht (ORL^O22)</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M15"/>
      </svrl:schematron-output>
   </xsl:template>

   <!--SCHEMATRON PATTERNS-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl"> Schematron file for ORL_O22 - Verzenden aanvraagbevestiging </svrl:text>

   <!--PATTERN -->
   <xsl:template match="text()" priority="-1" mode="M12"/>
   <xsl:template match="@*|node()" priority="-2" mode="M12">
      <xsl:apply-templates select="*" mode="M12"/>
   </xsl:template>

   <!--PATTERN ORL_O22_Lab2Lab-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">ORL_O22_Lab2Lab</svrl:text>

	  <!--RULE -->
   <xsl:template match="/" priority="1000" mode="M13">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::hl7v2:MSH | descendant-or-self::hl7v2:MSA | descendant-or-self::hl7v2:ERR | descendant-or-self::hl7v2:SFT | descendant-or-self::hl7v2:NTE | descendant-or-self::hl7v2:ORL_O22.RESPONSE"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="descendant-or-self::hl7v2:MSH | descendant-or-self::hl7v2:MSA | descendant-or-self::hl7v2:ERR | descendant-or-self::hl7v2:SFT | descendant-or-self::hl7v2:NTE | descendant-or-self::hl7v2:ORL_O22.RESPONSE">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>In de instance werd tenminste één van de volgende elementen verwacht: descendant-or-self::hl7v2:MSH | descendant-or-self::hl7v2:MSA | descendant-or-self::hl7v2:ERR | descendant-or-self::hl7v2:SFT | descendant-or-self::hl7v2:NTE | descendant-or-self::hl7v2:ORL_O22.RESPONSE</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M13"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M13"/>
   <xsl:template match="@*|node()" priority="-2" mode="M13">
      <xsl:apply-templates select="*" mode="M13"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701Lab2Lab Aanvraagbevestigingbericht (ORL^O22)-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">Lab2Lab Aanvraagbevestigingbericht (ORL^O22)</svrl:text>

	  <!--RULE d20e23176-false-d961634e0-->
   <xsl:template match="/" priority="4432" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab): element hl7v2:MSH is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab): element hl7v2:MSH komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSA) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSA) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab): element hl7v2:MSA is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSA) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSA) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab): element hl7v2:MSA komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORL_O22.RESPONSE) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7v2:ORL_O22.RESPONSE) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab): element hl7v2:ORL_O22.RESPONSE komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH" priority="4431" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.1) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.1) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): element hl7v2:MSH.1 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): element hl7v2:MSH.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.2) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.2) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): element hl7v2:MSH.2 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): element hl7v2:MSH.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.3) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.3) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): element hl7v2:MSH.3 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): element hl7v2:MSH.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): element hl7v2:MSH.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.5) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.5) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): element hl7v2:MSH.5 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): element hl7v2:MSH.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.6) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.6) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): element hl7v2:MSH.6 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): element hl7v2:MSH.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.7) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.7) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): element hl7v2:MSH.7 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): element hl7v2:MSH.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): element hl7v2:MSH.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.9) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.9) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): element hl7v2:MSH.9 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): element hl7v2:MSH.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.10) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.10) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): element hl7v2:MSH.10 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): element hl7v2:MSH.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.11) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.11) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): element hl7v2:MSH.11 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): element hl7v2:MSH.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.12) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.12) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): element hl7v2:MSH.12 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.12) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.12) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): element hl7v2:MSH.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.13) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.13) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): element hl7v2:MSH.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.14) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.14) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): element hl7v2:MSH.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.15) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.15) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): element hl7v2:MSH.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.16) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.16) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): element hl7v2:MSH.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.17) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.17) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): element hl7v2:MSH.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.18) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.18) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): element hl7v2:MSH.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.19) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.19) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): element hl7v2:MSH.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.20) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.20) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): element hl7v2:MSH.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.21) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.21) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): element hl7v2:MSH.21 is mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.1" priority="4430" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Item MOET '1' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Field Separator') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Field Separator') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van LongName MOET 'Field Separator' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.2" priority="4429" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('2') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('2') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Item MOET '2' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Encoding Characters') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Encoding Characters') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van LongName MOET 'Encoding Characters' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.3" priority="4428" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('3') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('3') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Item MOET '3' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70361') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70361') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Table MOET 'HL70361' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Sending Application') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Sending Application') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van LongName MOET 'Sending Application' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.3/hl7v2:HD.1"
                 priority="4426"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.3/hl7v2:HD.2"
                 priority="4425"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.3/hl7v2:HD.3"
                 priority="4424"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.4" priority="4422" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('4') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('4') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Item MOET '4' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70362') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70362') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Table MOET 'HL70362' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Sending Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Sending Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van LongName MOET 'Sending Facility' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.4/hl7v2:HD.1"
                 priority="4420"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.4/hl7v2:HD.2"
                 priority="4419"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.4/hl7v2:HD.3"
                 priority="4418"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.5" priority="4416" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('5') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('5') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Item MOET '5' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70361') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70361') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Table MOET 'HL70361' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Receiving Application') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Receiving Application') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van LongName MOET 'Receiving Application' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.5/hl7v2:HD.1"
                 priority="4414"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.5/hl7v2:HD.2"
                 priority="4413"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.5/hl7v2:HD.3"
                 priority="4412"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.6" priority="4410" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('6') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('6') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Item MOET '6' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70362') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70362') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Table MOET 'HL70362' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Receiving Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Receiving Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van LongName MOET 'Receiving Facility' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.6/hl7v2:HD.1"
                 priority="4408"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.6/hl7v2:HD.2"
                 priority="4407"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.6/hl7v2:HD.3"
                 priority="4406"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.7" priority="4404" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('7') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('7') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Item MOET '7' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Date/Time Of Message') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Date/Time Of Message') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van LongName MOET 'Date/Time Of Message' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.7/hl7v2:TS.1"
                 priority="4402"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.7/hl7v2:TS.2"
                 priority="4401"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.8" priority="4399" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('8') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('8') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Item MOET '8' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Security') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Security') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van LongName MOET 'Security' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.9" priority="4398" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSG.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSG.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSG_datatype): element hl7v2:MSG.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSG.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSG.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSG_datatype): element hl7v2:MSG.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSG.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSG.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSG_datatype): element hl7v2:MSG.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('9') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('9') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Item MOET '9' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('MSG') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('MSG') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Type MOET 'MSG' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Message Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Message Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van LongName MOET 'Message Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.9/hl7v2:MSG.1"
                 priority="4396"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSG_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70076') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70076') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSG_datatype): de waarde van Table MOET 'HL70076' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Message Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Message Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSG_datatype): de waarde van LongName MOET 'Message Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.9/hl7v2:MSG.2"
                 priority="4394"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSG_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70003') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70003') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSG_datatype): de waarde van Table MOET 'HL70003' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Trigger Event') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Trigger Event') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSG_datatype): de waarde van LongName MOET 'Trigger Event' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.9/hl7v2:MSG.3"
                 priority="4392"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSG_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70354') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70354') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSG_datatype): de waarde van Table MOET 'HL70354' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Message Structure') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Message Structure') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSG_datatype): de waarde van LongName MOET 'Message Structure' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.10" priority="4390" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('10') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('10') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Item MOET '10' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Message Control ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Message Control ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van LongName MOET 'Message Control ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.11" priority="4389" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PT.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PT.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.48-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PT_datatype): element hl7v2:PT.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PT.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PT.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.48-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PT_datatype): element hl7v2:PT.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('11') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('11') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Item MOET '11' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('PT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('PT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Type MOET 'PT' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Processing ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Processing ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van LongName MOET 'Processing ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.11/hl7v2:PT.1"
                 priority="4387"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.48-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PT_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70103') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70103') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.48-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PT_datatype): de waarde van Table MOET 'HL70103' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Processing ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Processing ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.48-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PT_datatype): de waarde van LongName MOET 'Processing ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.11/hl7v2:PT.2"
                 priority="4385"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.48-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PT_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70207') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70207') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.48-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PT_datatype): de waarde van Table MOET 'HL70207' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Processing Mode') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Processing Mode') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.48-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PT_datatype): de waarde van LongName MOET 'Processing Mode' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.12" priority="4383" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='2.5'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="text()='2.5'">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(VID_datatype): de elementinhoud van hl7v2:MSH.12 MOET ''2.5'' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:VID.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:VID.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(VID_datatype): element hl7v2:VID.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:VID.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:VID.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(VID_datatype): element hl7v2:VID.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:VID.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:VID.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(VID_datatype): element hl7v2:VID.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('12') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('12') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Item MOET '12' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('VID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('VID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Type MOET 'VID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van LongName MOET 'Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.1"
                 priority="4381"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(VID_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70104') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70104') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(VID_datatype): de waarde van Table MOET 'HL70104' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(VID_datatype): de waarde van LongName MOET 'Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.2"
                 priority="4379"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(VID_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70399') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70399') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(VID_datatype): de waarde van Table MOET 'HL70399' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Internationalization Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Internationalization Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(VID_datatype): de waarde van LongName MOET 'Internationalization Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.2/hl7v2:CE.1"
                 priority="4377"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.2/hl7v2:CE.2"
                 priority="4376"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.2/hl7v2:CE.3"
                 priority="4375"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.2/hl7v2:CE.4"
                 priority="4373"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.2/hl7v2:CE.5"
                 priority="4372"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.2/hl7v2:CE.6"
                 priority="4371"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.3"
                 priority="4369"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(VID_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('International Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('International Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(VID_datatype): de waarde van LongName MOET 'International Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.3/hl7v2:CE.1"
                 priority="4367"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.3/hl7v2:CE.2"
                 priority="4366"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.3/hl7v2:CE.3"
                 priority="4365"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.3/hl7v2:CE.4"
                 priority="4363"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.3/hl7v2:CE.5"
                 priority="4362"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.3/hl7v2:CE.6"
                 priority="4361"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.13" priority="4359" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('13') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('13') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Item MOET '13' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Sequence Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Sequence Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van LongName MOET 'Sequence Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.14" priority="4358" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('14') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('14') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Item MOET '14' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Continuation Pointer') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Continuation Pointer') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van LongName MOET 'Continuation Pointer' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.15" priority="4357" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('15') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('15') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Item MOET '15' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70155') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70155') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Table MOET 'HL70155' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Accept Acknowledgment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Accept Acknowledgment Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van LongName MOET 'Accept Acknowledgment Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.16" priority="4355" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('16') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('16') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Item MOET '16' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70155') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70155') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Table MOET 'HL70155' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Application Acknowledgment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Application Acknowledgment Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van LongName MOET 'Application Acknowledgment Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.17" priority="4353" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='NLD'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="text()='NLD'">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de elementinhoud van hl7v2:MSH.17 MOET ''NLD'' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="."/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('17') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('17') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Item MOET '17' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70399') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70399') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Table MOET 'HL70399' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Country Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van LongName MOET 'Country Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.18" priority="4351" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('692') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('692') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Item MOET '692' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70211') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70211') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Table MOET 'HL70211' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Character Set') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Character Set') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van LongName MOET 'Character Set' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.19" priority="4349" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('693') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('693') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Item MOET '693' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Principal Language Of Message') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Principal Language Of Message') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van LongName MOET 'Principal Language Of Message' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.19/hl7v2:CE.1"
                 priority="4347"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.19/hl7v2:CE.2"
                 priority="4346"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.19/hl7v2:CE.3"
                 priority="4345"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.19/hl7v2:CE.4"
                 priority="4343"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.19/hl7v2:CE.5"
                 priority="4342"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.19/hl7v2:CE.6"
                 priority="4341"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.20" priority="4339" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1317') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1317') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Item MOET '1317' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70356') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70356') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Table MOET 'HL70356' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Character Set Handling Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Character Set Handling Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van LongName MOET 'Alternate Character Set Handling Scheme' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.21" priority="4337" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1598') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1598') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Item MOET '1598' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Message Profile Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Message Profile Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab_algemeen): de waarde van LongName MOET 'Message Profile Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.21/hl7v2:EI.1"
                 priority="4335"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.21/hl7v2:EI.2"
                 priority="4334"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.21/hl7v2:EI.3"
                 priority="4333"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.21/hl7v2:EI.4"
                 priority="4332"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSA" priority="4330" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSA.1) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSA.1) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.72-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSA_segment): element hl7v2:MSA.1 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSA.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSA.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.72-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSA_segment): element hl7v2:MSA.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSA.2) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSA.2) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.72-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSA_segment): element hl7v2:MSA.2 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSA.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSA.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.72-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSA_segment): element hl7v2:MSA.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSA.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSA.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.72-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSA_segment): element hl7v2:MSA.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSA.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSA.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.72-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSA_segment): element hl7v2:MSA.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSA.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSA.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.72-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSA_segment): element hl7v2:MSA.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSA.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSA.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.72-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSA_segment): element hl7v2:MSA.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSA/hl7v2:MSA.1" priority="4329" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('18') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('18') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.72-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSA_segment): de waarde van Item MOET '18' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.72-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSA_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70008') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70008') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.72-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSA_segment): de waarde van Table MOET 'HL70008' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Acknowledgment Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Acknowledgment Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.72-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSA_segment): de waarde van LongName MOET 'Acknowledgment Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSA/hl7v2:MSA.2" priority="4327" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('10') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('10') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.72-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSA_segment): de waarde van Item MOET '10' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.72-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSA_segment): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Message Control ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Message Control ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.72-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSA_segment): de waarde van LongName MOET 'Message Control ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSA/hl7v2:MSA.3" priority="4326" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('20') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('20') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.72-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSA_segment): de waarde van Item MOET '20' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.72-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSA_segment): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text Message') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text Message') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.72-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSA_segment): de waarde van LongName MOET 'Text Message' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSA/hl7v2:MSA.4" priority="4325" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('21') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('21') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.72-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSA_segment): de waarde van Item MOET '21' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.72-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSA_segment): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expected Sequence Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Expected Sequence Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.72-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSA_segment): de waarde van LongName MOET 'Expected Sequence Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSA/hl7v2:MSA.5" priority="4324" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('22') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('22') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.72-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSA_segment): de waarde van Item MOET '22' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.72-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSA_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Delayed Acknowledgment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Delayed Acknowledgment Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.72-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSA_segment): de waarde van LongName MOET 'Delayed Acknowledgment Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSA/hl7v2:MSA.6" priority="4322" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('23') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('23') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.72-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSA_segment): de waarde van Item MOET '23' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.72-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSA_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70357') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70357') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.72-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSA_segment): de waarde van Table MOET 'HL70357' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Error Condition') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Error Condition') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.72-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSA_segment): de waarde van LongName MOET 'Error Condition' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSA/hl7v2:MSA.6/hl7v2:CE.1"
                 priority="4320"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSA/hl7v2:MSA.6/hl7v2:CE.2"
                 priority="4319"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSA/hl7v2:MSA.6/hl7v2:CE.3"
                 priority="4318"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSA/hl7v2:MSA.6/hl7v2:CE.4"
                 priority="4316"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSA/hl7v2:MSA.6/hl7v2:CE.5"
                 priority="4315"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:MSA/hl7v2:MSA.6/hl7v2:CE.6"
                 priority="4314"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR" priority="4312" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ERR.3) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ERR.3) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): element hl7v2:ERR.3 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ERR.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ERR.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): element hl7v2:ERR.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ERR.4) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ERR.4) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): element hl7v2:ERR.4 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ERR.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ERR.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): element hl7v2:ERR.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ERR.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ERR.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): element hl7v2:ERR.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ERR.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ERR.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): element hl7v2:ERR.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ERR.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ERR.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): element hl7v2:ERR.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ERR.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ERR.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): element hl7v2:ERR.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.1" priority="4311" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ELD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ELD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.23-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ELD_datatype): element hl7v2:ELD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ELD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ELD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.23-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ELD_datatype): element hl7v2:ELD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ELD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ELD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.23-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ELD_datatype): element hl7v2:ELD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ELD.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ELD.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.23-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ELD_datatype): element hl7v2:ELD.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('24') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('24') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van Item MOET '24' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ELD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ELD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van Type MOET 'ELD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Error Code and Location') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Error Code and Location') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van LongName MOET 'Error Code and Location' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.1/hl7v2:ELD.1"
                 priority="4309"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.23-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ELD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Segment ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Segment ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.23-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ELD_datatype): de waarde van LongName MOET 'Segment ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.1/hl7v2:ELD.2"
                 priority="4308"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.23-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ELD_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Segment Sequence') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Segment Sequence') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.23-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ELD_datatype): de waarde van LongName MOET 'Segment Sequence' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.1/hl7v2:ELD.3"
                 priority="4307"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.23-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ELD_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Field Position') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Field Position') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.23-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ELD_datatype): de waarde van LongName MOET 'Field Position' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.1/hl7v2:ELD.4"
                 priority="4306"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.23-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ELD_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70357') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70357') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.23-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ELD_datatype): de waarde van Table MOET 'HL70357' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Code Identifying Error') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Code Identifying Error') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.23-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ELD_datatype): de waarde van LongName MOET 'Code Identifying Error' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.1/hl7v2:ELD.4/hl7v2:CE.1"
                 priority="4304"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.1/hl7v2:ELD.4/hl7v2:CE.2"
                 priority="4303"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.1/hl7v2:ELD.4/hl7v2:CE.3"
                 priority="4302"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.1/hl7v2:ELD.4/hl7v2:CE.4"
                 priority="4300"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.1/hl7v2:ELD.4/hl7v2:CE.5"
                 priority="4299"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.1/hl7v2:ELD.4/hl7v2:CE.6"
                 priority="4298"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.2" priority="4296" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ERL.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ERL.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.24-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERL_datatype): element hl7v2:ERL.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ERL.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ERL.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.24-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERL_datatype): element hl7v2:ERL.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ERL.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ERL.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.24-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERL_datatype): element hl7v2:ERL.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ERL.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ERL.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.24-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERL_datatype): element hl7v2:ERL.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ERL.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ERL.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.24-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERL_datatype): element hl7v2:ERL.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ERL.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ERL.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.24-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERL_datatype): element hl7v2:ERL.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1812') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1812') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van Item MOET '1812' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ERL') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ERL') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van Type MOET 'ERL' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Error Location') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Error Location') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van LongName MOET 'Error Location' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.2/hl7v2:ERL.1"
                 priority="4294"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.24-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERL_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Segment ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Segment ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.24-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERL_datatype): de waarde van LongName MOET 'Segment ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.2/hl7v2:ERL.2"
                 priority="4293"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.24-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERL_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Segment Sequence') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Segment Sequence') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.24-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERL_datatype): de waarde van LongName MOET 'Segment Sequence' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.2/hl7v2:ERL.3"
                 priority="4292"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.24-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERL_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Field Position') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Field Position') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.24-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERL_datatype): de waarde van LongName MOET 'Field Position' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.2/hl7v2:ERL.4"
                 priority="4291"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.24-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERL_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Field Repetition') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Field Repetition') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.24-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERL_datatype): de waarde van LongName MOET 'Field Repetition' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.2/hl7v2:ERL.5"
                 priority="4290"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.24-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERL_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Component Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Component Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.24-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERL_datatype): de waarde van LongName MOET 'Component Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.2/hl7v2:ERL.6"
                 priority="4289"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.24-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERL_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Sub-Component Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Sub-Component Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.24-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERL_datatype): de waarde van LongName MOET 'Sub-Component Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.3" priority="4288" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1813') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1813') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van Item MOET '1813' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70357') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70357') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van Table MOET 'HL70357' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('HL7 Error Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('HL7 Error Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van LongName MOET 'HL7 Error Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.3/hl7v2:CWE.1"
                 priority="4286"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.3/hl7v2:CWE.2"
                 priority="4285"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.3/hl7v2:CWE.3"
                 priority="4284"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.3/hl7v2:CWE.4"
                 priority="4282"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.3/hl7v2:CWE.5"
                 priority="4281"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.3/hl7v2:CWE.6"
                 priority="4280"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.3/hl7v2:CWE.7"
                 priority="4278"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.3/hl7v2:CWE.8"
                 priority="4277"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.3/hl7v2:CWE.9"
                 priority="4276"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.4" priority="4275" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1814') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1814') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van Item MOET '1814' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70516') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70516') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van Table MOET 'HL70516' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Severity') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Severity') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van LongName MOET 'Severity' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.5" priority="4273" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1815') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1815') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van Item MOET '1815' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70533') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70533') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van Table MOET 'HL70533' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Application Error Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Application Error Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van LongName MOET 'Application Error Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.5/hl7v2:CWE.1"
                 priority="4271"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.5/hl7v2:CWE.2"
                 priority="4270"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.5/hl7v2:CWE.3"
                 priority="4269"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.5/hl7v2:CWE.4"
                 priority="4267"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.5/hl7v2:CWE.5"
                 priority="4266"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.5/hl7v2:CWE.6"
                 priority="4265"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.5/hl7v2:CWE.7"
                 priority="4263"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.5/hl7v2:CWE.8"
                 priority="4262"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.5/hl7v2:CWE.9"
                 priority="4261"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.6" priority="4260" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1816') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1816') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van Item MOET '1816' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Application Error Parameter') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Application Error Parameter') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van LongName MOET 'Application Error Parameter' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.7" priority="4259" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1817') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1817') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van Item MOET '1817' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TX') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TX') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van Type MOET 'TX' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Diagnostic Information') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Diagnostic Information') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van LongName MOET 'Diagnostic Information' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.7/hl7v2:escape"
                 priority="4258"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.65-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TX_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.7/hl7v2:escape/hl7v2:escape"
                 priority="4257"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.7/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="4256"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.8" priority="4255" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1818') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1818') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van Item MOET '1818' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TX') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TX') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van Type MOET 'TX' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('User Message') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('User Message') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van LongName MOET 'User Message' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.8/hl7v2:escape"
                 priority="4254"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.65-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TX_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.8/hl7v2:escape/hl7v2:escape"
                 priority="4253"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.8/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="4252"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.9" priority="4251" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1819') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1819') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van Item MOET '1819' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70517') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70517') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van Table MOET 'HL70517' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Inform Person Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Inform Person Indicator') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van LongName MOET 'Inform Person Indicator' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.10" priority="4250" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1820') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1820') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van Item MOET '1820' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70518') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70518') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van Table MOET 'HL70518' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Override Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Override Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van LongName MOET 'Override Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.10/hl7v2:CWE.1"
                 priority="4248"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.10/hl7v2:CWE.2"
                 priority="4247"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.10/hl7v2:CWE.3"
                 priority="4246"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.10/hl7v2:CWE.4"
                 priority="4244"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.10/hl7v2:CWE.5"
                 priority="4243"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.10/hl7v2:CWE.6"
                 priority="4242"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.10/hl7v2:CWE.7"
                 priority="4240"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.10/hl7v2:CWE.8"
                 priority="4239"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.10/hl7v2:CWE.9"
                 priority="4238"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.11" priority="4237" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1821') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1821') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van Item MOET '1821' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70519') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70519') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van Table MOET 'HL70519' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Override Reason Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Override Reason Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van LongName MOET 'Override Reason Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.11/hl7v2:CWE.1"
                 priority="4235"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.11/hl7v2:CWE.2"
                 priority="4234"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.11/hl7v2:CWE.3"
                 priority="4233"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.11/hl7v2:CWE.4"
                 priority="4231"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.11/hl7v2:CWE.5"
                 priority="4230"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.11/hl7v2:CWE.6"
                 priority="4229"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.11/hl7v2:CWE.7"
                 priority="4227"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.11/hl7v2:CWE.8"
                 priority="4226"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.11/hl7v2:CWE.9"
                 priority="4225"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.12" priority="4224" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.12) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1822') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1822') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van Item MOET '1822' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('XTN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van Type MOET 'XTN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Help Desk Contact Point') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Help Desk Contact Point') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ERR_segment): de waarde van LongName MOET 'Help Desk Contact Point' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.12/hl7v2:XTN.1"
                 priority="4222"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Telephone Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Telephone Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.12/hl7v2:XTN.2"
                 priority="4221"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70201') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Table MOET 'HL70201' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Telecommunication Use Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Use Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.12/hl7v2:XTN.3"
                 priority="4219"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70202') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Table MOET 'HL70202' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Equipment Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.12/hl7v2:XTN.4"
                 priority="4217"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Email Address') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Email Address' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.12/hl7v2:XTN.5"
                 priority="4216"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Country Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Country Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.12/hl7v2:XTN.6"
                 priority="4215"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Area/City Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Area/City Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.12/hl7v2:XTN.7"
                 priority="4214"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Local Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Local Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.12/hl7v2:XTN.8"
                 priority="4213"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Extension') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Extension' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.12/hl7v2:XTN.9"
                 priority="4212"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Any Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Any Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.12/hl7v2:XTN.10"
                 priority="4211"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Extension Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Extension Prefix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.12/hl7v2:XTN.11"
                 priority="4210"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Speed Dial Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Speed Dial Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.12/hl7v2:XTN.12"
                 priority="4209"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Unformatted Telephone number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Unformatted Telephone number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:SFT" priority="4208" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SFT.1) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SFT.1) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SFT_segment): element hl7v2:SFT.1 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SFT.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SFT.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SFT_segment): element hl7v2:SFT.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SFT.2) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SFT.2) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SFT_segment): element hl7v2:SFT.2 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SFT.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SFT.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SFT_segment): element hl7v2:SFT.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SFT.3) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SFT.3) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SFT_segment): element hl7v2:SFT.3 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SFT.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SFT.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SFT_segment): element hl7v2:SFT.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SFT.4) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SFT.4) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SFT_segment): element hl7v2:SFT.4 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SFT.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SFT.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SFT_segment): element hl7v2:SFT.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SFT.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SFT.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SFT_segment): element hl7v2:SFT.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SFT.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SFT.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SFT_segment): element hl7v2:SFT.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:SFT/hl7v2:SFT.1" priority="4207" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1834') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1834') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SFT_segment): de waarde van Item MOET '1834' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XON') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('XON') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SFT_segment): de waarde van Type MOET 'XON' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Software Vendor Organization') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Software Vendor Organization') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SFT_segment): de waarde van LongName MOET 'Software Vendor Organization' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:SFT/hl7v2:SFT.1/hl7v2:XON.1"
                 priority="4205"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organization Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Organization Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van LongName MOET 'Organization Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:SFT/hl7v2:SFT.1/hl7v2:XON.2"
                 priority="4204"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70204') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70204') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Table MOET 'HL70204' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organization Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Organization Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van LongName MOET 'Organization Name Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:SFT/hl7v2:SFT.1/hl7v2:XON.3"
                 priority="4203"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:SFT/hl7v2:SFT.1/hl7v2:XON.4"
                 priority="4202"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van LongName MOET 'Check Digit' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:SFT/hl7v2:SFT.1/hl7v2:XON.5"
                 priority="4201"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:SFT/hl7v2:SFT.1/hl7v2:XON.6"
                 priority="4199"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:SFT/hl7v2:SFT.1/hl7v2:XON.6/hl7v2:HD.1"
                 priority="4197"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:SFT/hl7v2:SFT.1/hl7v2:XON.6/hl7v2:HD.2"
                 priority="4196"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:SFT/hl7v2:SFT.1/hl7v2:XON.6/hl7v2:HD.3"
                 priority="4195"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:SFT/hl7v2:SFT.1/hl7v2:XON.7"
                 priority="4193"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:SFT/hl7v2:SFT.1/hl7v2:XON.8"
                 priority="4191"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:SFT/hl7v2:SFT.1/hl7v2:XON.8/hl7v2:HD.1"
                 priority="4189"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:SFT/hl7v2:SFT.1/hl7v2:XON.8/hl7v2:HD.2"
                 priority="4188"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:SFT/hl7v2:SFT.1/hl7v2:XON.8/hl7v2:HD.3"
                 priority="4187"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:SFT/hl7v2:SFT.1/hl7v2:XON.9"
                 priority="4185"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:SFT/hl7v2:SFT.1/hl7v2:XON.10"
                 priority="4183"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organization Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Organization Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van LongName MOET 'Organization Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:SFT/hl7v2:SFT.2" priority="4182" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1835') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1835') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SFT_segment): de waarde van Item MOET '1835' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SFT_segment): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Software Certified Version or Release Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Software Certified Version or Release Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SFT_segment): de waarde van LongName MOET 'Software Certified Version or Release Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:SFT/hl7v2:SFT.3" priority="4181" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1836') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1836') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SFT_segment): de waarde van Item MOET '1836' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SFT_segment): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Software Product Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Software Product Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SFT_segment): de waarde van LongName MOET 'Software Product Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:SFT/hl7v2:SFT.4" priority="4180" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1837') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1837') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SFT_segment): de waarde van Item MOET '1837' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SFT_segment): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Software Binary ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Software Binary ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SFT_segment): de waarde van LongName MOET 'Software Binary ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:SFT/hl7v2:SFT.5" priority="4179" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1838') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1838') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SFT_segment): de waarde van Item MOET '1838' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TX') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TX') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SFT_segment): de waarde van Type MOET 'TX' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Software Product Information') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Software Product Information') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SFT_segment): de waarde van LongName MOET 'Software Product Information' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:SFT/hl7v2:SFT.5/hl7v2:escape"
                 priority="4178"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.65-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TX_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:SFT/hl7v2:SFT.5/hl7v2:escape/hl7v2:escape"
                 priority="4177"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:SFT/hl7v2:SFT.5/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="4176"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:SFT/hl7v2:SFT.6" priority="4175" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1839') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1839') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SFT_segment): de waarde van Item MOET '1839' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SFT_segment): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Software Install Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Software Install Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SFT_segment): de waarde van LongName MOET 'Software Install Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:SFT/hl7v2:SFT.6/hl7v2:TS.1"
                 priority="4173"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:SFT/hl7v2:SFT.6/hl7v2:TS.2"
                 priority="4172"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:NTE" priority="4170" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NTE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.80-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): element hl7v2:NTE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NTE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.80-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): element hl7v2:NTE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NTE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.80-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): element hl7v2:NTE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:NTE/hl7v2:NTE.1" priority="4169" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('96') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('96') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.80-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van Item MOET '96' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('SI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.80-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van Type MOET 'SI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Set ID - NTE') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Set ID - NTE') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.80-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van LongName MOET 'Set ID - NTE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:NTE/hl7v2:NTE.2" priority="4168" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('97') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('97') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.80-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van Item MOET '97' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.80-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70105') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70105') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.80-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van Table MOET 'HL70105' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source of Comment') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Source of Comment') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.80-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van LongName MOET 'Source of Comment' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:NTE/hl7v2:NTE.3" priority="4166" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('98') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('98') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.80-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van Item MOET '98' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('FT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.80-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van Type MOET 'FT' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Comment') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Comment') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.80-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van LongName MOET 'Comment' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape"
                 priority="4165"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.27-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FT_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/hl7v2:escape"
                 priority="4164"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="4163"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:NTE/hl7v2:NTE.4" priority="4162" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1318') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1318') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.80-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van Item MOET '1318' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.80-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70364') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70364') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.80-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van Table MOET 'HL70364' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Comment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Comment Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.80-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van LongName MOET 'Comment Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.1"
                 priority="4160"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.2"
                 priority="4159"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.3"
                 priority="4158"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.4"
                 priority="4156"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.5"
                 priority="4155"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.6"
                 priority="4154"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE d20e23206-false-d968030e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE" priority="4152" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORL_O22.PATIENT) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7v2:ORL_O22.PATIENT) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab): element hl7v2:ORL_O22.PATIENT is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORL_O22.PATIENT) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7v2:ORL_O22.PATIENT) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab): element hl7v2:ORL_O22.PATIENT komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE d20e23214-false-d968042e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT"
                 priority="4151"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab): element hl7v2:PID is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab): element hl7v2:PID komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORL_O22.ORDER) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7v2:ORL_O22.ORDER) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab): element hl7v2:ORL_O22.ORDER is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID"
                 priority="4150"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): element hl7v2:PID.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): element hl7v2:PID.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.3) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.3) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): element hl7v2:PID.3 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.5) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.5) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): element hl7v2:PID.5 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): element hl7v2:PID.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): element hl7v2:PID.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.12) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.12) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): element hl7v2:PID.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.15) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.15) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): element hl7v2:PID.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.16) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.16) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): element hl7v2:PID.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.17) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.17) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): element hl7v2:PID.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.18) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.18) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): element hl7v2:PID.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.19) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.19) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): element hl7v2:PID.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.20) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.20) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): element hl7v2:PID.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.23) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.23) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): element hl7v2:PID.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.24) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.24) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): element hl7v2:PID.24 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.25) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.25) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): element hl7v2:PID.25 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.27) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.27) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): element hl7v2:PID.27 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.28) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.28) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): element hl7v2:PID.28 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.29) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.29) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): element hl7v2:PID.29 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.30) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.30) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): element hl7v2:PID.30 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.31) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.31) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): element hl7v2:PID.31 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.33) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.33) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): element hl7v2:PID.33 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.34) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.34) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): element hl7v2:PID.34 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.35) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.35) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): element hl7v2:PID.35 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.36) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.36) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): element hl7v2:PID.36 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.37) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.37) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): element hl7v2:PID.37 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.38) &lt;= 2"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.38) &lt;= 2">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): element hl7v2:PID.38 komt te vaak voor [max 2x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.1"
                 priority="4149"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('104') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('104') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Item MOET '104' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('SI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Type MOET 'SI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Set ID - PID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Set ID - PID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van LongName MOET 'Set ID - PID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.2"
                 priority="4148"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('105') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('105') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Item MOET '105' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CX') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CX') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Type MOET 'CX' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Patient ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van LongName MOET 'Patient ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.1"
                 priority="4146"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.2"
                 priority="4145"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Check Digit' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.3"
                 priority="4144"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.4"
                 priority="4142"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.4/hl7v2:HD.1"
                 priority="4140"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.4/hl7v2:HD.2"
                 priority="4139"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.4/hl7v2:HD.3"
                 priority="4138"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.5"
                 priority="4136"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.6"
                 priority="4134"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.6/hl7v2:HD.1"
                 priority="4132"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.6/hl7v2:HD.2"
                 priority="4131"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.6/hl7v2:HD.3"
                 priority="4130"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.7"
                 priority="4128"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.8"
                 priority="4127"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9"
                 priority="4126"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="4124"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="4123"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="4122"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="4120"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="4119"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="4118"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="4116"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="4115"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="4114"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10"
                 priority="4113"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="4111"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="4110"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="4109"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="4107"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="4106"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="4105"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="4103"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="4102"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="4101"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.3"
                 priority="4100"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('106') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('106') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Item MOET '106' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CX') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CX') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Type MOET 'CX' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Identifier List') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Patient Identifier List') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van LongName MOET 'Patient Identifier List' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.1"
                 priority="4098"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.2"
                 priority="4097"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Check Digit' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.3"
                 priority="4096"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.4"
                 priority="4094"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.4/hl7v2:HD.1"
                 priority="4092"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.4/hl7v2:HD.2"
                 priority="4091"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.4/hl7v2:HD.3"
                 priority="4090"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.5"
                 priority="4088"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.6"
                 priority="4086"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.6/hl7v2:HD.1"
                 priority="4084"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.6/hl7v2:HD.2"
                 priority="4083"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.6/hl7v2:HD.3"
                 priority="4082"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.7"
                 priority="4080"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.8"
                 priority="4079"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9"
                 priority="4078"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="4076"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="4075"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="4074"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="4072"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="4071"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="4070"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="4068"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="4067"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="4066"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10"
                 priority="4065"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="4063"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="4062"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="4061"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="4059"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="4058"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="4057"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="4055"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="4054"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="4053"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.4"
                 priority="4052"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('107') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('107') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Item MOET '107' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CX') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CX') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Type MOET 'CX' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Patient ID - PID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Patient ID - PID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van LongName MOET 'Alternate Patient ID - PID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.1"
                 priority="4050"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.2"
                 priority="4049"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Check Digit' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.3"
                 priority="4048"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.4"
                 priority="4046"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.4/hl7v2:HD.1"
                 priority="4044"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.4/hl7v2:HD.2"
                 priority="4043"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.4/hl7v2:HD.3"
                 priority="4042"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.5"
                 priority="4040"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.6"
                 priority="4038"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.6/hl7v2:HD.1"
                 priority="4036"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.6/hl7v2:HD.2"
                 priority="4035"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.6/hl7v2:HD.3"
                 priority="4034"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.7"
                 priority="4032"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.8"
                 priority="4031"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9"
                 priority="4030"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="4028"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="4027"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="4026"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="4024"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="4023"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="4022"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="4020"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="4019"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="4018"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10"
                 priority="4017"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="4015"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="4014"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="4013"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="4011"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="4010"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="4009"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="4007"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="4006"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="4005"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.5"
                 priority="4004"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.12) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.12) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.13) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.13) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.14) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.14) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('108') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('108') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Item MOET '108' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XPN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('XPN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Type MOET 'XPN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Patient Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van LongName MOET 'Patient Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.1"
                 priority="4002"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('FN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.1/hl7v2:FN.1"
                 priority="4000"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.1/hl7v2:FN.2"
                 priority="3999"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.1/hl7v2:FN.3"
                 priority="3998"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Own Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.1/hl7v2:FN.4"
                 priority="3997"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.1/hl7v2:FN.5"
                 priority="3996"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.2"
                 priority="3995"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.3"
                 priority="3994"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.4"
                 priority="3993"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.5"
                 priority="3992"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.6"
                 priority="3991"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.7"
                 priority="3990"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70200') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.8"
                 priority="3988"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.9"
                 priority="3986"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70448') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Context') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.9/hl7v2:CE.1"
                 priority="3984"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.9/hl7v2:CE.2"
                 priority="3983"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.9/hl7v2:CE.3"
                 priority="3982"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.9/hl7v2:CE.4"
                 priority="3980"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.9/hl7v2:CE.5"
                 priority="3979"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.9/hl7v2:CE.6"
                 priority="3978"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.10"
                 priority="3976"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.10/hl7v2:DR.1"
                 priority="3974"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.1"
                 priority="3972"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.2"
                 priority="3971"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.10/hl7v2:DR.2"
                 priority="3969"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.1"
                 priority="3967"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.2"
                 priority="3966"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.11"
                 priority="3964"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70444') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Assembly Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.12"
                 priority="3962"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.12/hl7v2:TS.1"
                 priority="3960"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.12/hl7v2:TS.2"
                 priority="3959"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.13"
                 priority="3957"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.13/hl7v2:TS.1"
                 priority="3955"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.13/hl7v2:TS.2"
                 priority="3954"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.14"
                 priority="3952"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Professional Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.6"
                 priority="3951"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.12) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.12) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.13) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.13) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.14) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.14) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('109') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('109') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Item MOET '109' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XPN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('XPN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Type MOET 'XPN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Mother''s Maiden Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Mother''s Maiden Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van LongName MOET 'Mother''s Maiden Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.1"
                 priority="3949"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('FN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.1/hl7v2:FN.1"
                 priority="3947"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.1/hl7v2:FN.2"
                 priority="3946"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.1/hl7v2:FN.3"
                 priority="3945"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Own Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.1/hl7v2:FN.4"
                 priority="3944"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.1/hl7v2:FN.5"
                 priority="3943"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.2"
                 priority="3942"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.3"
                 priority="3941"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.4"
                 priority="3940"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.5"
                 priority="3939"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.6"
                 priority="3938"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.7"
                 priority="3937"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70200') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.8"
                 priority="3935"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.9"
                 priority="3933"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70448') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Context') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.9/hl7v2:CE.1"
                 priority="3931"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.9/hl7v2:CE.2"
                 priority="3930"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.9/hl7v2:CE.3"
                 priority="3929"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.9/hl7v2:CE.4"
                 priority="3927"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.9/hl7v2:CE.5"
                 priority="3926"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.9/hl7v2:CE.6"
                 priority="3925"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.10"
                 priority="3923"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.10/hl7v2:DR.1"
                 priority="3921"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.1"
                 priority="3919"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.2"
                 priority="3918"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.10/hl7v2:DR.2"
                 priority="3916"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.1"
                 priority="3914"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.2"
                 priority="3913"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.11"
                 priority="3911"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70444') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Assembly Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.12"
                 priority="3909"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.12/hl7v2:TS.1"
                 priority="3907"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.12/hl7v2:TS.2"
                 priority="3906"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.13"
                 priority="3904"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.13/hl7v2:TS.1"
                 priority="3902"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.13/hl7v2:TS.2"
                 priority="3901"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.14"
                 priority="3899"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Professional Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.7"
                 priority="3898"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('110') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('110') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Item MOET '110' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Date/Time of Birth') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Date/Time of Birth') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van LongName MOET 'Date/Time of Birth' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.7/hl7v2:TS.1"
                 priority="3896"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.7/hl7v2:TS.2"
                 priority="3895"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.8"
                 priority="3893"
                 mode="M14">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.3.1937.777.10.11.1-2013-02-10T000000.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.3.1937.777.10.11.1-2013-02-10T000000.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.84-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(IS_datatype): de elementwaarde MOET een zijn van '2.16.840.1.113883.3.1937.777.10.11.1 Administrative Sex (2013-02-10T00:00:00)'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('111') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('111') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Item MOET '111' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70001') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70001') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Table MOET 'HL70001' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Administrative Sex') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Administrative Sex') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van LongName MOET 'Administrative Sex' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.9"
                 priority="3891"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.12) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.12) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.13) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.13) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.14) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.14) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('112') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('112') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Item MOET '112' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XPN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('XPN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Type MOET 'XPN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Alias') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Patient Alias') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van LongName MOET 'Patient Alias' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.1"
                 priority="3889"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('FN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.1/hl7v2:FN.1"
                 priority="3887"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.1/hl7v2:FN.2"
                 priority="3886"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.1/hl7v2:FN.3"
                 priority="3885"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Own Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.1/hl7v2:FN.4"
                 priority="3884"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.1/hl7v2:FN.5"
                 priority="3883"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.2"
                 priority="3882"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.3"
                 priority="3881"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.4"
                 priority="3880"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.5"
                 priority="3879"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.6"
                 priority="3878"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.7"
                 priority="3877"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70200') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.8"
                 priority="3875"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.9"
                 priority="3873"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70448') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Context') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.9/hl7v2:CE.1"
                 priority="3871"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.9/hl7v2:CE.2"
                 priority="3870"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.9/hl7v2:CE.3"
                 priority="3869"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.9/hl7v2:CE.4"
                 priority="3867"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.9/hl7v2:CE.5"
                 priority="3866"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.9/hl7v2:CE.6"
                 priority="3865"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.10"
                 priority="3863"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.10/hl7v2:DR.1"
                 priority="3861"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.1"
                 priority="3859"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.2"
                 priority="3858"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.10/hl7v2:DR.2"
                 priority="3856"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.1"
                 priority="3854"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.2"
                 priority="3853"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.11"
                 priority="3851"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70444') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Assembly Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.12"
                 priority="3849"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.12/hl7v2:TS.1"
                 priority="3847"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.12/hl7v2:TS.2"
                 priority="3846"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.13"
                 priority="3844"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.13/hl7v2:TS.1"
                 priority="3842"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.13/hl7v2:TS.2"
                 priority="3841"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.14"
                 priority="3839"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Professional Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.10"
                 priority="3838"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('113') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('113') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Item MOET '113' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70005') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70005') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Table MOET 'HL70005' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Race') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Race') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van LongName MOET 'Race' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.10/hl7v2:CE.1"
                 priority="3836"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.10/hl7v2:CE.2"
                 priority="3835"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.10/hl7v2:CE.3"
                 priority="3834"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.10/hl7v2:CE.4"
                 priority="3832"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.10/hl7v2:CE.5"
                 priority="3831"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.10/hl7v2:CE.6"
                 priority="3830"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.11"
                 priority="3828"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.12) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.12) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.13) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.13) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.14) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.14) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('114') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('114') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Item MOET '114' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XAD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('XAD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Type MOET 'XAD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Address') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Patient Address') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van LongName MOET 'Patient Address' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.1"
                 priority="3826"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): element hl7v2:SAD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): element hl7v2:SAD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): element hl7v2:SAD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SAD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('SAD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'SAD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Street Address') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Street Address') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'Street Address' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.1/hl7v2:SAD.1"
                 priority="3824"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Street or Mailing Address') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Street or Mailing Address') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): de waarde van LongName MOET 'Street or Mailing Address' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.1/hl7v2:SAD.2"
                 priority="3823"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Street Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Street Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): de waarde van LongName MOET 'Street Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.1/hl7v2:SAD.3"
                 priority="3822"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Dwelling Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Dwelling Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): de waarde van LongName MOET 'Dwelling Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.2"
                 priority="3821"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Other Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Other Designation') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'Other Designation' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.3"
                 priority="3820"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('City') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('City') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'City' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.4"
                 priority="3819"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('State or Province') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('State or Province') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'State or Province' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.5"
                 priority="3818"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Zip or Postal Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Zip or Postal Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'Zip or Postal Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.6"
                 priority="3817"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70399') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70399') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Table MOET 'HL70399' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Country') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Country') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'Country' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.7"
                 priority="3815"
                 mode="M14">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.25.11.409 Adrestype HL7v2 NL (DYNAMISCH)'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70190') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70190') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Table MOET 'HL70190' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Address Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Address Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'Address Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.8"
                 priority="3813"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Other Geographic Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Other Geographic Designation') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'Other Geographic Designation' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.9"
                 priority="3812"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70289') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70289') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Table MOET 'HL70289' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('County/Parish Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('County/Parish Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'County/Parish Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.10"
                 priority="3811"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70288') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70288') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Table MOET 'HL70288' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Census Tract') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Census Tract') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'Census Tract' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.11"
                 priority="3810"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Address Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Address Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'Address Representation Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.12"
                 priority="3808"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Address Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Address Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'Address Validity Range' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.12/hl7v2:DR.1"
                 priority="3806"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.1"
                 priority="3804"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.2"
                 priority="3803"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.12/hl7v2:DR.2"
                 priority="3801"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.1"
                 priority="3799"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.2"
                 priority="3798"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.13"
                 priority="3796"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.13/hl7v2:TS.1"
                 priority="3794"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.13/hl7v2:TS.2"
                 priority="3793"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.14"
                 priority="3791"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.14/hl7v2:TS.1"
                 priority="3789"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.14/hl7v2:TS.2"
                 priority="3788"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.12"
                 priority="3786"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('115') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('115') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Item MOET '115' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70289') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70289') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Table MOET 'HL70289' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('County Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('County Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van LongName MOET 'County Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.13"
                 priority="3785"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.12) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('116') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('116') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Item MOET '116' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('XTN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Type MOET 'XTN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Phone Number - Home') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Phone Number - Home') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van LongName MOET 'Phone Number - Home' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.1"
                 priority="3783"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Telephone Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Telephone Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.2"
                 priority="3782"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70201') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Table MOET 'HL70201' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Telecommunication Use Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Use Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.3"
                 priority="3780"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70202') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Table MOET 'HL70202' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Equipment Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.4"
                 priority="3778"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Email Address') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Email Address' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.5"
                 priority="3777"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Country Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Country Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.6"
                 priority="3776"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Area/City Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Area/City Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.7"
                 priority="3775"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Local Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Local Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.8"
                 priority="3774"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Extension') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Extension' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.9"
                 priority="3773"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Any Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Any Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.10"
                 priority="3772"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Extension Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Extension Prefix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.11"
                 priority="3771"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Speed Dial Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Speed Dial Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.12"
                 priority="3770"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Unformatted Telephone number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Unformatted Telephone number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.14"
                 priority="3769"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.12) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('117') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('117') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Item MOET '117' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('XTN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Type MOET 'XTN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Phone Number - Business') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Phone Number - Business') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van LongName MOET 'Phone Number - Business' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.1"
                 priority="3767"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Telephone Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Telephone Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.2"
                 priority="3766"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70201') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Table MOET 'HL70201' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Telecommunication Use Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Use Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.3"
                 priority="3764"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70202') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Table MOET 'HL70202' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Equipment Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.4"
                 priority="3762"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Email Address') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Email Address' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.5"
                 priority="3761"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Country Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Country Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.6"
                 priority="3760"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Area/City Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Area/City Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.7"
                 priority="3759"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Local Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Local Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.8"
                 priority="3758"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Extension') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Extension' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.9"
                 priority="3757"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Any Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Any Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.10"
                 priority="3756"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Extension Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Extension Prefix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.11"
                 priority="3755"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Speed Dial Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Speed Dial Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.12"
                 priority="3754"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Unformatted Telephone number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Unformatted Telephone number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.15"
                 priority="3753"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('118') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('118') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Item MOET '118' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70296') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70296') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Table MOET 'HL70296' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Primary Language') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Primary Language') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van LongName MOET 'Primary Language' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.15/hl7v2:CE.1"
                 priority="3751"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.15/hl7v2:CE.2"
                 priority="3750"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.15/hl7v2:CE.3"
                 priority="3749"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.15/hl7v2:CE.4"
                 priority="3747"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.15/hl7v2:CE.5"
                 priority="3746"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.15/hl7v2:CE.6"
                 priority="3745"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.16"
                 priority="3743"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('119') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('119') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Item MOET '119' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70002') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70002') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Table MOET 'HL70002' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Marital Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Marital Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van LongName MOET 'Marital Status' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.16/hl7v2:CE.1"
                 priority="3741"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.16/hl7v2:CE.2"
                 priority="3740"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.16/hl7v2:CE.3"
                 priority="3739"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.16/hl7v2:CE.4"
                 priority="3737"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.16/hl7v2:CE.5"
                 priority="3736"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.16/hl7v2:CE.6"
                 priority="3735"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.17"
                 priority="3733"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('120') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('120') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Item MOET '120' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70006') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70006') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Table MOET 'HL70006' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Religion') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Religion') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van LongName MOET 'Religion' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.17/hl7v2:CE.1"
                 priority="3731"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.17/hl7v2:CE.2"
                 priority="3730"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.17/hl7v2:CE.3"
                 priority="3729"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.17/hl7v2:CE.4"
                 priority="3727"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.17/hl7v2:CE.5"
                 priority="3726"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.17/hl7v2:CE.6"
                 priority="3725"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.18"
                 priority="3723"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('121') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('121') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Item MOET '121' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CX') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CX') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Type MOET 'CX' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Account Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Patient Account Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van LongName MOET 'Patient Account Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.1"
                 priority="3721"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.2"
                 priority="3720"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Check Digit' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.3"
                 priority="3719"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.4"
                 priority="3717"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.4/hl7v2:HD.1"
                 priority="3715"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.4/hl7v2:HD.2"
                 priority="3714"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.4/hl7v2:HD.3"
                 priority="3713"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.5"
                 priority="3711"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.6"
                 priority="3709"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.6/hl7v2:HD.1"
                 priority="3707"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.6/hl7v2:HD.2"
                 priority="3706"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.6/hl7v2:HD.3"
                 priority="3705"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.7"
                 priority="3703"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.8"
                 priority="3702"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9"
                 priority="3701"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="3699"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="3698"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="3697"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="3695"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="3694"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="3693"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="3691"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="3690"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="3689"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10"
                 priority="3688"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="3686"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="3685"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="3684"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="3682"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="3681"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="3680"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="3678"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="3677"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="3676"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.19"
                 priority="3675"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('122') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('122') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Item MOET '122' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('SSN Number - Patient') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('SSN Number - Patient') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van LongName MOET 'SSN Number - Patient' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.20"
                 priority="3674"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DLN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DLN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DLN_datatype): element hl7v2:DLN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DLN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DLN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DLN_datatype): element hl7v2:DLN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DLN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DLN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DLN_datatype): element hl7v2:DLN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('123') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('123') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Item MOET '123' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DLN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DLN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Type MOET 'DLN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Driver''s License Number - Patient') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Driver''s License Number - Patient') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van LongName MOET 'Driver''s License Number - Patient' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.20/hl7v2:DLN.1"
                 priority="3672"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DLN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('License Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('License Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DLN_datatype): de waarde van LongName MOET 'License Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.20/hl7v2:DLN.2"
                 priority="3671"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DLN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70333') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70333') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DLN_datatype): de waarde van Table MOET 'HL70333' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Issuing State, Province, Country') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Issuing State, Province, Country') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DLN_datatype): de waarde van LongName MOET 'Issuing State, Province, Country' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.20/hl7v2:DLN.3"
                 priority="3670"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DLN_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DLN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.21"
                 priority="3669"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('124') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('124') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Item MOET '124' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CX') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CX') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Type MOET 'CX' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Mother''s Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Mother''s Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van LongName MOET 'Mother''s Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.1"
                 priority="3667"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.2"
                 priority="3666"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Check Digit' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.3"
                 priority="3665"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.4"
                 priority="3663"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.4/hl7v2:HD.1"
                 priority="3661"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.4/hl7v2:HD.2"
                 priority="3660"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.4/hl7v2:HD.3"
                 priority="3659"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.5"
                 priority="3657"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.6"
                 priority="3655"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.6/hl7v2:HD.1"
                 priority="3653"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.6/hl7v2:HD.2"
                 priority="3652"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.6/hl7v2:HD.3"
                 priority="3651"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.7"
                 priority="3649"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.8"
                 priority="3648"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9"
                 priority="3647"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="3645"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="3644"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="3643"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="3641"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="3640"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="3639"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="3637"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="3636"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="3635"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10"
                 priority="3634"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="3632"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="3631"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="3630"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="3628"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="3627"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="3626"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="3624"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="3623"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="3622"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.22"
                 priority="3621"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('125') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('125') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Item MOET '125' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70189') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70189') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Table MOET 'HL70189' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Ethnic Group') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Ethnic Group') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van LongName MOET 'Ethnic Group' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.22/hl7v2:CE.1"
                 priority="3619"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.22/hl7v2:CE.2"
                 priority="3618"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.22/hl7v2:CE.3"
                 priority="3617"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.22/hl7v2:CE.4"
                 priority="3615"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.22/hl7v2:CE.5"
                 priority="3614"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.22/hl7v2:CE.6"
                 priority="3613"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.23"
                 priority="3611"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('126') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('126') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Item MOET '126' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Birth Place') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Birth Place') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van LongName MOET 'Birth Place' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.24"
                 priority="3610"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('127') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('127') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Item MOET '127' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70136') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Multiple Birth Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Multiple Birth Indicator') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van LongName MOET 'Multiple Birth Indicator' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.25"
                 priority="3608"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('128') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('128') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Item MOET '128' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Birth Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Birth Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van LongName MOET 'Birth Order' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.26"
                 priority="3607"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('129') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('129') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Item MOET '129' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70171') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70171') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Table MOET 'HL70171' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Citizenship') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Citizenship') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van LongName MOET 'Citizenship' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.26/hl7v2:CE.1"
                 priority="3605"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.26/hl7v2:CE.2"
                 priority="3604"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.26/hl7v2:CE.3"
                 priority="3603"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.26/hl7v2:CE.4"
                 priority="3601"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.26/hl7v2:CE.5"
                 priority="3600"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.26/hl7v2:CE.6"
                 priority="3599"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.27"
                 priority="3597"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('130') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('130') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Item MOET '130' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70172') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70172') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Table MOET 'HL70172' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Veterans Military Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Veterans Military Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van LongName MOET 'Veterans Military Status' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.27/hl7v2:CE.1"
                 priority="3595"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.27/hl7v2:CE.2"
                 priority="3594"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.27/hl7v2:CE.3"
                 priority="3593"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.27/hl7v2:CE.4"
                 priority="3591"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.27/hl7v2:CE.5"
                 priority="3590"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.27/hl7v2:CE.6"
                 priority="3589"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.28"
                 priority="3587"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('739') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('739') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Item MOET '739' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70212') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70212') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Table MOET 'HL70212' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Nationality') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Nationality') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van LongName MOET 'Nationality' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.28/hl7v2:CE.1"
                 priority="3585"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.28/hl7v2:CE.2"
                 priority="3584"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.28/hl7v2:CE.3"
                 priority="3583"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.28/hl7v2:CE.4"
                 priority="3581"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.28/hl7v2:CE.5"
                 priority="3580"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.28/hl7v2:CE.6"
                 priority="3579"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.29"
                 priority="3577"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('740') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('740') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Item MOET '740' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Death Date and Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Patient Death Date and Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van LongName MOET 'Patient Death Date and Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.29/hl7v2:TS.1"
                 priority="3575"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.29/hl7v2:TS.2"
                 priority="3574"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.30"
                 priority="3572"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('741') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('741') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Item MOET '741' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70136') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Death Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Patient Death Indicator') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van LongName MOET 'Patient Death Indicator' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.31"
                 priority="3570"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1535') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1535') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Item MOET '1535' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70136') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identity Unknown Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identity Unknown Indicator') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van LongName MOET 'Identity Unknown Indicator' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.32"
                 priority="3568"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1536') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1536') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Item MOET '1536' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70445') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70445') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Table MOET 'HL70445' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identity Reliability Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identity Reliability Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van LongName MOET 'Identity Reliability Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.33"
                 priority="3567"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1537') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1537') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Item MOET '1537' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Last Update Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Last Update Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van LongName MOET 'Last Update Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.33/hl7v2:TS.1"
                 priority="3565"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.33/hl7v2:TS.2"
                 priority="3564"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.34"
                 priority="3562"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1538') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1538') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Item MOET '1538' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Last Update Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Last Update Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van LongName MOET 'Last Update Facility' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.34/hl7v2:HD.1"
                 priority="3560"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.34/hl7v2:HD.2"
                 priority="3559"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.34/hl7v2:HD.3"
                 priority="3558"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.35"
                 priority="3556"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1539') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1539') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Item MOET '1539' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70446') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70446') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Table MOET 'HL70446' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Species Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Species Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van LongName MOET 'Species Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.35/hl7v2:CE.1"
                 priority="3554"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.35/hl7v2:CE.2"
                 priority="3553"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.35/hl7v2:CE.3"
                 priority="3552"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.35/hl7v2:CE.4"
                 priority="3550"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.35/hl7v2:CE.5"
                 priority="3549"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.35/hl7v2:CE.6"
                 priority="3548"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.36"
                 priority="3546"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1540') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1540') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Item MOET '1540' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70447') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70447') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Table MOET 'HL70447' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Breed Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Breed Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van LongName MOET 'Breed Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.36/hl7v2:CE.1"
                 priority="3544"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.36/hl7v2:CE.2"
                 priority="3543"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.36/hl7v2:CE.3"
                 priority="3542"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.36/hl7v2:CE.4"
                 priority="3540"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.36/hl7v2:CE.5"
                 priority="3539"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.36/hl7v2:CE.6"
                 priority="3538"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.37"
                 priority="3536"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1541') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1541') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Item MOET '1541' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Strain') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Strain') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van LongName MOET 'Strain' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.38"
                 priority="3535"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1542') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1542') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Item MOET '1542' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70429') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70429') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Table MOET 'HL70429' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Production Class Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Production Class Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van LongName MOET 'Production Class Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.38/hl7v2:CE.1"
                 priority="3533"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.38/hl7v2:CE.2"
                 priority="3532"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.38/hl7v2:CE.3"
                 priority="3531"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.38/hl7v2:CE.4"
                 priority="3529"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.38/hl7v2:CE.5"
                 priority="3528"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.38/hl7v2:CE.6"
                 priority="3527"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.39"
                 priority="3525"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1840') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1840') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Item MOET '1840' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70171') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70171') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van Table MOET 'HL70171' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Tribal Citizenship') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Tribal Citizenship') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van LongName MOET 'Tribal Citizenship' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.1"
                 priority="3523"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.2"
                 priority="3522"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.3"
                 priority="3521"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.4"
                 priority="3519"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.5"
                 priority="3518"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.6"
                 priority="3517"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.7"
                 priority="3515"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.8"
                 priority="3514"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.9"
                 priority="3513"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE d20e23218-false-d982145e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER"
                 priority="3512"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab): element hl7v2:ORC is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab): element hl7v2:ORC komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORL_O22.OBSERVATION_REQUEST) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7v2:ORL_O22.OBSERVATION_REQUEST) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab): element hl7v2:ORL_O22.OBSERVATION_REQUEST komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC"
                 priority="3511"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.1) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC.1) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): element hl7v2:ORC.1 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): element hl7v2:ORC.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): element hl7v2:ORC.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): element hl7v2:ORC.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): element hl7v2:ORC.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): element hl7v2:ORC.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): element hl7v2:ORC.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): element hl7v2:ORC.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): element hl7v2:ORC.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.13) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC.13) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): element hl7v2:ORC.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.15) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC.15) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): element hl7v2:ORC.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.16) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC.16) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): element hl7v2:ORC.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.17) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC.17) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): element hl7v2:ORC.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.18) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC.18) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): element hl7v2:ORC.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.20) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC.20) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): element hl7v2:ORC.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.25) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC.25) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): element hl7v2:ORC.25 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.26) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC.26) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): element hl7v2:ORC.26 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.27) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC.27) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): element hl7v2:ORC.27 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.28) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC.28) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): element hl7v2:ORC.28 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.29) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC.29) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): element hl7v2:ORC.29 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.30) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC.30) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): element hl7v2:ORC.30 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.1"
                 priority="3510"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('215') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('215') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van Item MOET '215' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70119') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70119') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van Table MOET 'HL70119' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Order Control') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Order Control') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Order Control' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.2"
                 priority="3508"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('216') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('216') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van Item MOET '216' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Order Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Placer Order Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Placer Order Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.2/hl7v2:EI.1"
                 priority="3506"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.2/hl7v2:EI.2"
                 priority="3505"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.2/hl7v2:EI.3"
                 priority="3504"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.2/hl7v2:EI.4"
                 priority="3503"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.3"
                 priority="3501"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('217') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('217') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van Item MOET '217' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler Order Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Filler Order Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Filler Order Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.3/hl7v2:EI.1"
                 priority="3499"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.3/hl7v2:EI.2"
                 priority="3498"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.3/hl7v2:EI.3"
                 priority="3497"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.3/hl7v2:EI.4"
                 priority="3496"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.4"
                 priority="3494"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('218') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('218') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van Item MOET '218' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Group Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Placer Group Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Placer Group Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.4/hl7v2:EI.1"
                 priority="3492"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.4/hl7v2:EI.2"
                 priority="3491"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.4/hl7v2:EI.3"
                 priority="3490"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.4/hl7v2:EI.4"
                 priority="3489"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.5"
                 priority="3487"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('219') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('219') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van Item MOET '219' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70038') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70038') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van Table MOET 'HL70038' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Order Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Order Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Order Status' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.6"
                 priority="3485"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('220') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('220') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van Item MOET '220' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70121') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70121') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van Table MOET 'HL70121' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Response Flag') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Response Flag') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Response Flag' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.7"
                 priority="3483"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.12) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.12) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('221') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('221') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van Item MOET '221' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TQ') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TQ') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'TQ' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity/Timing') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Quantity/Timing') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Quantity/Timing' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1"
                 priority="3481"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CQ') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van Type MOET 'CQ' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Quantity') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van LongName MOET 'Quantity' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/hl7v2:CQ.1"
                 priority="3479"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Quantity') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van LongName MOET 'Quantity' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/hl7v2:CQ.2"
                 priority="3478"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van LongName MOET 'Units' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="3476"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="3475"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="3474"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="3472"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="3471"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="3470"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.2"
                 priority="3468"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RI.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:RI.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RI_datatype): element hl7v2:RI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RI.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:RI.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RI_datatype): element hl7v2:RI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('RI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('RI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van Type MOET 'RI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Interval') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Interval') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van LongName MOET 'Interval' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.2/hl7v2:RI.1"
                 priority="3466"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70335') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70335') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RI_datatype): de waarde van Table MOET 'HL70335' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Repeat Pattern') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Repeat Pattern') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RI_datatype): de waarde van LongName MOET 'Repeat Pattern' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.2/hl7v2:RI.2"
                 priority="3465"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Explicit Time Interval') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Explicit Time Interval') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RI_datatype): de waarde van LongName MOET 'Explicit Time Interval' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.3"
                 priority="3464"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Duration') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Duration') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van LongName MOET 'Duration' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.4"
                 priority="3463"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van LongName MOET 'Start Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.4/hl7v2:TS.1"
                 priority="3461"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.4/hl7v2:TS.2"
                 priority="3460"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.5"
                 priority="3458"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van LongName MOET 'End Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.5/hl7v2:TS.1"
                 priority="3456"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.5/hl7v2:TS.2"
                 priority="3455"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.6"
                 priority="3453"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Priority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Priority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van LongName MOET 'Priority' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.7"
                 priority="3452"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Condition') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Condition') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van LongName MOET 'Condition' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.8"
                 priority="3451"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TX') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TX') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van Type MOET 'TX' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.8/hl7v2:escape"
                 priority="3450"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.65-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TX_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.8/hl7v2:escape/hl7v2:escape"
                 priority="3449"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.8/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="3448"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.9"
                 priority="3447"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70472') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70472') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van Table MOET 'HL70472' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Conjunction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Conjunction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van LongName MOET 'Conjunction' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10"
                 priority="3445"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('OSD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('OSD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van Type MOET 'OSD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Order Sequencing') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Order Sequencing') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van LongName MOET 'Order Sequencing' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.1"
                 priority="3443"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70524') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70524') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Table MOET 'HL70524' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Sequence/Results Flag') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Sequence/Results Flag') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van LongName MOET 'Sequence/Results Flag' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.2"
                 priority="3441"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Order Number: Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Placer Order Number: Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van LongName MOET 'Placer Order Number: Entity Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.3"
                 priority="3440"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Order Number: Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Placer Order Number: Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van LongName MOET 'Placer Order Number: Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.4"
                 priority="3439"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler Order Number: Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Filler Order Number: Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van LongName MOET 'Filler Order Number: Entity Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.5"
                 priority="3438"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler Order Number: Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Filler Order Number: Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van LongName MOET 'Filler Order Number: Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.6"
                 priority="3437"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Sequence Condition Value') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Sequence Condition Value') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van LongName MOET 'Sequence Condition Value' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.7"
                 priority="3436"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Maximum Number of Repeats') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Maximum Number of Repeats') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van LongName MOET 'Maximum Number of Repeats' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.8"
                 priority="3435"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Order Number: Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Placer Order Number: Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van LongName MOET 'Placer Order Number: Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.9"
                 priority="3434"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Order Number: Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Placer Order Number: Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van LongName MOET 'Placer Order Number: Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.10"
                 priority="3432"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler Order Number: Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Filler Order Number: Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van LongName MOET 'Filler Order Number: Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.11"
                 priority="3431"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler Order Number: Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Filler Order Number: Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van LongName MOET 'Filler Order Number: Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.11"
                 priority="3429"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Occurrence Duration') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Occurrence Duration') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van LongName MOET 'Occurrence Duration' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.11/hl7v2:CE.1"
                 priority="3427"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.11/hl7v2:CE.2"
                 priority="3426"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.11/hl7v2:CE.3"
                 priority="3425"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.11/hl7v2:CE.4"
                 priority="3423"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.11/hl7v2:CE.5"
                 priority="3422"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.11/hl7v2:CE.6"
                 priority="3421"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.12"
                 priority="3419"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Total Occurrences') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Total Occurrences') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van LongName MOET 'Total Occurrences' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.8"
                 priority="3418"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EIP.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EIP.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): element hl7v2:EIP.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EIP.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EIP.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): element hl7v2:EIP.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('222') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('222') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van Item MOET '222' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EIP') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('EIP') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'EIP' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Parent') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Parent') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Parent' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.1"
                 priority="3416"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Assigned Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Placer Assigned Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): de waarde van LongName MOET 'Placer Assigned Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.1/hl7v2:EI.1"
                 priority="3414"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.1/hl7v2:EI.2"
                 priority="3413"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.1/hl7v2:EI.3"
                 priority="3412"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.1/hl7v2:EI.4"
                 priority="3411"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.2"
                 priority="3409"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler Assigned Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Filler Assigned Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): de waarde van LongName MOET 'Filler Assigned Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.2/hl7v2:EI.1"
                 priority="3407"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.2/hl7v2:EI.2"
                 priority="3406"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.2/hl7v2:EI.3"
                 priority="3405"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.2/hl7v2:EI.4"
                 priority="3404"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.9"
                 priority="3402"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('223') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('223') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van Item MOET '223' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Date/Time of Transaction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Date/Time of Transaction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Date/Time of Transaction' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.9/hl7v2:TS.1"
                 priority="3400"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.9/hl7v2:TS.2"
                 priority="3399"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10"
                 priority="3397"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.12) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.13) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.14) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.15) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.16) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.17) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.18) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.19) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.20) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.21) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.22) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.23) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('224') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('224') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van Item MOET '224' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('XCN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entered By') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Entered By') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Entered By' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.1"
                 priority="3395"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.2"
                 priority="3394"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('FN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="3392"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="3391"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="3390"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Own Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="3389"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="3388"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.3"
                 priority="3387"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.4"
                 priority="3386"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.5"
                 priority="3385"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.6"
                 priority="3384"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.7"
                 priority="3383"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.8"
                 priority="3382"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.9"
                 priority="3381"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="3379"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="3378"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="3377"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.10"
                 priority="3375"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70200') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.11"
                 priority="3373"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.12"
                 priority="3372"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.13"
                 priority="3370"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.14"
                 priority="3368"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="3366"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="3365"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="3364"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.15"
                 priority="3362"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.16"
                 priority="3360"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70448') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Context') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="3358"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="3357"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="3356"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="3354"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="3353"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="3352"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.17"
                 priority="3350"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="3348"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="3346"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="3345"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="3343"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="3341"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="3340"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.18"
                 priority="3338"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70444') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Assembly Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.19"
                 priority="3336"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="3334"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="3333"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.20"
                 priority="3331"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="3329"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="3328"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.21"
                 priority="3326"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Professional Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22"
                 priority="3325"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="3323"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="3322"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="3321"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="3319"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="3318"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="3317"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="3315"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="3314"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="3313"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23"
                 priority="3312"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="3310"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="3309"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="3308"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="3306"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="3305"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="3304"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="3302"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="3301"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="3300"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11"
                 priority="3299"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.12) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.13) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.14) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.15) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.16) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.17) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.18) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.19) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.20) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.21) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.22) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.23) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('225') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('225') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van Item MOET '225' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('XCN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Verified By') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Verified By') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Verified By' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.1"
                 priority="3297"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.2"
                 priority="3296"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('FN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="3294"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="3293"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="3292"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Own Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="3291"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="3290"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.3"
                 priority="3289"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.4"
                 priority="3288"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.5"
                 priority="3287"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.6"
                 priority="3286"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.7"
                 priority="3285"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.8"
                 priority="3284"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.9"
                 priority="3283"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="3281"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="3280"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="3279"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.10"
                 priority="3277"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70200') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.11"
                 priority="3275"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.12"
                 priority="3274"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.13"
                 priority="3272"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.14"
                 priority="3270"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="3268"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="3267"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="3266"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.15"
                 priority="3264"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.16"
                 priority="3262"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70448') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Context') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="3260"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="3259"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="3258"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="3256"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="3255"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="3254"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.17"
                 priority="3252"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="3250"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="3248"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="3247"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="3245"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="3243"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="3242"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.18"
                 priority="3240"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70444') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Assembly Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.19"
                 priority="3238"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="3236"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="3235"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.20"
                 priority="3233"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="3231"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="3230"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.21"
                 priority="3228"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Professional Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22"
                 priority="3227"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="3225"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="3224"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="3223"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="3221"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="3220"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="3219"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="3217"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="3216"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="3215"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23"
                 priority="3214"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="3212"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="3211"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="3210"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="3208"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="3207"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="3206"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="3204"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="3203"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="3202"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12"
                 priority="3201"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.12) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.13) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.14) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.15) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.16) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.17) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.18) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.19) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.20) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.21) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.22) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.23) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('226') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('226') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van Item MOET '226' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('XCN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Ordering Provider') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Ordering Provider') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Ordering Provider' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.1"
                 priority="3199"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.2"
                 priority="3198"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('FN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="3196"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="3195"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="3194"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Own Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="3193"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="3192"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.3"
                 priority="3191"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.4"
                 priority="3190"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.5"
                 priority="3189"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.6"
                 priority="3188"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.7"
                 priority="3187"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.8"
                 priority="3186"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.9"
                 priority="3185"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="3183"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="3182"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="3181"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.10"
                 priority="3179"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70200') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.11"
                 priority="3177"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.12"
                 priority="3176"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.13"
                 priority="3174"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.14"
                 priority="3172"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="3170"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="3169"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="3168"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.15"
                 priority="3166"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.16"
                 priority="3164"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70448') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Context') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="3162"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="3161"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="3160"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="3158"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="3157"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="3156"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.17"
                 priority="3154"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="3152"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="3150"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="3149"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="3147"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="3145"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="3144"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.18"
                 priority="3142"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70444') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Assembly Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.19"
                 priority="3140"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="3138"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="3137"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.20"
                 priority="3135"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="3133"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="3132"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.21"
                 priority="3130"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Professional Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22"
                 priority="3129"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="3127"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="3126"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="3125"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="3123"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="3122"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="3121"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="3119"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="3118"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="3117"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23"
                 priority="3116"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="3114"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="3113"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="3112"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="3110"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="3109"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="3108"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="3106"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="3105"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="3104"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.13"
                 priority="3103"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('227') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('227') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van Item MOET '227' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('PL') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('PL') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'PL' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Enterer''s Location') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Enterer''s Location') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Enterer''s Location' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.1"
                 priority="3101"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70302') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Table MOET 'HL70302' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Point of Care') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Point of Care' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.2"
                 priority="3100"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70303') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Table MOET 'HL70303' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Room') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Room' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.3"
                 priority="3099"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70304') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Table MOET 'HL70304' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Bed') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Bed' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.4"
                 priority="3098"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Facility' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.4/hl7v2:HD.1"
                 priority="3096"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.4/hl7v2:HD.2"
                 priority="3095"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.4/hl7v2:HD.3"
                 priority="3094"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.5"
                 priority="3092"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70306') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Table MOET 'HL70306' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Location Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Location Status' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.6"
                 priority="3091"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70305') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Table MOET 'HL70305' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Person Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Person Location Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Person Location Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.7"
                 priority="3090"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70307') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Table MOET 'HL70307' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Building') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Building' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.8"
                 priority="3089"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70308') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Table MOET 'HL70308' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Floor') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Floor' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.9"
                 priority="3088"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Location Description') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Location Description') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Location Description' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.10"
                 priority="3087"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Comprehensive Location Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Comprehensive Location Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Comprehensive Location Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.10/hl7v2:EI.1"
                 priority="3085"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.10/hl7v2:EI.2"
                 priority="3084"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.10/hl7v2:EI.3"
                 priority="3083"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.10/hl7v2:EI.4"
                 priority="3082"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.11"
                 priority="3080"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority for Location') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority for Location') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van LongName MOET 'Assigning Authority for Location' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.11/hl7v2:HD.1"
                 priority="3078"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.11/hl7v2:HD.2"
                 priority="3077"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.11/hl7v2:HD.3"
                 priority="3076"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.14"
                 priority="3074"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.12) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('228') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('228') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van Item MOET '228' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('XTN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'XTN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Call Back Phone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Call Back Phone Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Call Back Phone Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.1"
                 priority="3072"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Telephone Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Telephone Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.2"
                 priority="3071"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70201') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Table MOET 'HL70201' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Telecommunication Use Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Use Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.3"
                 priority="3069"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70202') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Table MOET 'HL70202' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Equipment Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.4"
                 priority="3067"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Email Address') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Email Address' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.5"
                 priority="3066"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Country Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Country Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.6"
                 priority="3065"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Area/City Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Area/City Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.7"
                 priority="3064"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Local Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Local Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.8"
                 priority="3063"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Extension') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Extension' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.9"
                 priority="3062"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Any Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Any Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.10"
                 priority="3061"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Extension Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Extension Prefix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.11"
                 priority="3060"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Speed Dial Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Speed Dial Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.12"
                 priority="3059"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Unformatted Telephone number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Unformatted Telephone number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.15"
                 priority="3058"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('229') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('229') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van Item MOET '229' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Order Effective Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Order Effective Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Order Effective Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.15/hl7v2:TS.1"
                 priority="3056"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.15/hl7v2:TS.2"
                 priority="3055"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.16"
                 priority="3053"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('230') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('230') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van Item MOET '230' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Order Control Code Reason') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Order Control Code Reason') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Order Control Code Reason' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.16/hl7v2:CE.1"
                 priority="3051"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.16/hl7v2:CE.2"
                 priority="3050"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.16/hl7v2:CE.3"
                 priority="3049"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.16/hl7v2:CE.4"
                 priority="3047"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.16/hl7v2:CE.5"
                 priority="3046"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.16/hl7v2:CE.6"
                 priority="3045"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.17"
                 priority="3043"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('231') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('231') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van Item MOET '231' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entering Organization') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Entering Organization') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Entering Organization' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.17/hl7v2:CE.1"
                 priority="3041"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.17/hl7v2:CE.2"
                 priority="3040"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.17/hl7v2:CE.3"
                 priority="3039"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.17/hl7v2:CE.4"
                 priority="3037"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.17/hl7v2:CE.5"
                 priority="3036"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.17/hl7v2:CE.6"
                 priority="3035"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.18"
                 priority="3033"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('232') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('232') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van Item MOET '232' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entering Device') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Entering Device') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Entering Device' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.18/hl7v2:CE.1"
                 priority="3031"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.18/hl7v2:CE.2"
                 priority="3030"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.18/hl7v2:CE.3"
                 priority="3029"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.18/hl7v2:CE.4"
                 priority="3027"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.18/hl7v2:CE.5"
                 priority="3026"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.18/hl7v2:CE.6"
                 priority="3025"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19"
                 priority="3023"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.12) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.13) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.14) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.15) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.16) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.17) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.18) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.19) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.20) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.21) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.22) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.23) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('233') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('233') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van Item MOET '233' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('XCN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Action By') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Action By') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Action By' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.1"
                 priority="3021"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.2"
                 priority="3020"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('FN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="3018"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="3017"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="3016"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Own Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="3015"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="3014"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.3"
                 priority="3013"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.4"
                 priority="3012"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.5"
                 priority="3011"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.6"
                 priority="3010"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.7"
                 priority="3009"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.8"
                 priority="3008"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.9"
                 priority="3007"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="3005"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="3004"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="3003"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.10"
                 priority="3001"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70200') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.11"
                 priority="2999"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.12"
                 priority="2998"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.13"
                 priority="2996"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.14"
                 priority="2994"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="2992"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="2991"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="2990"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.15"
                 priority="2988"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.16"
                 priority="2986"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70448') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Context') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="2984"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="2983"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="2982"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="2980"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="2979"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="2978"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.17"
                 priority="2976"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="2974"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="2972"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="2971"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="2969"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="2967"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="2966"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.18"
                 priority="2964"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70444') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Assembly Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.19"
                 priority="2962"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="2960"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="2959"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.20"
                 priority="2957"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="2955"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="2954"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.21"
                 priority="2952"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Professional Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22"
                 priority="2951"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="2949"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="2948"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="2947"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="2945"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="2944"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="2943"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="2941"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="2940"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="2939"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23"
                 priority="2938"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="2936"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="2935"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="2934"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="2932"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="2931"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="2930"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="2928"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="2927"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="2926"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.20"
                 priority="2925"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1310') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1310') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1310' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70339') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70339') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van Table MOET 'HL70339' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Advanced Beneficiary Notice Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Advanced Beneficiary Notice Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Advanced Beneficiary Notice Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.20/hl7v2:CE.1"
                 priority="2923"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.20/hl7v2:CE.2"
                 priority="2922"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.20/hl7v2:CE.3"
                 priority="2921"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.20/hl7v2:CE.4"
                 priority="2919"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.20/hl7v2:CE.5"
                 priority="2918"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.20/hl7v2:CE.6"
                 priority="2917"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.21"
                 priority="2915"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1311') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1311') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1311' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XON') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('XON') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'XON' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Ordering Facility Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Ordering Facility Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Ordering Facility Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.1"
                 priority="2913"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organization Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Organization Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van LongName MOET 'Organization Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.2"
                 priority="2912"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70204') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70204') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Table MOET 'HL70204' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organization Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Organization Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van LongName MOET 'Organization Name Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.3"
                 priority="2911"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.4"
                 priority="2910"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van LongName MOET 'Check Digit' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.5"
                 priority="2909"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.6"
                 priority="2907"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.6/hl7v2:HD.1"
                 priority="2905"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.6/hl7v2:HD.2"
                 priority="2904"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.6/hl7v2:HD.3"
                 priority="2903"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.7"
                 priority="2901"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.8"
                 priority="2899"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.8/hl7v2:HD.1"
                 priority="2897"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.8/hl7v2:HD.2"
                 priority="2896"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.8/hl7v2:HD.3"
                 priority="2895"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.9"
                 priority="2893"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.10"
                 priority="2891"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organization Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Organization Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van LongName MOET 'Organization Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.22"
                 priority="2890"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.12) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.12) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.13) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.13) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.14) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.14) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1312') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1312') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1312' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XAD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('XAD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'XAD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Ordering Facility Address') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Ordering Facility Address') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Ordering Facility Address' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.1"
                 priority="2888"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): element hl7v2:SAD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): element hl7v2:SAD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): element hl7v2:SAD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SAD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('SAD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'SAD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Street Address') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Street Address') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'Street Address' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.1/hl7v2:SAD.1"
                 priority="2886"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Street or Mailing Address') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Street or Mailing Address') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): de waarde van LongName MOET 'Street or Mailing Address' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.1/hl7v2:SAD.2"
                 priority="2885"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Street Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Street Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): de waarde van LongName MOET 'Street Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.1/hl7v2:SAD.3"
                 priority="2884"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Dwelling Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Dwelling Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): de waarde van LongName MOET 'Dwelling Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.2"
                 priority="2883"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Other Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Other Designation') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'Other Designation' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.3"
                 priority="2882"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('City') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('City') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'City' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.4"
                 priority="2881"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('State or Province') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('State or Province') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'State or Province' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.5"
                 priority="2880"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Zip or Postal Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Zip or Postal Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'Zip or Postal Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.6"
                 priority="2879"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70399') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70399') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Table MOET 'HL70399' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Country') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Country') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'Country' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.7"
                 priority="2877"
                 mode="M14">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.25.11.409 Adrestype HL7v2 NL (DYNAMISCH)'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70190') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70190') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Table MOET 'HL70190' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Address Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Address Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'Address Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.8"
                 priority="2875"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Other Geographic Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Other Geographic Designation') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'Other Geographic Designation' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.9"
                 priority="2874"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70289') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70289') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Table MOET 'HL70289' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('County/Parish Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('County/Parish Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'County/Parish Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.10"
                 priority="2873"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70288') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70288') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Table MOET 'HL70288' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Census Tract') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Census Tract') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'Census Tract' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.11"
                 priority="2872"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Address Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Address Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'Address Representation Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.12"
                 priority="2870"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Address Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Address Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'Address Validity Range' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.12/hl7v2:DR.1"
                 priority="2868"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.1"
                 priority="2866"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.2"
                 priority="2865"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.12/hl7v2:DR.2"
                 priority="2863"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.1"
                 priority="2861"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.2"
                 priority="2860"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.13"
                 priority="2858"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.13/hl7v2:TS.1"
                 priority="2856"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.13/hl7v2:TS.2"
                 priority="2855"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.14"
                 priority="2853"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.14/hl7v2:TS.1"
                 priority="2851"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.14/hl7v2:TS.2"
                 priority="2850"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.23"
                 priority="2848"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.12) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1313') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1313') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1313' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('XTN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'XTN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Ordering Facility Phone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Ordering Facility Phone Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Ordering Facility Phone Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.1"
                 priority="2846"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Telephone Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Telephone Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.2"
                 priority="2845"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70201') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Table MOET 'HL70201' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Telecommunication Use Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Use Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.3"
                 priority="2843"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70202') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Table MOET 'HL70202' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Equipment Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.4"
                 priority="2841"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Email Address') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Email Address' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.5"
                 priority="2840"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Country Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Country Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.6"
                 priority="2839"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Area/City Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Area/City Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.7"
                 priority="2838"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Local Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Local Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.8"
                 priority="2837"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Extension') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Extension' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.9"
                 priority="2836"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Any Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Any Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.10"
                 priority="2835"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Extension Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Extension Prefix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.11"
                 priority="2834"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Speed Dial Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Speed Dial Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.12"
                 priority="2833"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Unformatted Telephone number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Unformatted Telephone number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.24"
                 priority="2832"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.12) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.12) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.13) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.13) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.14) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.14) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1314') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1314') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1314' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XAD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('XAD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'XAD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Ordering Provider Address') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Ordering Provider Address') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Ordering Provider Address' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.1"
                 priority="2830"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): element hl7v2:SAD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): element hl7v2:SAD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): element hl7v2:SAD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SAD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('SAD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'SAD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Street Address') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Street Address') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'Street Address' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.1/hl7v2:SAD.1"
                 priority="2828"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Street or Mailing Address') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Street or Mailing Address') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): de waarde van LongName MOET 'Street or Mailing Address' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.1/hl7v2:SAD.2"
                 priority="2827"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Street Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Street Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): de waarde van LongName MOET 'Street Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.1/hl7v2:SAD.3"
                 priority="2826"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Dwelling Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Dwelling Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): de waarde van LongName MOET 'Dwelling Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.2"
                 priority="2825"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Other Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Other Designation') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'Other Designation' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.3"
                 priority="2824"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('City') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('City') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'City' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.4"
                 priority="2823"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('State or Province') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('State or Province') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'State or Province' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.5"
                 priority="2822"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Zip or Postal Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Zip or Postal Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'Zip or Postal Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.6"
                 priority="2821"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70399') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70399') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Table MOET 'HL70399' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Country') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Country') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'Country' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.7"
                 priority="2819"
                 mode="M14">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.25.11.409 Adrestype HL7v2 NL (DYNAMISCH)'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70190') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70190') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Table MOET 'HL70190' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Address Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Address Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'Address Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.8"
                 priority="2817"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Other Geographic Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Other Geographic Designation') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'Other Geographic Designation' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.9"
                 priority="2816"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70289') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70289') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Table MOET 'HL70289' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('County/Parish Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('County/Parish Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'County/Parish Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.10"
                 priority="2815"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70288') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70288') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Table MOET 'HL70288' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Census Tract') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Census Tract') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'Census Tract' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.11"
                 priority="2814"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Address Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Address Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'Address Representation Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.12"
                 priority="2812"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Address Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Address Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'Address Validity Range' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.12/hl7v2:DR.1"
                 priority="2810"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.1"
                 priority="2808"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.2"
                 priority="2807"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.12/hl7v2:DR.2"
                 priority="2805"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.1"
                 priority="2803"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.2"
                 priority="2802"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.13"
                 priority="2800"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.13/hl7v2:TS.1"
                 priority="2798"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.13/hl7v2:TS.2"
                 priority="2797"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.14"
                 priority="2795"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.14/hl7v2:TS.1"
                 priority="2793"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.14/hl7v2:TS.2"
                 priority="2792"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.25"
                 priority="2790"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1473') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1473') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1473' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Order Status Modifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Order Status Modifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Order Status Modifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.1"
                 priority="2788"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.2"
                 priority="2787"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.3"
                 priority="2786"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.4"
                 priority="2784"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.5"
                 priority="2783"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.6"
                 priority="2782"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.7"
                 priority="2780"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.8"
                 priority="2779"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.9"
                 priority="2778"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.26"
                 priority="2777"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1641') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1641') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1641' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70552') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70552') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van Table MOET 'HL70552' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Advanced Beneficiary Notice Override Reason') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Advanced Beneficiary Notice Override Reason') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Advanced Beneficiary Notice Override Reason' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.1"
                 priority="2775"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.2"
                 priority="2774"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.3"
                 priority="2773"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.4"
                 priority="2771"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.5"
                 priority="2770"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.6"
                 priority="2769"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.7"
                 priority="2767"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.8"
                 priority="2766"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.9"
                 priority="2765"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.27"
                 priority="2764"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1642') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1642') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1642' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler''s Expected Availability Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Filler''s Expected Availability Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Filler''s Expected Availability Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.27/hl7v2:TS.1"
                 priority="2762"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.27/hl7v2:TS.2"
                 priority="2761"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.28"
                 priority="2759"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('615') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('615') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van Item MOET '615' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70177') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70177') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van Table MOET 'HL70177' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Confidentiality Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Confidentiality Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Confidentiality Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.1"
                 priority="2757"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.2"
                 priority="2756"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.3"
                 priority="2755"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.4"
                 priority="2753"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.5"
                 priority="2752"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.6"
                 priority="2751"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.7"
                 priority="2749"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.8"
                 priority="2748"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.9"
                 priority="2747"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.29"
                 priority="2746"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1643') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1643') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1643' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70482') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70482') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van Table MOET 'HL70482' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Order Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Order Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Order Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.1"
                 priority="2744"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.2"
                 priority="2743"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.3"
                 priority="2742"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.4"
                 priority="2740"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.5"
                 priority="2739"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.6"
                 priority="2738"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.7"
                 priority="2736"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.8"
                 priority="2735"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.9"
                 priority="2734"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.30"
                 priority="2733"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): element hl7v2:CNE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): element hl7v2:CNE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): element hl7v2:CNE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): element hl7v2:CNE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): element hl7v2:CNE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): element hl7v2:CNE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): element hl7v2:CNE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): element hl7v2:CNE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): element hl7v2:CNE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1644') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1644') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1644' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CNE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CNE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'CNE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70483') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70483') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van Table MOET 'HL70483' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Enterer Authorization Mode') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Enterer Authorization Mode') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Enterer Authorization Mode' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.1"
                 priority="2731"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.2"
                 priority="2730"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.3"
                 priority="2729"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.4"
                 priority="2727"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.5"
                 priority="2726"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.6"
                 priority="2725"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.7"
                 priority="2723"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.8"
                 priority="2722"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.9"
                 priority="2721"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE d20e23222-false-d999524e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING"
                 priority="2720"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ1) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab): element hl7v2:TQ1 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab): element hl7v2:TQ1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1"
                 priority="2719"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ1.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.142-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment): element hl7v2:TQ1.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ1.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.142-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment): element hl7v2:TQ1.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ1.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.142-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment): element hl7v2:TQ1.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ1.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.142-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment): element hl7v2:TQ1.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ1.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.142-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment): element hl7v2:TQ1.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ1.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.142-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment): element hl7v2:TQ1.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ1.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.142-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment): element hl7v2:TQ1.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.12) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ1.12) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.142-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment): element hl7v2:TQ1.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.13) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ1.13) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.142-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment): element hl7v2:TQ1.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.14) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ1.14) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.142-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment): element hl7v2:TQ1.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.1"
                 priority="2718"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1627') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1627') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.142-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment): de waarde van Item MOET '1627' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('SI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.142-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment): de waarde van Type MOET 'SI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Set ID - TQ1') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Set ID - TQ1') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.142-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment): de waarde van LongName MOET 'Set ID - TQ1' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.2"
                 priority="2717"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1628') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1628') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.142-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment): de waarde van Item MOET '1628' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CQ') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.142-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment): de waarde van Type MOET 'CQ' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Quantity') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.142-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment): de waarde van LongName MOET 'Quantity' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.2/hl7v2:CQ.1"
                 priority="2715"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Quantity') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van LongName MOET 'Quantity' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.2/hl7v2:CQ.2"
                 priority="2714"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van LongName MOET 'Units' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.2/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="2712"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.2/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="2711"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.2/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="2710"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.2/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="2708"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.2/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="2707"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.2/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="2706"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.3"
                 priority="2704"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:RPT.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): element hl7v2:RPT.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:RPT.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): element hl7v2:RPT.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:RPT.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): element hl7v2:RPT.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:RPT.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): element hl7v2:RPT.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:RPT.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): element hl7v2:RPT.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:RPT.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): element hl7v2:RPT.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:RPT.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): element hl7v2:RPT.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:RPT.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): element hl7v2:RPT.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:RPT.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): element hl7v2:RPT.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:RPT.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): element hl7v2:RPT.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:RPT.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): element hl7v2:RPT.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1629') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1629') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.142-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment): de waarde van Item MOET '1629' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('RPT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('RPT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.142-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment): de waarde van Type MOET 'RPT' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70335') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70335') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.142-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment): de waarde van Table MOET 'HL70335' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Repeat Pattern') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Repeat Pattern') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.142-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment): de waarde van LongName MOET 'Repeat Pattern' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1"
                 priority="2702"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70335') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70335') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van Table MOET 'HL70335' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Repeat Pattern Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Repeat Pattern Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van LongName MOET 'Repeat Pattern Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.1"
                 priority="2700"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.2"
                 priority="2699"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.3"
                 priority="2698"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.4"
                 priority="2696"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.5"
                 priority="2695"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.6"
                 priority="2694"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.7"
                 priority="2692"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.8"
                 priority="2691"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.9"
                 priority="2690"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.2"
                 priority="2689"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70527') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70527') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van Table MOET 'HL70527' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Calendar Alignment') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Calendar Alignment') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van LongName MOET 'Calendar Alignment' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.3"
                 priority="2687"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Phase Range Begin Value') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Phase Range Begin Value') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van LongName MOET 'Phase Range Begin Value' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.4"
                 priority="2686"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Phase Range End Value') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Phase Range End Value') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van LongName MOET 'Phase Range End Value' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.5"
                 priority="2685"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Period Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Period Quantity') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van LongName MOET 'Period Quantity' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.6"
                 priority="2684"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Period Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Period Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van LongName MOET 'Period Units' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.7"
                 priority="2683"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70136') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Institution Specified Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Institution Specified Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van LongName MOET 'Institution Specified Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.8"
                 priority="2681"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70528') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70528') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van Table MOET 'HL70528' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Event') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Event') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van LongName MOET 'Event' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.9"
                 priority="2679"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Event Offset Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Event Offset Quantity') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van LongName MOET 'Event Offset Quantity' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.10"
                 priority="2678"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Event Offset Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Event Offset Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van LongName MOET 'Event Offset Units' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.11"
                 priority="2677"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('GTS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('GTS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van Type MOET 'GTS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('General Timing Specification') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('General Timing Specification') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van LongName MOET 'General Timing Specification' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.4"
                 priority="2676"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1630') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1630') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.142-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment): de waarde van Item MOET '1630' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.142-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment): de waarde van Type MOET 'TM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Explicit Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Explicit Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.142-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment): de waarde van LongName MOET 'Explicit Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.5"
                 priority="2675"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1631') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1631') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.142-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment): de waarde van Item MOET '1631' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CQ') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.142-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment): de waarde van Type MOET 'CQ' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Relative Time and Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Relative Time and Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.142-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment): de waarde van LongName MOET 'Relative Time and Units' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.5/hl7v2:CQ.1"
                 priority="2673"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Quantity') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van LongName MOET 'Quantity' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.5/hl7v2:CQ.2"
                 priority="2672"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van LongName MOET 'Units' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.5/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="2670"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.5/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="2669"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.5/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="2668"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.5/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="2666"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.5/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="2665"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.5/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="2664"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.6"
                 priority="2662"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1632') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1632') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.142-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment): de waarde van Item MOET '1632' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CQ') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.142-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment): de waarde van Type MOET 'CQ' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Service Duration') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Service Duration') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.142-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment): de waarde van LongName MOET 'Service Duration' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.6/hl7v2:CQ.1"
                 priority="2660"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Quantity') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van LongName MOET 'Quantity' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.6/hl7v2:CQ.2"
                 priority="2659"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van LongName MOET 'Units' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.6/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="2657"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.6/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="2656"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.6/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="2655"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.6/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="2653"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.6/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="2652"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.6/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="2651"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.7"
                 priority="2649"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1633') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1633') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.142-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment): de waarde van Item MOET '1633' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.142-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Start date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Start date/time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.142-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment): de waarde van LongName MOET 'Start date/time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.7/hl7v2:TS.1"
                 priority="2647"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.7/hl7v2:TS.2"
                 priority="2646"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.8"
                 priority="2644"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1634') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1634') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.142-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment): de waarde van Item MOET '1634' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.142-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('End date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('End date/time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.142-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment): de waarde van LongName MOET 'End date/time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.8/hl7v2:TS.1"
                 priority="2642"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.8/hl7v2:TS.2"
                 priority="2641"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.9"
                 priority="2639"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1635') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1635') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.142-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment): de waarde van Item MOET '1635' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.142-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70485') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70485') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.142-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment): de waarde van Table MOET 'HL70485' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Priority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Priority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.142-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment): de waarde van LongName MOET 'Priority' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.1"
                 priority="2637"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.2"
                 priority="2636"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.3"
                 priority="2635"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.4"
                 priority="2633"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.5"
                 priority="2632"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.6"
                 priority="2631"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.7"
                 priority="2629"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.8"
                 priority="2628"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.9"
                 priority="2627"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.10"
                 priority="2626"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1636') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1636') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.142-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment): de waarde van Item MOET '1636' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TX') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TX') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.142-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment): de waarde van Type MOET 'TX' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Condition text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Condition text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.142-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment): de waarde van LongName MOET 'Condition text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.10/hl7v2:escape"
                 priority="2625"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.65-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TX_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.10/hl7v2:escape/hl7v2:escape"
                 priority="2624"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.10/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="2623"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.11"
                 priority="2622"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1637') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1637') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.142-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment): de waarde van Item MOET '1637' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TX') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TX') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.142-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment): de waarde van Type MOET 'TX' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text instruction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text instruction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.142-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment): de waarde van LongName MOET 'Text instruction' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.11/hl7v2:escape"
                 priority="2621"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.65-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TX_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.11/hl7v2:escape/hl7v2:escape"
                 priority="2620"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.11/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="2619"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.12"
                 priority="2618"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1638') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1638') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.142-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment): de waarde van Item MOET '1638' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.142-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70427') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70427') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.142-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment): de waarde van Table MOET 'HL70427' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Conjunction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Conjunction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.142-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment): de waarde van LongName MOET 'Conjunction' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.13"
                 priority="2616"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1639') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1639') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.142-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment): de waarde van Item MOET '1639' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CQ') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.142-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment): de waarde van Type MOET 'CQ' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Occurrence duration') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Occurrence duration') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.142-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment): de waarde van LongName MOET 'Occurrence duration' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.13/hl7v2:CQ.1"
                 priority="2614"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Quantity') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van LongName MOET 'Quantity' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.13/hl7v2:CQ.2"
                 priority="2613"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van LongName MOET 'Units' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.13/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="2611"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.13/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="2610"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.13/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="2609"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.13/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="2607"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.13/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="2606"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.13/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="2605"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.14"
                 priority="2603"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1640') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1640') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.142-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment): de waarde van Item MOET '1640' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.142-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Total occurrence''s') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Total occurrence''s') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.142-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment): de waarde van LongName MOET 'Total occurrence''s' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ2"
                 priority="2602"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ2.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ2.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): element hl7v2:TQ2.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ2.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ2.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): element hl7v2:TQ2.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ2.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ2.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): element hl7v2:TQ2.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ2.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ2.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): element hl7v2:TQ2.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ2.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ2.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): element hl7v2:TQ2.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ2.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ2.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): element hl7v2:TQ2.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ2.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ2.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): element hl7v2:TQ2.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ2/hl7v2:TQ2.1"
                 priority="2601"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1648') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1648') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van Item MOET '1648' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('SI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van Type MOET 'SI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Set ID - TQ2') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Set ID - TQ2') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van LongName MOET 'Set ID - TQ2' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ2/hl7v2:TQ2.2"
                 priority="2600"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1649') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1649') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van Item MOET '1649' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70503') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70503') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van Table MOET 'HL70503' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Sequence/Results Flag') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Sequence/Results Flag') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van LongName MOET 'Sequence/Results Flag' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ2/hl7v2:TQ2.3"
                 priority="2598"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1650') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1650') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van Item MOET '1650' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Related Placer Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Related Placer Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van LongName MOET 'Related Placer Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ2/hl7v2:TQ2.3/hl7v2:EI.1"
                 priority="2596"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ2/hl7v2:TQ2.3/hl7v2:EI.2"
                 priority="2595"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ2/hl7v2:TQ2.3/hl7v2:EI.3"
                 priority="2594"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ2/hl7v2:TQ2.3/hl7v2:EI.4"
                 priority="2593"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ2/hl7v2:TQ2.4"
                 priority="2591"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1651') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1651') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van Item MOET '1651' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Related Filler Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Related Filler Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van LongName MOET 'Related Filler Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ2/hl7v2:TQ2.4/hl7v2:EI.1"
                 priority="2589"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ2/hl7v2:TQ2.4/hl7v2:EI.2"
                 priority="2588"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ2/hl7v2:TQ2.4/hl7v2:EI.3"
                 priority="2587"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ2/hl7v2:TQ2.4/hl7v2:EI.4"
                 priority="2586"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ2/hl7v2:TQ2.5"
                 priority="2584"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1652') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1652') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van Item MOET '1652' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Related Placer Group Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Related Placer Group Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van LongName MOET 'Related Placer Group Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ2/hl7v2:TQ2.5/hl7v2:EI.1"
                 priority="2582"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ2/hl7v2:TQ2.5/hl7v2:EI.2"
                 priority="2581"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ2/hl7v2:TQ2.5/hl7v2:EI.3"
                 priority="2580"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ2/hl7v2:TQ2.5/hl7v2:EI.4"
                 priority="2579"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ2/hl7v2:TQ2.6"
                 priority="2577"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1653') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1653') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van Item MOET '1653' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70504') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70504') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van Table MOET 'HL70504' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Sequence Condition Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Sequence Condition Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van LongName MOET 'Sequence Condition Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ2/hl7v2:TQ2.7"
                 priority="2575"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1654') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1654') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van Item MOET '1654' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70505') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70505') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van Table MOET 'HL70505' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Cyclic Entry/Exit Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Cyclic Entry/Exit Indicator') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van LongName MOET 'Cyclic Entry/Exit Indicator' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ2/hl7v2:TQ2.8"
                 priority="2573"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1655') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1655') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van Item MOET '1655' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CQ') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van Type MOET 'CQ' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Sequence Condition Time Interval') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Sequence Condition Time Interval') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van LongName MOET 'Sequence Condition Time Interval' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ2/hl7v2:TQ2.8/hl7v2:CQ.1"
                 priority="2571"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Quantity') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van LongName MOET 'Quantity' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ2/hl7v2:TQ2.8/hl7v2:CQ.2"
                 priority="2570"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van LongName MOET 'Units' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ2/hl7v2:TQ2.8/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="2568"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ2/hl7v2:TQ2.8/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="2567"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ2/hl7v2:TQ2.8/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="2566"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ2/hl7v2:TQ2.8/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="2564"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ2/hl7v2:TQ2.8/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="2563"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ2/hl7v2:TQ2.8/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="2562"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ2/hl7v2:TQ2.9"
                 priority="2560"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1656') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1656') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van Item MOET '1656' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Cyclic Group Maximum Number of Repeats') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Cyclic Group Maximum Number of Repeats') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van LongName MOET 'Cyclic Group Maximum Number of Repeats' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ2/hl7v2:TQ2.10"
                 priority="2559"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1657') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1657') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van Item MOET '1657' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70506') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70506') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van Table MOET 'HL70506' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Special Service Request Relationship') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Special Service Request Relationship') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van LongName MOET 'Special Service Request Relationship' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE d20e23229-false-d1003120e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST"
                 priority="2557"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab): element hl7v2:OBR is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab): element hl7v2:OBR komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR"
                 priority="2556"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.4) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.4) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.4 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.12) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.12) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.13) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.13) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.14) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.14) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.15) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.15) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.18) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.18) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.19) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.19) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.20) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.20) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.21) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.21) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.22) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.22) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.23) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.23) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.24) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.24) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.24 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.25) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.25) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.25 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.26) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.26) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.26 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.29) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.29) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.29 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.30) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.30) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.30 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.32) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.32) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.32 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.36) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.36) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.36 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.37) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.37) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.37 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.40) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.40) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.40 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.41) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.41) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.41 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.42) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.42) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.42 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.44) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.44) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.44 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.48) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.48) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.48 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.49) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.49) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.49 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.1"
                 priority="2555"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('237') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('237') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '237' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('SI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'SI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Set ID - OBR') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Set ID - OBR') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Set ID - OBR' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.2"
                 priority="2554"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('216') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('216') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '216' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Order Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Placer Order Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Placer Order Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.2/hl7v2:EI.1"
                 priority="2552"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.2/hl7v2:EI.2"
                 priority="2551"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.2/hl7v2:EI.3"
                 priority="2550"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.2/hl7v2:EI.4"
                 priority="2549"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.3"
                 priority="2547"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('217') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('217') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '217' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler Order Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Filler Order Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Filler Order Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.3/hl7v2:EI.1"
                 priority="2545"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.3/hl7v2:EI.2"
                 priority="2544"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.3/hl7v2:EI.3"
                 priority="2543"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.3/hl7v2:EI.4"
                 priority="2542"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.4"
                 priority="2540"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('238') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('238') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '238' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal Service Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal Service Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Universal Service Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.4/hl7v2:CE.1"
                 priority="2538"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.4/hl7v2:CE.2"
                 priority="2537"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.4/hl7v2:CE.3"
                 priority="2536"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.4/hl7v2:CE.4"
                 priority="2534"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.4/hl7v2:CE.5"
                 priority="2533"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.4/hl7v2:CE.6"
                 priority="2532"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.5"
                 priority="2530"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('239') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('239') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '239' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Priority _ OBR') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Priority _ OBR') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Priority _ OBR' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.6"
                 priority="2528"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('240') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('240') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '240' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Requested Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Requested Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Requested Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.6/hl7v2:TS.1"
                 priority="2526"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.6/hl7v2:TS.2"
                 priority="2525"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.7"
                 priority="2523"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('241') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('241') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '241' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Observation Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Observation Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.7/hl7v2:TS.1"
                 priority="2521"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.7/hl7v2:TS.2"
                 priority="2520"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.8"
                 priority="2518"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('242') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('242') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '242' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Observation End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Observation End Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.8/hl7v2:TS.1"
                 priority="2516"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.8/hl7v2:TS.2"
                 priority="2515"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.9"
                 priority="2513"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('243') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('243') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '243' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CQ') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'CQ' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Collection Volume') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Collection Volume') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Collection Volume' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.9/hl7v2:CQ.1"
                 priority="2511"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Quantity') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van LongName MOET 'Quantity' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.9/hl7v2:CQ.2"
                 priority="2510"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van LongName MOET 'Units' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.9/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="2508"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.9/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="2507"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.9/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="2506"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.9/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="2504"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.9/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="2503"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.9/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="2502"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10"
                 priority="2500"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.12) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.13) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.14) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.15) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.16) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.17) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.18) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.19) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.20) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.21) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.22) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.23) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('244') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('244') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '244' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('XCN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Collector Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Collector Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Collector Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.1"
                 priority="2498"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.2"
                 priority="2497"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('FN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="2495"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="2494"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="2493"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Own Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="2492"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="2491"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.3"
                 priority="2490"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.4"
                 priority="2489"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.5"
                 priority="2488"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.6"
                 priority="2487"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.7"
                 priority="2486"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.8"
                 priority="2485"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.9"
                 priority="2484"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="2482"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="2481"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="2480"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.10"
                 priority="2478"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70200') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.11"
                 priority="2476"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.12"
                 priority="2475"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.13"
                 priority="2473"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.14"
                 priority="2471"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="2469"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="2468"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="2467"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.15"
                 priority="2465"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.16"
                 priority="2463"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70448') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Context') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="2461"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="2460"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="2459"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="2457"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="2456"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="2455"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.17"
                 priority="2453"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="2451"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="2449"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="2448"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="2446"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="2444"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="2443"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.18"
                 priority="2441"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70444') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Assembly Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.19"
                 priority="2439"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="2437"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="2436"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.20"
                 priority="2434"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="2432"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="2431"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.21"
                 priority="2429"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Professional Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22"
                 priority="2428"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="2426"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="2425"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="2424"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="2422"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="2421"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="2420"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="2418"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="2417"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="2416"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23"
                 priority="2415"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="2413"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="2412"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="2411"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="2409"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="2408"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="2407"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="2405"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="2404"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="2403"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.11"
                 priority="2402"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('245') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('245') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '245' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70065') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70065') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Table MOET 'HL70065' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Action Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Specimen Action Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Specimen Action Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.12"
                 priority="2400"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('246') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('246') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '246' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Danger Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Danger Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Danger Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.12/hl7v2:CE.1"
                 priority="2398"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.12/hl7v2:CE.2"
                 priority="2397"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.12/hl7v2:CE.3"
                 priority="2396"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.12/hl7v2:CE.4"
                 priority="2394"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.12/hl7v2:CE.5"
                 priority="2393"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.12/hl7v2:CE.6"
                 priority="2392"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.13"
                 priority="2390"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('247') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('247') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '247' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Relevant Clinical Information') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Relevant Clinical Information') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Relevant Clinical Information' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.14"
                 priority="2389"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('248') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('248') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '248' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Received Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Specimen Received Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Specimen Received Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.14/hl7v2:TS.1"
                 priority="2387"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.14/hl7v2:TS.2"
                 priority="2386"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15"
                 priority="2384"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): element hl7v2:SPS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): element hl7v2:SPS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPS.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): element hl7v2:SPS.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPS.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): element hl7v2:SPS.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPS.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): element hl7v2:SPS.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPS.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): element hl7v2:SPS.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPS.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): element hl7v2:SPS.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('249') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('249') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '249' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SPS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('SPS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'SPS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Source') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Specimen Source') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Specimen Source' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1"
                 priority="2382"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Source Name or Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Specimen Source Name or Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van LongName MOET 'Specimen Source Name or Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.1"
                 priority="2380"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.2"
                 priority="2379"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.3"
                 priority="2378"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.4"
                 priority="2376"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.5"
                 priority="2375"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.6"
                 priority="2374"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.7"
                 priority="2372"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.8"
                 priority="2371"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.9"
                 priority="2370"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2"
                 priority="2369"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70371') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70371') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van Table MOET 'HL70371' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Additives') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Additives') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van LongName MOET 'Additives' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.1"
                 priority="2367"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.2"
                 priority="2366"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.3"
                 priority="2365"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.4"
                 priority="2363"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.5"
                 priority="2362"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.6"
                 priority="2361"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.7"
                 priority="2359"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.8"
                 priority="2358"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.9"
                 priority="2357"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.3"
                 priority="2356"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TX') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TX') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van Type MOET 'TX' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Collection Method') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Specimen Collection Method') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van LongName MOET 'Specimen Collection Method' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.3/hl7v2:escape"
                 priority="2355"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.65-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TX_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.3/hl7v2:escape/hl7v2:escape"
                 priority="2354"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.3/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="2353"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4"
                 priority="2352"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70163') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70163') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van Table MOET 'HL70163' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Body Site') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Body Site') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van LongName MOET 'Body Site' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.1"
                 priority="2350"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.2"
                 priority="2349"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.3"
                 priority="2348"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.4"
                 priority="2346"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.5"
                 priority="2345"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.6"
                 priority="2344"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.7"
                 priority="2342"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.8"
                 priority="2341"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.9"
                 priority="2340"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5"
                 priority="2339"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70495') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70495') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van Table MOET 'HL70495' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Site Modifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Site Modifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van LongName MOET 'Site Modifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.1"
                 priority="2337"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.2"
                 priority="2336"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.3"
                 priority="2335"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.4"
                 priority="2333"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.5"
                 priority="2332"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.6"
                 priority="2331"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.7"
                 priority="2329"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.8"
                 priority="2328"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.9"
                 priority="2327"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6"
                 priority="2326"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Collection Method Modifier Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Collection Method Modifier Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van LongName MOET 'Collection Method Modifier Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.1"
                 priority="2324"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.2"
                 priority="2323"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.3"
                 priority="2322"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.4"
                 priority="2320"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.5"
                 priority="2319"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.6"
                 priority="2318"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.7"
                 priority="2316"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.8"
                 priority="2315"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.9"
                 priority="2314"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7"
                 priority="2313"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70369') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70369') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van Table MOET 'HL70369' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Role') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Specimen Role') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van LongName MOET 'Specimen Role' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.1"
                 priority="2311"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.2"
                 priority="2310"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.3"
                 priority="2309"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.4"
                 priority="2307"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.5"
                 priority="2306"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.6"
                 priority="2305"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.7"
                 priority="2303"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.8"
                 priority="2302"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.9"
                 priority="2301"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16"
                 priority="2300"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.12) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.13) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.14) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.15) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.16) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.17) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.18) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.19) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.20) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.21) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.22) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.23) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('226') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('226') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '226' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('XCN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Ordering Provider') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Ordering Provider') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Ordering Provider' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.1"
                 priority="2298"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.2"
                 priority="2297"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('FN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="2295"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="2294"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="2293"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Own Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="2292"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="2291"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.3"
                 priority="2290"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.4"
                 priority="2289"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.5"
                 priority="2288"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.6"
                 priority="2287"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.7"
                 priority="2286"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.8"
                 priority="2285"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.9"
                 priority="2284"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="2282"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="2281"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="2280"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.10"
                 priority="2278"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70200') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.11"
                 priority="2276"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.12"
                 priority="2275"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.13"
                 priority="2273"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.14"
                 priority="2271"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="2269"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="2268"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="2267"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.15"
                 priority="2265"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.16"
                 priority="2263"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70448') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Context') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="2261"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="2260"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="2259"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="2257"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="2256"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="2255"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.17"
                 priority="2253"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="2251"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="2249"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="2248"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="2246"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="2244"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="2243"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.18"
                 priority="2241"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70444') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Assembly Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.19"
                 priority="2239"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="2237"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="2236"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.20"
                 priority="2234"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="2232"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="2231"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.21"
                 priority="2229"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Professional Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22"
                 priority="2228"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="2226"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="2225"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="2224"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="2222"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="2221"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="2220"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="2218"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="2217"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="2216"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23"
                 priority="2215"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="2213"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="2212"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="2211"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="2209"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="2208"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="2207"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="2205"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="2204"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="2203"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.17"
                 priority="2202"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.12) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('250') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('250') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '250' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('XTN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'XTN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Order Callback Phone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Order Callback Phone Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Order Callback Phone Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.1"
                 priority="2200"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Telephone Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Telephone Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.2"
                 priority="2199"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70201') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Table MOET 'HL70201' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Telecommunication Use Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Use Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.3"
                 priority="2197"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70202') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Table MOET 'HL70202' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Equipment Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.4"
                 priority="2195"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Email Address') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Email Address' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.5"
                 priority="2194"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Country Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Country Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.6"
                 priority="2193"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Area/City Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Area/City Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.7"
                 priority="2192"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Local Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Local Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.8"
                 priority="2191"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Extension') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Extension' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.9"
                 priority="2190"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Any Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Any Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.10"
                 priority="2189"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Extension Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Extension Prefix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.11"
                 priority="2188"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Speed Dial Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Speed Dial Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.12"
                 priority="2187"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Unformatted Telephone number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van LongName MOET 'Unformatted Telephone number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.18"
                 priority="2186"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('251') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('251') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '251' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Field 1') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Placer Field 1') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Placer Field 1' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.19"
                 priority="2185"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('252') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('252') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '252' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Field 2') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Placer Field 2') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Placer Field 2' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.20"
                 priority="2184"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('253') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('253') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '253' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler Field 1') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Filler Field 1') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Filler Field 1' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.21"
                 priority="2183"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('254') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('254') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '254' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler Field 2') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Filler Field 2') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Filler Field 2' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.22"
                 priority="2182"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('255') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('255') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '255' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Results Rpt/Status Chng - Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Results Rpt/Status Chng - Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Results Rpt/Status Chng - Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.22/hl7v2:TS.1"
                 priority="2180"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.22/hl7v2:TS.2"
                 priority="2179"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.23"
                 priority="2177"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MOC.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MOC.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.34-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MOC_datatype): element hl7v2:MOC.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MOC.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MOC.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.34-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MOC_datatype): element hl7v2:MOC.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('256') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('256') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '256' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('MOC') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('MOC') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'MOC' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Charge to Practice') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Charge to Practice') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Charge to Practice' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.1"
                 priority="2175"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MO.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MO.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MO_datatype): element hl7v2:MO.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MO.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MO.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MO_datatype): element hl7v2:MO.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('MO') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('MO') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.34-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MOC_datatype): de waarde van Type MOET 'MO' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Monetary Amount') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Monetary Amount') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.34-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MOC_datatype): de waarde van LongName MOET 'Monetary Amount' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.1/hl7v2:MO.1"
                 priority="2173"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MO_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Quantity') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MO_datatype): de waarde van LongName MOET 'Quantity' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.1/hl7v2:MO.2"
                 priority="2172"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MO_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Denomination') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Denomination') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MO_datatype): de waarde van LongName MOET 'Denomination' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.2"
                 priority="2170"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.34-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MOC_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Charge Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Charge Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.34-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MOC_datatype): de waarde van LongName MOET 'Charge Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.2/hl7v2:CE.1"
                 priority="2168"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.2/hl7v2:CE.2"
                 priority="2167"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.2/hl7v2:CE.3"
                 priority="2166"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.2/hl7v2:CE.4"
                 priority="2164"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.2/hl7v2:CE.5"
                 priority="2163"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.2/hl7v2:CE.6"
                 priority="2162"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.24"
                 priority="2160"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('257') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('257') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '257' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70074') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70074') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Table MOET 'HL70074' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Diagnostic Serv Sect ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Diagnostic Serv Sect ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Diagnostic Serv Sect ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.25"
                 priority="2158"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('258') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('258') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '258' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70123') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70123') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Table MOET 'HL70123' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Result Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Result Status' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.26"
                 priority="2156"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PRL.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PRL.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PRL_datatype): element hl7v2:PRL.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PRL.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PRL.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PRL_datatype): element hl7v2:PRL.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PRL.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PRL.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PRL_datatype): element hl7v2:PRL.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('259') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('259') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '259' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('PRL') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('PRL') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'PRL' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Parent Result') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Parent Result') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Parent Result' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.1"
                 priority="2154"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PRL_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Parent Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Parent Observation Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PRL_datatype): de waarde van LongName MOET 'Parent Observation Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.1/hl7v2:CE.1"
                 priority="2152"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.1/hl7v2:CE.2"
                 priority="2151"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.1/hl7v2:CE.3"
                 priority="2150"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.1/hl7v2:CE.4"
                 priority="2148"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.1/hl7v2:CE.5"
                 priority="2147"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.1/hl7v2:CE.6"
                 priority="2146"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.2"
                 priority="2144"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PRL_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Parent Observation Sub-identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Parent Observation Sub-identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PRL_datatype): de waarde van LongName MOET 'Parent Observation Sub-identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.3"
                 priority="2143"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TX') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TX') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PRL_datatype): de waarde van Type MOET 'TX' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Parent Observation Value Descriptor') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Parent Observation Value Descriptor') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PRL_datatype): de waarde van LongName MOET 'Parent Observation Value Descriptor' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.3/hl7v2:escape"
                 priority="2142"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.65-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TX_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.3/hl7v2:escape/hl7v2:escape"
                 priority="2141"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.3/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="2140"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27"
                 priority="2139"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.12) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.12) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('221') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('221') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '221' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TQ') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TQ') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'TQ' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity/Timing') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Quantity/Timing') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Quantity/Timing' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1"
                 priority="2137"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CQ') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van Type MOET 'CQ' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Quantity') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van LongName MOET 'Quantity' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/hl7v2:CQ.1"
                 priority="2135"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Quantity') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van LongName MOET 'Quantity' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/hl7v2:CQ.2"
                 priority="2134"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van LongName MOET 'Units' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="2132"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="2131"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="2130"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="2128"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="2127"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="2126"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.2"
                 priority="2124"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RI.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:RI.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RI_datatype): element hl7v2:RI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RI.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:RI.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RI_datatype): element hl7v2:RI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('RI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('RI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van Type MOET 'RI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Interval') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Interval') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van LongName MOET 'Interval' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.2/hl7v2:RI.1"
                 priority="2122"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70335') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70335') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RI_datatype): de waarde van Table MOET 'HL70335' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Repeat Pattern') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Repeat Pattern') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RI_datatype): de waarde van LongName MOET 'Repeat Pattern' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.2/hl7v2:RI.2"
                 priority="2121"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Explicit Time Interval') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Explicit Time Interval') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RI_datatype): de waarde van LongName MOET 'Explicit Time Interval' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.3"
                 priority="2120"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Duration') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Duration') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van LongName MOET 'Duration' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.4"
                 priority="2119"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van LongName MOET 'Start Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.4/hl7v2:TS.1"
                 priority="2117"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.4/hl7v2:TS.2"
                 priority="2116"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.5"
                 priority="2114"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van LongName MOET 'End Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.5/hl7v2:TS.1"
                 priority="2112"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.5/hl7v2:TS.2"
                 priority="2111"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.6"
                 priority="2109"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Priority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Priority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van LongName MOET 'Priority' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.7"
                 priority="2108"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Condition') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Condition') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van LongName MOET 'Condition' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.8"
                 priority="2107"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TX') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TX') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van Type MOET 'TX' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.8/hl7v2:escape"
                 priority="2106"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.65-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TX_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.8/hl7v2:escape/hl7v2:escape"
                 priority="2105"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.8/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="2104"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.9"
                 priority="2103"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70472') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70472') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van Table MOET 'HL70472' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Conjunction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Conjunction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van LongName MOET 'Conjunction' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10"
                 priority="2101"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('OSD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('OSD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van Type MOET 'OSD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Order Sequencing') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Order Sequencing') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van LongName MOET 'Order Sequencing' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.1"
                 priority="2099"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70524') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70524') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Table MOET 'HL70524' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Sequence/Results Flag') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Sequence/Results Flag') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van LongName MOET 'Sequence/Results Flag' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.2"
                 priority="2097"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Order Number: Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Placer Order Number: Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van LongName MOET 'Placer Order Number: Entity Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.3"
                 priority="2096"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Order Number: Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Placer Order Number: Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van LongName MOET 'Placer Order Number: Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.4"
                 priority="2095"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler Order Number: Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Filler Order Number: Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van LongName MOET 'Filler Order Number: Entity Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.5"
                 priority="2094"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler Order Number: Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Filler Order Number: Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van LongName MOET 'Filler Order Number: Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.6"
                 priority="2093"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Sequence Condition Value') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Sequence Condition Value') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van LongName MOET 'Sequence Condition Value' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.7"
                 priority="2092"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Maximum Number of Repeats') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Maximum Number of Repeats') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van LongName MOET 'Maximum Number of Repeats' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.8"
                 priority="2091"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Order Number: Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Placer Order Number: Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van LongName MOET 'Placer Order Number: Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.9"
                 priority="2090"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Order Number: Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Placer Order Number: Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van LongName MOET 'Placer Order Number: Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.10"
                 priority="2088"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler Order Number: Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Filler Order Number: Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van LongName MOET 'Filler Order Number: Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.11"
                 priority="2087"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler Order Number: Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Filler Order Number: Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van LongName MOET 'Filler Order Number: Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.11"
                 priority="2085"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Occurrence Duration') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Occurrence Duration') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van LongName MOET 'Occurrence Duration' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.11/hl7v2:CE.1"
                 priority="2083"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.11/hl7v2:CE.2"
                 priority="2082"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.11/hl7v2:CE.3"
                 priority="2081"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.11/hl7v2:CE.4"
                 priority="2079"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.11/hl7v2:CE.5"
                 priority="2078"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.11/hl7v2:CE.6"
                 priority="2077"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.12"
                 priority="2075"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Total Occurrences') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Total Occurrences') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van LongName MOET 'Total Occurrences' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28"
                 priority="2074"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.12) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.13) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.14) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.15) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.16) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.17) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.18) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.19) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.20) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.21) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.22) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.23) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('260') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('260') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '260' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('XCN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Result Copies To') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Result Copies To') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Result Copies To' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.1"
                 priority="2072"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.2"
                 priority="2071"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('FN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="2069"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="2068"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="2067"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Own Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="2066"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="2065"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.3"
                 priority="2064"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.4"
                 priority="2063"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.5"
                 priority="2062"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.6"
                 priority="2061"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.7"
                 priority="2060"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.8"
                 priority="2059"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.9"
                 priority="2058"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="2056"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="2055"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="2054"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.10"
                 priority="2052"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70200') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.11"
                 priority="2050"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.12"
                 priority="2049"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.13"
                 priority="2047"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.14"
                 priority="2045"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="2043"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="2042"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="2041"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.15"
                 priority="2039"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.16"
                 priority="2037"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70448') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Context') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="2035"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="2034"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="2033"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="2031"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="2030"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="2029"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.17"
                 priority="2027"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="2025"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="2023"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="2022"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="2020"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="2018"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="2017"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.18"
                 priority="2015"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70444') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name Assembly Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.19"
                 priority="2013"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="2011"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="2010"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.20"
                 priority="2008"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="2006"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="2005"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.21"
                 priority="2003"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Professional Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22"
                 priority="2002"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="2000"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="1999"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="1998"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="1996"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="1995"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="1994"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="1992"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="1991"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="1990"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23"
                 priority="1989"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="1987"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="1986"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="1985"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="1983"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="1982"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="1981"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="1979"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="1978"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="1977"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.29"
                 priority="1976"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EIP.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EIP.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): element hl7v2:EIP.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EIP.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EIP.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): element hl7v2:EIP.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('261') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('261') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '261' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EIP') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('EIP') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'EIP' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Parent') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Parent') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Parent' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.1"
                 priority="1974"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Assigned Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Placer Assigned Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): de waarde van LongName MOET 'Placer Assigned Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.1/hl7v2:EI.1"
                 priority="1972"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.1/hl7v2:EI.2"
                 priority="1971"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.1/hl7v2:EI.3"
                 priority="1970"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.1/hl7v2:EI.4"
                 priority="1969"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.2"
                 priority="1967"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler Assigned Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Filler Assigned Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): de waarde van LongName MOET 'Filler Assigned Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.2/hl7v2:EI.1"
                 priority="1965"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.2/hl7v2:EI.2"
                 priority="1964"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.2/hl7v2:EI.3"
                 priority="1963"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.2/hl7v2:EI.4"
                 priority="1962"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.30"
                 priority="1960"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('262') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('262') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '262' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70124') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70124') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Table MOET 'HL70124' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Transportation Mode') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Transportation Mode') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Transportation Mode' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.31"
                 priority="1958"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('263') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('263') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '263' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Reason for Study') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Reason for Study') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Reason for Study' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.31/hl7v2:CE.1"
                 priority="1956"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.31/hl7v2:CE.2"
                 priority="1955"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.31/hl7v2:CE.3"
                 priority="1954"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.31/hl7v2:CE.4"
                 priority="1952"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.31/hl7v2:CE.5"
                 priority="1951"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.31/hl7v2:CE.6"
                 priority="1950"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32"
                 priority="1948"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('264') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('264') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '264' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NDL') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NDL') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'NDL' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Principal Result Interpreter') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Principal Result Interpreter') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Principal Result Interpreter' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1"
                 priority="1946"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CNN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CNN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'CNN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.1"
                 priority="1944"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.2"
                 priority="1943"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.3"
                 priority="1942"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.4"
                 priority="1941"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.5"
                 priority="1940"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.6"
                 priority="1939"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.7"
                 priority="1938"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree (e.g., MD') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Degree (e.g., MD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.8"
                 priority="1937"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.9"
                 priority="1936"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority - Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority - Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Assigning Authority - Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.10"
                 priority="1935"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority - Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority - Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Assigning Authority - Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.11"
                 priority="1934"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority - Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority - Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Assigning Authority - Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.2"
                 priority="1932"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Start Date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Start Date/time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Start Date/time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.2/hl7v2:TS.1"
                 priority="1930"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.2/hl7v2:TS.2"
                 priority="1929"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.3"
                 priority="1927"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('End Date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('End Date/time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'End Date/time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.3/hl7v2:TS.1"
                 priority="1925"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.3/hl7v2:TS.2"
                 priority="1924"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.4"
                 priority="1922"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70302') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Table MOET 'HL70302' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Point of Care') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Point of Care' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.5"
                 priority="1921"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70303') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Table MOET 'HL70303' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Room') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Room' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.6"
                 priority="1920"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70304') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Table MOET 'HL70304' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Bed') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Bed' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.7"
                 priority="1919"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Facility' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.7/hl7v2:HD.1"
                 priority="1917"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.7/hl7v2:HD.2"
                 priority="1916"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.7/hl7v2:HD.3"
                 priority="1915"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.8"
                 priority="1913"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70306') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Table MOET 'HL70306' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Location Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Location Status' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.9"
                 priority="1912"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70305') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Table MOET 'HL70305' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Patient Location Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Patient Location Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.10"
                 priority="1911"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70307') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Table MOET 'HL70307' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Building') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Building' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.11"
                 priority="1910"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70308') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Table MOET 'HL70308' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Floor') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Floor' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33"
                 priority="1909"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('265') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('265') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '265' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NDL') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NDL') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'NDL' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assistant Result Interpreter') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assistant Result Interpreter') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Assistant Result Interpreter' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1"
                 priority="1907"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CNN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CNN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'CNN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.1"
                 priority="1905"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.2"
                 priority="1904"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.3"
                 priority="1903"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.4"
                 priority="1902"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.5"
                 priority="1901"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.6"
                 priority="1900"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.7"
                 priority="1899"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree (e.g., MD') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Degree (e.g., MD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.8"
                 priority="1898"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.9"
                 priority="1897"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority - Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority - Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Assigning Authority - Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.10"
                 priority="1896"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority - Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority - Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Assigning Authority - Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.11"
                 priority="1895"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority - Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority - Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Assigning Authority - Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.2"
                 priority="1893"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Start Date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Start Date/time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Start Date/time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.2/hl7v2:TS.1"
                 priority="1891"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.2/hl7v2:TS.2"
                 priority="1890"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.3"
                 priority="1888"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('End Date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('End Date/time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'End Date/time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.3/hl7v2:TS.1"
                 priority="1886"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.3/hl7v2:TS.2"
                 priority="1885"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.4"
                 priority="1883"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70302') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Table MOET 'HL70302' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Point of Care') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Point of Care' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.5"
                 priority="1882"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70303') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Table MOET 'HL70303' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Room') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Room' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.6"
                 priority="1881"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70304') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Table MOET 'HL70304' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Bed') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Bed' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.7"
                 priority="1880"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Facility' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.7/hl7v2:HD.1"
                 priority="1878"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.7/hl7v2:HD.2"
                 priority="1877"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.7/hl7v2:HD.3"
                 priority="1876"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.8"
                 priority="1874"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70306') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Table MOET 'HL70306' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Location Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Location Status' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.9"
                 priority="1873"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70305') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Table MOET 'HL70305' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Patient Location Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Patient Location Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.10"
                 priority="1872"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70307') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Table MOET 'HL70307' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Building') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Building' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.11"
                 priority="1871"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70308') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Table MOET 'HL70308' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Floor') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Floor' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34"
                 priority="1870"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('266') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('266') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '266' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NDL') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NDL') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'NDL' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Technician') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Technician') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Technician' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1"
                 priority="1868"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CNN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CNN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'CNN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.1"
                 priority="1866"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.2"
                 priority="1865"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.3"
                 priority="1864"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.4"
                 priority="1863"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.5"
                 priority="1862"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.6"
                 priority="1861"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.7"
                 priority="1860"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree (e.g., MD') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Degree (e.g., MD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.8"
                 priority="1859"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.9"
                 priority="1858"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority - Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority - Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Assigning Authority - Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.10"
                 priority="1857"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority - Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority - Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Assigning Authority - Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.11"
                 priority="1856"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority - Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority - Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Assigning Authority - Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.2"
                 priority="1854"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Start Date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Start Date/time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Start Date/time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.2/hl7v2:TS.1"
                 priority="1852"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.2/hl7v2:TS.2"
                 priority="1851"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.3"
                 priority="1849"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('End Date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('End Date/time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'End Date/time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.3/hl7v2:TS.1"
                 priority="1847"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.3/hl7v2:TS.2"
                 priority="1846"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.4"
                 priority="1844"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70302') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Table MOET 'HL70302' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Point of Care') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Point of Care' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.5"
                 priority="1843"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70303') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Table MOET 'HL70303' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Room') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Room' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.6"
                 priority="1842"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70304') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Table MOET 'HL70304' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Bed') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Bed' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.7"
                 priority="1841"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Facility' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.7/hl7v2:HD.1"
                 priority="1839"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.7/hl7v2:HD.2"
                 priority="1838"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.7/hl7v2:HD.3"
                 priority="1837"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.8"
                 priority="1835"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70306') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Table MOET 'HL70306' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Location Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Location Status' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.9"
                 priority="1834"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70305') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Table MOET 'HL70305' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Patient Location Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Patient Location Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.10"
                 priority="1833"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70307') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Table MOET 'HL70307' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Building') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Building' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.11"
                 priority="1832"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70308') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Table MOET 'HL70308' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Floor') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Floor' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35"
                 priority="1831"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('267') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('267') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '267' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NDL') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NDL') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'NDL' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Transcriptionist') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Transcriptionist') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Transcriptionist' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1"
                 priority="1829"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CNN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CNN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'CNN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.1"
                 priority="1827"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.2"
                 priority="1826"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.3"
                 priority="1825"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.4"
                 priority="1824"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.5"
                 priority="1823"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.6"
                 priority="1822"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.7"
                 priority="1821"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree (e.g., MD') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Degree (e.g., MD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.8"
                 priority="1820"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.9"
                 priority="1819"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority - Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority - Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Assigning Authority - Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.10"
                 priority="1818"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority - Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority - Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Assigning Authority - Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.11"
                 priority="1817"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority - Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Assigning Authority - Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van LongName MOET 'Assigning Authority - Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.2"
                 priority="1815"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Start Date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Start Date/time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Start Date/time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.2/hl7v2:TS.1"
                 priority="1813"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.2/hl7v2:TS.2"
                 priority="1812"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.3"
                 priority="1810"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('End Date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('End Date/time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'End Date/time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.3/hl7v2:TS.1"
                 priority="1808"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.3/hl7v2:TS.2"
                 priority="1807"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.4"
                 priority="1805"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70302') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Table MOET 'HL70302' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Point of Care') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Point of Care' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.5"
                 priority="1804"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70303') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Table MOET 'HL70303' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Room') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Room' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.6"
                 priority="1803"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70304') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Table MOET 'HL70304' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Bed') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Bed' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.7"
                 priority="1802"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Facility' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.7/hl7v2:HD.1"
                 priority="1800"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.7/hl7v2:HD.2"
                 priority="1799"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.7/hl7v2:HD.3"
                 priority="1798"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.8"
                 priority="1796"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70306') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Table MOET 'HL70306' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Location Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Location Status' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.9"
                 priority="1795"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70305') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Table MOET 'HL70305' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Patient Location Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Patient Location Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.10"
                 priority="1794"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70307') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Table MOET 'HL70307' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Building') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Building' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.11"
                 priority="1793"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70308') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van Table MOET 'HL70308' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Floor') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van LongName MOET 'Floor' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.36"
                 priority="1792"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('268') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('268') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '268' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Scheduled Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Scheduled Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Scheduled Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.36/hl7v2:TS.1"
                 priority="1790"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.36/hl7v2:TS.2"
                 priority="1789"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.37"
                 priority="1787"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1028') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1028') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1028' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Number of Sample Containers *') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Number of Sample Containers *') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Number of Sample Containers *' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.38"
                 priority="1786"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1029') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1029') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1029' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Transport Logistics of Collected Sample') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Transport Logistics of Collected Sample') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Transport Logistics of Collected Sample' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.38/hl7v2:CE.1"
                 priority="1784"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.38/hl7v2:CE.2"
                 priority="1783"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.38/hl7v2:CE.3"
                 priority="1782"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.38/hl7v2:CE.4"
                 priority="1780"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.38/hl7v2:CE.5"
                 priority="1779"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.38/hl7v2:CE.6"
                 priority="1778"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.39"
                 priority="1776"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1030') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1030') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1030' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Collector''s Comment *') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Collector''s Comment *') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Collector''s Comment *' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.39/hl7v2:CE.1"
                 priority="1774"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.39/hl7v2:CE.2"
                 priority="1773"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.39/hl7v2:CE.3"
                 priority="1772"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.39/hl7v2:CE.4"
                 priority="1770"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.39/hl7v2:CE.5"
                 priority="1769"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.39/hl7v2:CE.6"
                 priority="1768"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.40"
                 priority="1766"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1031') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1031') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1031' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Transport Arrangement Responsibility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Transport Arrangement Responsibility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Transport Arrangement Responsibility' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.40/hl7v2:CE.1"
                 priority="1764"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.40/hl7v2:CE.2"
                 priority="1763"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.40/hl7v2:CE.3"
                 priority="1762"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.40/hl7v2:CE.4"
                 priority="1760"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.40/hl7v2:CE.5"
                 priority="1759"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.40/hl7v2:CE.6"
                 priority="1758"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.41"
                 priority="1756"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1032') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1032') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1032' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70224') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70224') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Table MOET 'HL70224' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Transport Arranged') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Transport Arranged') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Transport Arranged' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.42"
                 priority="1754"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1033') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1033') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1033' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70225') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70225') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Table MOET 'HL70225' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Escort Required') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Escort Required') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Escort Required' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.43"
                 priority="1752"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1034') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1034') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1034' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Planned Patient Transport Comment') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Planned Patient Transport Comment') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Planned Patient Transport Comment' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.43/hl7v2:CE.1"
                 priority="1750"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.43/hl7v2:CE.2"
                 priority="1749"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.43/hl7v2:CE.3"
                 priority="1748"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.43/hl7v2:CE.4"
                 priority="1746"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.43/hl7v2:CE.5"
                 priority="1745"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.43/hl7v2:CE.6"
                 priority="1744"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.44"
                 priority="1742"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('393') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('393') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '393' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70088') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70088') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Table MOET 'HL70088' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Procedure Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Procedure Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Procedure Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.44/hl7v2:CE.1"
                 priority="1740"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.44/hl7v2:CE.2"
                 priority="1739"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.44/hl7v2:CE.3"
                 priority="1738"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.44/hl7v2:CE.4"
                 priority="1736"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.44/hl7v2:CE.5"
                 priority="1735"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.44/hl7v2:CE.6"
                 priority="1734"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.45"
                 priority="1732"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1316') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1316') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1316' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70340') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70340') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Table MOET 'HL70340' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Procedure Code Modifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Procedure Code Modifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Procedure Code Modifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.45/hl7v2:CE.1"
                 priority="1730"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.45/hl7v2:CE.2"
                 priority="1729"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.45/hl7v2:CE.3"
                 priority="1728"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.45/hl7v2:CE.4"
                 priority="1726"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.45/hl7v2:CE.5"
                 priority="1725"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.45/hl7v2:CE.6"
                 priority="1724"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.46"
                 priority="1722"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1474') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1474') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1474' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70411') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70411') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Table MOET 'HL70411' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Supplemental Service Information') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Placer Supplemental Service Information') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Placer Supplemental Service Information' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.46/hl7v2:CE.1"
                 priority="1720"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.46/hl7v2:CE.2"
                 priority="1719"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.46/hl7v2:CE.3"
                 priority="1718"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.46/hl7v2:CE.4"
                 priority="1716"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.46/hl7v2:CE.5"
                 priority="1715"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.46/hl7v2:CE.6"
                 priority="1714"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.47"
                 priority="1712"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1475') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1475') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1475' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70411') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70411') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Table MOET 'HL70411' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler Supplemental Service Information') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Filler Supplemental Service Information') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Filler Supplemental Service Information' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.47/hl7v2:CE.1"
                 priority="1710"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.47/hl7v2:CE.2"
                 priority="1709"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.47/hl7v2:CE.3"
                 priority="1708"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.47/hl7v2:CE.4"
                 priority="1706"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.47/hl7v2:CE.5"
                 priority="1705"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.47/hl7v2:CE.6"
                 priority="1704"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.48"
                 priority="1702"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1646') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1646') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1646' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70476') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70476') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Table MOET 'HL70476' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Medically Necessary Duplicate Procedure Reason.') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Medically Necessary Duplicate Procedure Reason.') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Medically Necessary Duplicate Procedure Reason.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.1"
                 priority="1700"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.2"
                 priority="1699"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.3"
                 priority="1698"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.4"
                 priority="1696"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.5"
                 priority="1695"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.6"
                 priority="1694"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.7"
                 priority="1692"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.8"
                 priority="1691"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.9"
                 priority="1690"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.49"
                 priority="1689"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1647') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1647') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1647' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70507') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70507') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van Table MOET 'HL70507' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Result Handling') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Result Handling') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Result Handling' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE d20e23233-false-d1022473e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN"
                 priority="1688"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPM) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab): element hl7v2:SPM is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPM) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab): element hl7v2:SPM komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM"
                 priority="1687"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPM.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): element hl7v2:SPM.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.2) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPM.2) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): element hl7v2:SPM.2 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPM.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): element hl7v2:SPM.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.4) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPM.4) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): element hl7v2:SPM.4 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPM.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): element hl7v2:SPM.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPM.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): element hl7v2:SPM.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPM.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): element hl7v2:SPM.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPM.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): element hl7v2:SPM.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.12) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPM.12) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): element hl7v2:SPM.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.13) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPM.13) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): element hl7v2:SPM.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.17) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPM.17) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): element hl7v2:SPM.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.18) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPM.18) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): element hl7v2:SPM.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.19) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPM.19) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): element hl7v2:SPM.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.20) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPM.20) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): element hl7v2:SPM.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.22) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPM.22) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): element hl7v2:SPM.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.23) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPM.23) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): element hl7v2:SPM.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.25) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPM.25) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): element hl7v2:SPM.25 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.26) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPM.26) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): element hl7v2:SPM.26 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.27) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPM.27) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): element hl7v2:SPM.27 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.28) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPM.28) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): element hl7v2:SPM.28 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.29) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPM.29) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): element hl7v2:SPM.29 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.1"
                 priority="1686"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1754') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1754') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Item MOET '1754' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('SI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Type MOET 'SI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Set ID _ SPM') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Set ID _ SPM') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van LongName MOET 'Set ID _ SPM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2"
                 priority="1685"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EIP.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EIP.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): element hl7v2:EIP.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EIP.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EIP.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): element hl7v2:EIP.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1755') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1755') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Item MOET '1755' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EIP') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('EIP') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Type MOET 'EIP' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Specimen ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van LongName MOET 'Specimen ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2/hl7v2:EIP.1"
                 priority="1683"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Assigned Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Placer Assigned Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): de waarde van LongName MOET 'Placer Assigned Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2/hl7v2:EIP.1/hl7v2:EI.1"
                 priority="1681"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2/hl7v2:EIP.1/hl7v2:EI.2"
                 priority="1680"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2/hl7v2:EIP.1/hl7v2:EI.3"
                 priority="1679"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2/hl7v2:EIP.1/hl7v2:EI.4"
                 priority="1678"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2/hl7v2:EIP.2"
                 priority="1676"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler Assigned Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Filler Assigned Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): de waarde van LongName MOET 'Filler Assigned Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2/hl7v2:EIP.2/hl7v2:EI.1"
                 priority="1674"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2/hl7v2:EIP.2/hl7v2:EI.2"
                 priority="1673"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2/hl7v2:EIP.2/hl7v2:EI.3"
                 priority="1672"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2/hl7v2:EIP.2/hl7v2:EI.4"
                 priority="1671"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3"
                 priority="1669"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EIP.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EIP.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): element hl7v2:EIP.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EIP.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EIP.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): element hl7v2:EIP.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1756') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1756') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Item MOET '1756' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EIP') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('EIP') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Type MOET 'EIP' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Parent IDs') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Specimen Parent IDs') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van LongName MOET 'Specimen Parent IDs' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3/hl7v2:EIP.1"
                 priority="1667"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Assigned Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Placer Assigned Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): de waarde van LongName MOET 'Placer Assigned Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3/hl7v2:EIP.1/hl7v2:EI.1"
                 priority="1665"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3/hl7v2:EIP.1/hl7v2:EI.2"
                 priority="1664"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3/hl7v2:EIP.1/hl7v2:EI.3"
                 priority="1663"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3/hl7v2:EIP.1/hl7v2:EI.4"
                 priority="1662"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3/hl7v2:EIP.2"
                 priority="1660"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler Assigned Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Filler Assigned Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): de waarde van LongName MOET 'Filler Assigned Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3/hl7v2:EIP.2/hl7v2:EI.1"
                 priority="1658"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3/hl7v2:EIP.2/hl7v2:EI.2"
                 priority="1657"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3/hl7v2:EIP.2/hl7v2:EI.3"
                 priority="1656"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3/hl7v2:EIP.2/hl7v2:EI.4"
                 priority="1655"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.4"
                 priority="1653"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1900') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1900') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Item MOET '1900' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70487') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70487') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Table MOET 'HL70487' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Specimen Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van LongName MOET 'Specimen Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.4/hl7v2:CWE.1"
                 priority="1651"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.4/hl7v2:CWE.2"
                 priority="1650"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.4/hl7v2:CWE.3"
                 priority="1649"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.4/hl7v2:CWE.4"
                 priority="1647"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.4/hl7v2:CWE.5"
                 priority="1646"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.4/hl7v2:CWE.6"
                 priority="1645"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.4/hl7v2:CWE.7"
                 priority="1643"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.4/hl7v2:CWE.8"
                 priority="1642"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.4/hl7v2:CWE.9"
                 priority="1641"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.5"
                 priority="1640"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1757') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1757') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Item MOET '1757' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70541') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70541') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Table MOET 'HL70541' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Type Modifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Specimen Type Modifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van LongName MOET 'Specimen Type Modifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.5/hl7v2:CWE.1"
                 priority="1638"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.5/hl7v2:CWE.2"
                 priority="1637"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.5/hl7v2:CWE.3"
                 priority="1636"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.5/hl7v2:CWE.4"
                 priority="1634"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.5/hl7v2:CWE.5"
                 priority="1633"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.5/hl7v2:CWE.6"
                 priority="1632"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.5/hl7v2:CWE.7"
                 priority="1630"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.5/hl7v2:CWE.8"
                 priority="1629"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.5/hl7v2:CWE.9"
                 priority="1628"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.6"
                 priority="1627"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1758') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1758') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Item MOET '1758' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70371') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70371') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Table MOET 'HL70371' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Additives') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Specimen Additives') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van LongName MOET 'Specimen Additives' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.6/hl7v2:CWE.1"
                 priority="1625"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.6/hl7v2:CWE.2"
                 priority="1624"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.6/hl7v2:CWE.3"
                 priority="1623"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.6/hl7v2:CWE.4"
                 priority="1621"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.6/hl7v2:CWE.5"
                 priority="1620"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.6/hl7v2:CWE.6"
                 priority="1619"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.6/hl7v2:CWE.7"
                 priority="1617"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.6/hl7v2:CWE.8"
                 priority="1616"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.6/hl7v2:CWE.9"
                 priority="1615"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.7"
                 priority="1614"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1759') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1759') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Item MOET '1759' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70488') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70488') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Table MOET 'HL70488' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Collection Method') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Specimen Collection Method') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van LongName MOET 'Specimen Collection Method' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.7/hl7v2:CWE.1"
                 priority="1612"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.7/hl7v2:CWE.2"
                 priority="1611"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.7/hl7v2:CWE.3"
                 priority="1610"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.7/hl7v2:CWE.4"
                 priority="1608"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.7/hl7v2:CWE.5"
                 priority="1607"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.7/hl7v2:CWE.6"
                 priority="1606"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.7/hl7v2:CWE.7"
                 priority="1604"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.7/hl7v2:CWE.8"
                 priority="1603"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.7/hl7v2:CWE.9"
                 priority="1602"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.8"
                 priority="1601"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1901') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1901') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Item MOET '1901' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Source Site') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Specimen Source Site') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van LongName MOET 'Specimen Source Site' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.8/hl7v2:CWE.1"
                 priority="1599"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.8/hl7v2:CWE.2"
                 priority="1598"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.8/hl7v2:CWE.3"
                 priority="1597"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.8/hl7v2:CWE.4"
                 priority="1595"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.8/hl7v2:CWE.5"
                 priority="1594"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.8/hl7v2:CWE.6"
                 priority="1593"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.8/hl7v2:CWE.7"
                 priority="1591"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.8/hl7v2:CWE.8"
                 priority="1590"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.8/hl7v2:CWE.9"
                 priority="1589"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.9"
                 priority="1588"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1760') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1760') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Item MOET '1760' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70542') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70542') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Table MOET 'HL70542' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Source Site Modifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Specimen Source Site Modifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van LongName MOET 'Specimen Source Site Modifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.9/hl7v2:CWE.1"
                 priority="1586"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.9/hl7v2:CWE.2"
                 priority="1585"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.9/hl7v2:CWE.3"
                 priority="1584"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.9/hl7v2:CWE.4"
                 priority="1582"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.9/hl7v2:CWE.5"
                 priority="1581"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.9/hl7v2:CWE.6"
                 priority="1580"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.9/hl7v2:CWE.7"
                 priority="1578"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.9/hl7v2:CWE.8"
                 priority="1577"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.9/hl7v2:CWE.9"
                 priority="1576"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.10"
                 priority="1575"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1761') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1761') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Item MOET '1761' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70543') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70543') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Table MOET 'HL70543' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Collection Site') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Specimen Collection Site') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van LongName MOET 'Specimen Collection Site' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.10/hl7v2:CWE.1"
                 priority="1573"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.10/hl7v2:CWE.2"
                 priority="1572"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.10/hl7v2:CWE.3"
                 priority="1571"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.10/hl7v2:CWE.4"
                 priority="1569"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.10/hl7v2:CWE.5"
                 priority="1568"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.10/hl7v2:CWE.6"
                 priority="1567"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.10/hl7v2:CWE.7"
                 priority="1565"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.10/hl7v2:CWE.8"
                 priority="1564"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.10/hl7v2:CWE.9"
                 priority="1563"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.11"
                 priority="1562"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1762') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1762') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Item MOET '1762' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70369') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70369') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Table MOET 'HL70369' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Role') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Specimen Role') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van LongName MOET 'Specimen Role' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.11/hl7v2:CWE.1"
                 priority="1560"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.11/hl7v2:CWE.2"
                 priority="1559"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.11/hl7v2:CWE.3"
                 priority="1558"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.11/hl7v2:CWE.4"
                 priority="1556"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.11/hl7v2:CWE.5"
                 priority="1555"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.11/hl7v2:CWE.6"
                 priority="1554"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.11/hl7v2:CWE.7"
                 priority="1552"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.11/hl7v2:CWE.8"
                 priority="1551"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.11/hl7v2:CWE.9"
                 priority="1550"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.12"
                 priority="1549"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1902') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1902') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Item MOET '1902' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CQ') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Type MOET 'CQ' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Collection Amount') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Specimen Collection Amount') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van LongName MOET 'Specimen Collection Amount' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.12/hl7v2:CQ.1"
                 priority="1547"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Quantity') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van LongName MOET 'Quantity' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.12/hl7v2:CQ.2"
                 priority="1546"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van LongName MOET 'Units' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.12/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="1544"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.12/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="1543"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.12/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="1542"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.12/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="1540"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.12/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="1539"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.12/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="1538"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.13"
                 priority="1536"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1763') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1763') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Item MOET '1763' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Grouped Specimen Count') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Grouped Specimen Count') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van LongName MOET 'Grouped Specimen Count' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.14"
                 priority="1535"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1764') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1764') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Item MOET '1764' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Description') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Specimen Description') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van LongName MOET 'Specimen Description' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.15"
                 priority="1534"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1908') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1908') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Item MOET '1908' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70376') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70376') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Table MOET 'HL70376' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Handling Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Specimen Handling Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van LongName MOET 'Specimen Handling Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.15/hl7v2:CWE.1"
                 priority="1532"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.15/hl7v2:CWE.2"
                 priority="1531"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.15/hl7v2:CWE.3"
                 priority="1530"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.15/hl7v2:CWE.4"
                 priority="1528"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.15/hl7v2:CWE.5"
                 priority="1527"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.15/hl7v2:CWE.6"
                 priority="1526"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.15/hl7v2:CWE.7"
                 priority="1524"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.15/hl7v2:CWE.8"
                 priority="1523"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.15/hl7v2:CWE.9"
                 priority="1522"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.16"
                 priority="1521"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1903') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1903') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Item MOET '1903' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70489') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70489') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Table MOET 'HL70489' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Risk Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Specimen Risk Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van LongName MOET 'Specimen Risk Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.16/hl7v2:CWE.1"
                 priority="1519"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.16/hl7v2:CWE.2"
                 priority="1518"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.16/hl7v2:CWE.3"
                 priority="1517"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.16/hl7v2:CWE.4"
                 priority="1515"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.16/hl7v2:CWE.5"
                 priority="1514"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.16/hl7v2:CWE.6"
                 priority="1513"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.16/hl7v2:CWE.7"
                 priority="1511"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.16/hl7v2:CWE.8"
                 priority="1510"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.16/hl7v2:CWE.9"
                 priority="1509"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.17"
                 priority="1508"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1765') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1765') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Item MOET '1765' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Collection Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Specimen Collection Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van LongName MOET 'Specimen Collection Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.17/hl7v2:DR.1"
                 priority="1506"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="1504"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="1503"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.17/hl7v2:DR.2"
                 priority="1501"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="1499"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="1498"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.18"
                 priority="1496"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('248') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('248') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Item MOET '248' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Received Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Specimen Received Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van LongName MOET 'Specimen Received Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.18/hl7v2:TS.1"
                 priority="1494"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.18/hl7v2:TS.2"
                 priority="1493"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.19"
                 priority="1491"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1904') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1904') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Item MOET '1904' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Expiration Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Specimen Expiration Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van LongName MOET 'Specimen Expiration Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.19/hl7v2:TS.1"
                 priority="1489"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.19/hl7v2:TS.2"
                 priority="1488"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.20"
                 priority="1486"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1766') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1766') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Item MOET '1766' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70136') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Availability') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Specimen Availability') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van LongName MOET 'Specimen Availability' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.21"
                 priority="1484"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1767') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1767') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Item MOET '1767' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70490') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70490') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Table MOET 'HL70490' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Reject Reason') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Specimen Reject Reason') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van LongName MOET 'Specimen Reject Reason' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.21/hl7v2:CWE.1"
                 priority="1482"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.21/hl7v2:CWE.2"
                 priority="1481"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.21/hl7v2:CWE.3"
                 priority="1480"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.21/hl7v2:CWE.4"
                 priority="1478"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.21/hl7v2:CWE.5"
                 priority="1477"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.21/hl7v2:CWE.6"
                 priority="1476"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.21/hl7v2:CWE.7"
                 priority="1474"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.21/hl7v2:CWE.8"
                 priority="1473"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.21/hl7v2:CWE.9"
                 priority="1472"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.22"
                 priority="1471"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1768') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1768') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Item MOET '1768' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70491') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70491') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Table MOET 'HL70491' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Quality') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Specimen Quality') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van LongName MOET 'Specimen Quality' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.22/hl7v2:CWE.1"
                 priority="1469"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.22/hl7v2:CWE.2"
                 priority="1468"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.22/hl7v2:CWE.3"
                 priority="1467"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.22/hl7v2:CWE.4"
                 priority="1465"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.22/hl7v2:CWE.5"
                 priority="1464"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.22/hl7v2:CWE.6"
                 priority="1463"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.22/hl7v2:CWE.7"
                 priority="1461"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.22/hl7v2:CWE.8"
                 priority="1460"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.22/hl7v2:CWE.9"
                 priority="1459"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.23"
                 priority="1458"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1769') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1769') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Item MOET '1769' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70492') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70492') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Table MOET 'HL70492' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Appropriateness') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Specimen Appropriateness') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van LongName MOET 'Specimen Appropriateness' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.23/hl7v2:CWE.1"
                 priority="1456"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.23/hl7v2:CWE.2"
                 priority="1455"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.23/hl7v2:CWE.3"
                 priority="1454"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.23/hl7v2:CWE.4"
                 priority="1452"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.23/hl7v2:CWE.5"
                 priority="1451"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.23/hl7v2:CWE.6"
                 priority="1450"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.23/hl7v2:CWE.7"
                 priority="1448"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.23/hl7v2:CWE.8"
                 priority="1447"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.23/hl7v2:CWE.9"
                 priority="1446"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.24"
                 priority="1445"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1770') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1770') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Item MOET '1770' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70493') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70493') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Table MOET 'HL70493' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Condition') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Specimen Condition') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van LongName MOET 'Specimen Condition' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.24/hl7v2:CWE.1"
                 priority="1443"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.24/hl7v2:CWE.2"
                 priority="1442"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.24/hl7v2:CWE.3"
                 priority="1441"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.24/hl7v2:CWE.4"
                 priority="1439"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.24/hl7v2:CWE.5"
                 priority="1438"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.24/hl7v2:CWE.6"
                 priority="1437"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.24/hl7v2:CWE.7"
                 priority="1435"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.24/hl7v2:CWE.8"
                 priority="1434"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.24/hl7v2:CWE.9"
                 priority="1433"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.25"
                 priority="1432"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1771') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1771') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Item MOET '1771' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CQ') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Type MOET 'CQ' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Current Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Specimen Current Quantity') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van LongName MOET 'Specimen Current Quantity' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.25/hl7v2:CQ.1"
                 priority="1430"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Quantity') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van LongName MOET 'Quantity' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.25/hl7v2:CQ.2"
                 priority="1429"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van LongName MOET 'Units' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.25/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="1427"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.25/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="1426"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.25/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="1425"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.25/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="1423"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.25/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="1422"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.25/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="1421"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.26"
                 priority="1419"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1772') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1772') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Item MOET '1772' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Number of Specimen Containers') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Number of Specimen Containers') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van LongName MOET 'Number of Specimen Containers' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.27"
                 priority="1418"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1773') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1773') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Item MOET '1773' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Container Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Container Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van LongName MOET 'Container Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.27/hl7v2:CWE.1"
                 priority="1416"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.27/hl7v2:CWE.2"
                 priority="1415"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.27/hl7v2:CWE.3"
                 priority="1414"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.27/hl7v2:CWE.4"
                 priority="1412"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.27/hl7v2:CWE.5"
                 priority="1411"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.27/hl7v2:CWE.6"
                 priority="1410"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.27/hl7v2:CWE.7"
                 priority="1408"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.27/hl7v2:CWE.8"
                 priority="1407"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.27/hl7v2:CWE.9"
                 priority="1406"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.28"
                 priority="1405"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1774') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1774') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Item MOET '1774' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70544') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70544') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Table MOET 'HL70544' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Container Condition') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Container Condition') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van LongName MOET 'Container Condition' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.28/hl7v2:CWE.1"
                 priority="1403"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.28/hl7v2:CWE.2"
                 priority="1402"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.28/hl7v2:CWE.3"
                 priority="1401"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.28/hl7v2:CWE.4"
                 priority="1399"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.28/hl7v2:CWE.5"
                 priority="1398"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.28/hl7v2:CWE.6"
                 priority="1397"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.28/hl7v2:CWE.7"
                 priority="1395"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.28/hl7v2:CWE.8"
                 priority="1394"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.28/hl7v2:CWE.9"
                 priority="1393"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.29"
                 priority="1392"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1775') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1775') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Item MOET '1775' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70494') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70494') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van Table MOET 'HL70494' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Child Role') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Specimen Child Role') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2Lab): de waarde van LongName MOET 'Specimen Child Role' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.29/hl7v2:CWE.1"
                 priority="1390"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.29/hl7v2:CWE.2"
                 priority="1389"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.29/hl7v2:CWE.3"
                 priority="1388"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.29/hl7v2:CWE.4"
                 priority="1386"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.29/hl7v2:CWE.5"
                 priority="1385"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.29/hl7v2:CWE.6"
                 priority="1384"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.29/hl7v2:CWE.7"
                 priority="1382"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.29/hl7v2:CWE.8"
                 priority="1381"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.29/hl7v2:CWE.9"
                 priority="1380"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC"
                 priority="1379"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.10) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.10) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.11) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.11) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.12) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.12) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.13) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.13) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.14) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.14) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.16) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.16) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.17) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.17) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.18) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.18) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.19) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.19) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.20) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.20) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.21) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.21) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.22) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.22) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.23) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.23) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.24) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.24) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.24 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.25) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.25) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.25 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.26) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.26) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.26 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.28) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.28) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.28 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.29) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.29) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.29 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.30) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.30) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.30 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.31) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.31) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.31 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.32) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.32) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.32 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.33) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.33) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.33 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.34) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.34) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.34 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.35) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.35) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.35 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.36) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.36) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.36 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.37) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.37) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.37 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.38) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.38) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.38 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.39) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.39) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.39 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.42) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.42) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.42 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.1"
                 priority="1378"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1329') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1329') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1329' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('External Accession Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('External Accession Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'External Accession Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.1/hl7v2:EI.1"
                 priority="1376"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.1/hl7v2:EI.2"
                 priority="1375"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.1/hl7v2:EI.3"
                 priority="1374"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.1/hl7v2:EI.4"
                 priority="1373"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.2"
                 priority="1371"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1330') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1330') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1330' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Accession Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Accession Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Accession Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.2/hl7v2:EI.1"
                 priority="1369"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.2/hl7v2:EI.2"
                 priority="1368"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.2/hl7v2:EI.3"
                 priority="1367"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.2/hl7v2:EI.4"
                 priority="1366"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.3"
                 priority="1364"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1331') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1331') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1331' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Container Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Container Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Container Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.3/hl7v2:EI.1"
                 priority="1362"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.3/hl7v2:EI.2"
                 priority="1361"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.3/hl7v2:EI.3"
                 priority="1360"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.3/hl7v2:EI.4"
                 priority="1359"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.4"
                 priority="1357"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1332') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1332') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1332' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Primary (parent) Container Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Primary (parent) Container Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Primary (parent) Container Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.4/hl7v2:EI.1"
                 priority="1355"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.4/hl7v2:EI.2"
                 priority="1354"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.4/hl7v2:EI.3"
                 priority="1353"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.4/hl7v2:EI.4"
                 priority="1352"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.5"
                 priority="1350"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1333') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1333') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1333' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Equipment Container Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Equipment Container Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Equipment Container Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.5/hl7v2:EI.1"
                 priority="1348"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.5/hl7v2:EI.2"
                 priority="1347"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.5/hl7v2:EI.3"
                 priority="1346"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.5/hl7v2:EI.4"
                 priority="1345"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6"
                 priority="1343"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): element hl7v2:SPS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): element hl7v2:SPS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPS.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): element hl7v2:SPS.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPS.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): element hl7v2:SPS.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPS.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): element hl7v2:SPS.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPS.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): element hl7v2:SPS.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPS.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): element hl7v2:SPS.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('249') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('249') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '249' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SPS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('SPS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'SPS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Source') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Specimen Source') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Specimen Source' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.1"
                 priority="1341"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Source Name or Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Specimen Source Name or Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van LongName MOET 'Specimen Source Name or Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.1/hl7v2:CWE.1"
                 priority="1339"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.1/hl7v2:CWE.2"
                 priority="1338"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.1/hl7v2:CWE.3"
                 priority="1337"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.1/hl7v2:CWE.4"
                 priority="1335"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.1/hl7v2:CWE.5"
                 priority="1334"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.1/hl7v2:CWE.6"
                 priority="1333"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.1/hl7v2:CWE.7"
                 priority="1331"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.1/hl7v2:CWE.8"
                 priority="1330"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.1/hl7v2:CWE.9"
                 priority="1329"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.2"
                 priority="1328"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70371') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70371') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van Table MOET 'HL70371' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Additives') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Additives') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van LongName MOET 'Additives' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.2/hl7v2:CWE.1"
                 priority="1326"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.2/hl7v2:CWE.2"
                 priority="1325"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.2/hl7v2:CWE.3"
                 priority="1324"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.2/hl7v2:CWE.4"
                 priority="1322"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.2/hl7v2:CWE.5"
                 priority="1321"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.2/hl7v2:CWE.6"
                 priority="1320"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.2/hl7v2:CWE.7"
                 priority="1318"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.2/hl7v2:CWE.8"
                 priority="1317"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.2/hl7v2:CWE.9"
                 priority="1316"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.3"
                 priority="1315"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TX') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TX') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van Type MOET 'TX' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Collection Method') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Specimen Collection Method') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van LongName MOET 'Specimen Collection Method' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.3/hl7v2:escape"
                 priority="1314"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.65-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TX_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.3/hl7v2:escape/hl7v2:escape"
                 priority="1313"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.3/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="1312"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.4"
                 priority="1311"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70163') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70163') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van Table MOET 'HL70163' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Body Site') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Body Site') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van LongName MOET 'Body Site' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.4/hl7v2:CWE.1"
                 priority="1309"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.4/hl7v2:CWE.2"
                 priority="1308"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.4/hl7v2:CWE.3"
                 priority="1307"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.4/hl7v2:CWE.4"
                 priority="1305"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.4/hl7v2:CWE.5"
                 priority="1304"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.4/hl7v2:CWE.6"
                 priority="1303"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.4/hl7v2:CWE.7"
                 priority="1301"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.4/hl7v2:CWE.8"
                 priority="1300"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.4/hl7v2:CWE.9"
                 priority="1299"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.5"
                 priority="1298"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70495') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70495') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van Table MOET 'HL70495' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Site Modifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Site Modifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van LongName MOET 'Site Modifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.5/hl7v2:CWE.1"
                 priority="1296"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.5/hl7v2:CWE.2"
                 priority="1295"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.5/hl7v2:CWE.3"
                 priority="1294"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.5/hl7v2:CWE.4"
                 priority="1292"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.5/hl7v2:CWE.5"
                 priority="1291"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.5/hl7v2:CWE.6"
                 priority="1290"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.5/hl7v2:CWE.7"
                 priority="1288"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.5/hl7v2:CWE.8"
                 priority="1287"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.5/hl7v2:CWE.9"
                 priority="1286"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.6"
                 priority="1285"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Collection Method Modifier Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Collection Method Modifier Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van LongName MOET 'Collection Method Modifier Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.6/hl7v2:CWE.1"
                 priority="1283"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.6/hl7v2:CWE.2"
                 priority="1282"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.6/hl7v2:CWE.3"
                 priority="1281"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.6/hl7v2:CWE.4"
                 priority="1279"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.6/hl7v2:CWE.5"
                 priority="1278"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.6/hl7v2:CWE.6"
                 priority="1277"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.6/hl7v2:CWE.7"
                 priority="1275"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.6/hl7v2:CWE.8"
                 priority="1274"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.6/hl7v2:CWE.9"
                 priority="1273"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.7"
                 priority="1272"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70369') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70369') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van Table MOET 'HL70369' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Role') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Specimen Role') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van LongName MOET 'Specimen Role' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.7/hl7v2:CWE.1"
                 priority="1270"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.7/hl7v2:CWE.2"
                 priority="1269"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.7/hl7v2:CWE.3"
                 priority="1268"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.7/hl7v2:CWE.4"
                 priority="1266"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.7/hl7v2:CWE.5"
                 priority="1265"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.7/hl7v2:CWE.6"
                 priority="1264"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.7/hl7v2:CWE.7"
                 priority="1262"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.7/hl7v2:CWE.8"
                 priority="1261"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.7/hl7v2:CWE.9"
                 priority="1260"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.7"
                 priority="1259"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1334') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1334') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1334' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Registration Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Registration Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Registration Date/Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.7/hl7v2:TS.1"
                 priority="1257"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.7/hl7v2:TS.2"
                 priority="1256"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.8"
                 priority="1254"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1335') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1335') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1335' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70370') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70370') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Table MOET 'HL70370' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Container Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Container Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Container Status' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.8/hl7v2:CE.1"
                 priority="1252"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.8/hl7v2:CE.2"
                 priority="1251"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.8/hl7v2:CE.3"
                 priority="1250"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.8/hl7v2:CE.4"
                 priority="1248"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.8/hl7v2:CE.5"
                 priority="1247"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.8/hl7v2:CE.6"
                 priority="1246"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.9"
                 priority="1244"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1336') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1336') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1336' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70378') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70378') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Table MOET 'HL70378' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Carrier Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Carrier Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Carrier Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.9/hl7v2:CE.1"
                 priority="1242"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.9/hl7v2:CE.2"
                 priority="1241"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.9/hl7v2:CE.3"
                 priority="1240"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.9/hl7v2:CE.4"
                 priority="1238"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.9/hl7v2:CE.5"
                 priority="1237"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.9/hl7v2:CE.6"
                 priority="1236"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.10"
                 priority="1234"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1337') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1337') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1337' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Carrier Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Carrier Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Carrier Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.10/hl7v2:EI.1"
                 priority="1232"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.10/hl7v2:EI.2"
                 priority="1231"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.10/hl7v2:EI.3"
                 priority="1230"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.10/hl7v2:EI.4"
                 priority="1229"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.11"
                 priority="1227"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="*[matches(local-name(),'^NA\.\d+$')]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="*[matches(local-name(),'^NA\.\d+$')]">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): Element names in the datatype NA SHALL conform to pattern 'NA.n' where n is an integer</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="*[. castable as xs:decimal]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="*[. castable as xs:decimal]">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): Element values in the datatype NA SHALL be a valid NM - Numeric</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NA.1) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NA.1) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): element hl7v2:NA.1 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NA.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NA.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): element hl7v2:NA.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NA.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NA.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): element hl7v2:NA.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NA.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NA.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): element hl7v2:NA.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NA.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NA.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): element hl7v2:NA.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1338') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1338') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1338' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NA') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NA') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'NA' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Position in Carrier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Position in Carrier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Position in Carrier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.11/hl7v2:NA.1"
                 priority="1225"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Value1') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Value1') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): de waarde van LongName MOET 'Value1' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.11/hl7v2:NA.2"
                 priority="1224"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Value2') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Value2') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): de waarde van LongName MOET 'Value2' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.11/hl7v2:NA.3"
                 priority="1223"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Value3') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Value3') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): de waarde van LongName MOET 'Value3' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.11/hl7v2:NA.4"
                 priority="1222"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Value4') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Value4') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): de waarde van LongName MOET 'Value4' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.12"
                 priority="1221"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1339') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1339') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1339' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70379') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70379') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Table MOET 'HL70379' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Tray Type - SAC') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Tray Type - SAC') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Tray Type - SAC' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.12/hl7v2:CE.1"
                 priority="1219"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.12/hl7v2:CE.2"
                 priority="1218"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.12/hl7v2:CE.3"
                 priority="1217"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.12/hl7v2:CE.4"
                 priority="1215"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.12/hl7v2:CE.5"
                 priority="1214"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.12/hl7v2:CE.6"
                 priority="1213"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.13"
                 priority="1211"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1340') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1340') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1340' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Tray Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Tray Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Tray Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.13/hl7v2:EI.1"
                 priority="1209"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.13/hl7v2:EI.2"
                 priority="1208"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.13/hl7v2:EI.3"
                 priority="1207"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.13/hl7v2:EI.4"
                 priority="1206"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.14"
                 priority="1204"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="*[matches(local-name(),'^NA\.\d+$')]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="*[matches(local-name(),'^NA\.\d+$')]">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): Element names in the datatype NA SHALL conform to pattern 'NA.n' where n is an integer</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="*[. castable as xs:decimal]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="*[. castable as xs:decimal]">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): Element values in the datatype NA SHALL be a valid NM - Numeric</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NA.1) &gt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NA.1) &gt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): element hl7v2:NA.1 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NA.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NA.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): element hl7v2:NA.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NA.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NA.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): element hl7v2:NA.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NA.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NA.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): element hl7v2:NA.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NA.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NA.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): element hl7v2:NA.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1341') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1341') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1341' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NA') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NA') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'NA' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Position in Tray') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Position in Tray') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Position in Tray' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.14/hl7v2:NA.1"
                 priority="1202"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Value1') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Value1') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): de waarde van LongName MOET 'Value1' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.14/hl7v2:NA.2"
                 priority="1201"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Value2') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Value2') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): de waarde van LongName MOET 'Value2' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.14/hl7v2:NA.3"
                 priority="1200"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Value3') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Value3') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): de waarde van LongName MOET 'Value3' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.14/hl7v2:NA.4"
                 priority="1199"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Value4') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Value4') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): de waarde van LongName MOET 'Value4' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.15"
                 priority="1198"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1342') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1342') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1342' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Location') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Location') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Location' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.15/hl7v2:CE.1"
                 priority="1196"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.15/hl7v2:CE.2"
                 priority="1195"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.15/hl7v2:CE.3"
                 priority="1194"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.15/hl7v2:CE.4"
                 priority="1192"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.15/hl7v2:CE.5"
                 priority="1191"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.15/hl7v2:CE.6"
                 priority="1190"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.16"
                 priority="1188"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1343') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1343') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1343' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Container Height') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Container Height') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Container Height' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.17"
                 priority="1187"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1344') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1344') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1344' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Container Diameter') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Container Diameter') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Container Diameter' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.18"
                 priority="1186"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1345') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1345') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1345' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Barrier Delta') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Barrier Delta') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Barrier Delta' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.19"
                 priority="1185"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1346') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1346') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1346' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Bottom Delta') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Bottom Delta') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Bottom Delta' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.20"
                 priority="1184"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1347') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1347') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1347' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Container Height/Diameter/Delta Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Container Height/Diameter/Delta Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Container Height/Diameter/Delta Units' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.20/hl7v2:CE.1"
                 priority="1182"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.20/hl7v2:CE.2"
                 priority="1181"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.20/hl7v2:CE.3"
                 priority="1180"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.20/hl7v2:CE.4"
                 priority="1178"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.20/hl7v2:CE.5"
                 priority="1177"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.20/hl7v2:CE.6"
                 priority="1176"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.21"
                 priority="1174"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('644') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('644') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '644' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Container Volume') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Container Volume') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Container Volume' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.22"
                 priority="1173"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1349') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1349') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1349' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Available Specimen Volume') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Available Specimen Volume') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Available Specimen Volume' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.23"
                 priority="1172"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1350') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1350') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1350' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Initial Specimen Volume') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Initial Specimen Volume') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Initial Specimen Volume' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.24"
                 priority="1171"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1351') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1351') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1351' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Volume Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Volume Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Volume Units' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.24/hl7v2:CE.1"
                 priority="1169"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.24/hl7v2:CE.2"
                 priority="1168"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.24/hl7v2:CE.3"
                 priority="1167"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.24/hl7v2:CE.4"
                 priority="1165"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.24/hl7v2:CE.5"
                 priority="1164"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.24/hl7v2:CE.6"
                 priority="1163"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.25"
                 priority="1161"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1352') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1352') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1352' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70380') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70380') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Table MOET 'HL70380' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Separator Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Separator Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Separator Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.25/hl7v2:CE.1"
                 priority="1159"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.25/hl7v2:CE.2"
                 priority="1158"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.25/hl7v2:CE.3"
                 priority="1157"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.25/hl7v2:CE.4"
                 priority="1155"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.25/hl7v2:CE.5"
                 priority="1154"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.25/hl7v2:CE.6"
                 priority="1153"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.26"
                 priority="1151"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1353') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1353') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1353' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70381') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70381') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Table MOET 'HL70381' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Cap Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Cap Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Cap Type' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.26/hl7v2:CE.1"
                 priority="1149"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.26/hl7v2:CE.2"
                 priority="1148"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.26/hl7v2:CE.3"
                 priority="1147"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.26/hl7v2:CE.4"
                 priority="1145"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.26/hl7v2:CE.5"
                 priority="1144"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.26/hl7v2:CE.6"
                 priority="1143"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.27"
                 priority="1141"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('647') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('647') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '647' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70371') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70371') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Table MOET 'HL70371' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Additive') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Additive') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Additive' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.27/hl7v2:CWE.1"
                 priority="1139"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.27/hl7v2:CWE.2"
                 priority="1138"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.27/hl7v2:CWE.3"
                 priority="1137"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.27/hl7v2:CWE.4"
                 priority="1135"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.27/hl7v2:CWE.5"
                 priority="1134"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.27/hl7v2:CWE.6"
                 priority="1133"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.27/hl7v2:CWE.7"
                 priority="1131"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.27/hl7v2:CWE.8"
                 priority="1130"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.27/hl7v2:CWE.9"
                 priority="1129"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.28"
                 priority="1128"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1355') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1355') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1355' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Component') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Specimen Component') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Specimen Component' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.28/hl7v2:CE.1"
                 priority="1126"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.28/hl7v2:CE.2"
                 priority="1125"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.28/hl7v2:CE.3"
                 priority="1124"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.28/hl7v2:CE.4"
                 priority="1122"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.28/hl7v2:CE.5"
                 priority="1121"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.28/hl7v2:CE.6"
                 priority="1120"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.29"
                 priority="1118"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): element hl7v2:SN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): element hl7v2:SN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): element hl7v2:SN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): element hl7v2:SN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1356') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1356') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1356' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('SN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'SN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Dilution Factor') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Dilution Factor') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Dilution Factor' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.29/hl7v2:SN.1"
                 priority="1116"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Comparator') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Comparator') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van LongName MOET 'Comparator' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.29/hl7v2:SN.2"
                 priority="1115"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Num1') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Num1') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van LongName MOET 'Num1' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.29/hl7v2:SN.3"
                 priority="1114"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Separator/Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Separator/Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van LongName MOET 'Separator/Suffix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.29/hl7v2:SN.4"
                 priority="1113"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Num2') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Num2') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van LongName MOET 'Num2' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.30"
                 priority="1112"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1357') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1357') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1357' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70373') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70373') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Table MOET 'HL70373' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Treatment') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Treatment') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Treatment' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.30/hl7v2:CE.1"
                 priority="1110"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.30/hl7v2:CE.2"
                 priority="1109"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.30/hl7v2:CE.3"
                 priority="1108"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.30/hl7v2:CE.4"
                 priority="1106"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.30/hl7v2:CE.5"
                 priority="1105"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.30/hl7v2:CE.6"
                 priority="1104"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.31"
                 priority="1102"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SN.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): element hl7v2:SN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SN.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): element hl7v2:SN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SN.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): element hl7v2:SN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SN.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): element hl7v2:SN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1358') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1358') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1358' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('SN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'SN' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Temperature') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Temperature') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Temperature' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.31/hl7v2:SN.1"
                 priority="1100"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Comparator') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Comparator') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van LongName MOET 'Comparator' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.31/hl7v2:SN.2"
                 priority="1099"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Num1') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Num1') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van LongName MOET 'Num1' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.31/hl7v2:SN.3"
                 priority="1098"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Separator/Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Separator/Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van LongName MOET 'Separator/Suffix' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.31/hl7v2:SN.4"
                 priority="1097"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Num2') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Num2') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van LongName MOET 'Num2' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.32"
                 priority="1096"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1359') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1359') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1359' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Hemolysis Index') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Hemolysis Index') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Hemolysis Index' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.33"
                 priority="1095"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1360') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1360') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1360' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Hemolysis Index Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Hemolysis Index Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Hemolysis Index Units' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.33/hl7v2:CE.1"
                 priority="1093"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.33/hl7v2:CE.2"
                 priority="1092"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.33/hl7v2:CE.3"
                 priority="1091"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.33/hl7v2:CE.4"
                 priority="1089"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.33/hl7v2:CE.5"
                 priority="1088"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.33/hl7v2:CE.6"
                 priority="1087"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.34"
                 priority="1085"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1361') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1361') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1361' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Lipemia Index') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Lipemia Index') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Lipemia Index' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.35"
                 priority="1084"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1362') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1362') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1362' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Lipemia Index Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Lipemia Index Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Lipemia Index Units' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.35/hl7v2:CE.1"
                 priority="1082"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.35/hl7v2:CE.2"
                 priority="1081"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.35/hl7v2:CE.3"
                 priority="1080"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.35/hl7v2:CE.4"
                 priority="1078"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.35/hl7v2:CE.5"
                 priority="1077"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.35/hl7v2:CE.6"
                 priority="1076"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.36"
                 priority="1074"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1363') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1363') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1363' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Icterus Index') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Icterus Index') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Icterus Index' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.37"
                 priority="1073"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1364') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1364') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1364' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Icterus Index Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Icterus Index Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Icterus Index Units' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.37/hl7v2:CE.1"
                 priority="1071"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.37/hl7v2:CE.2"
                 priority="1070"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.37/hl7v2:CE.3"
                 priority="1069"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.37/hl7v2:CE.4"
                 priority="1067"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.37/hl7v2:CE.5"
                 priority="1066"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.37/hl7v2:CE.6"
                 priority="1065"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.38"
                 priority="1063"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1365') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1365') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1365' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Fibrin Index') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Fibrin Index') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Fibrin Index' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.39"
                 priority="1062"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1366') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1366') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1366' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Fibrin Index Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Fibrin Index Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Fibrin Index Units' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.39/hl7v2:CE.1"
                 priority="1060"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.39/hl7v2:CE.2"
                 priority="1059"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.39/hl7v2:CE.3"
                 priority="1058"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.39/hl7v2:CE.4"
                 priority="1056"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.39/hl7v2:CE.5"
                 priority="1055"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.39/hl7v2:CE.6"
                 priority="1054"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.40"
                 priority="1052"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1367') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1367') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1367' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70374') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70374') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Table MOET 'HL70374' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('System Induced Contaminants') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('System Induced Contaminants') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'System Induced Contaminants' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.40/hl7v2:CE.1"
                 priority="1050"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.40/hl7v2:CE.2"
                 priority="1049"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.40/hl7v2:CE.3"
                 priority="1048"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.40/hl7v2:CE.4"
                 priority="1046"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.40/hl7v2:CE.5"
                 priority="1045"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.40/hl7v2:CE.6"
                 priority="1044"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.41"
                 priority="1042"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1368') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1368') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1368' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70382') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70382') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Table MOET 'HL70382' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Drug Interference') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Drug Interference') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Drug Interference' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.41/hl7v2:CE.1"
                 priority="1040"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.41/hl7v2:CE.2"
                 priority="1039"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.41/hl7v2:CE.3"
                 priority="1038"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.41/hl7v2:CE.4"
                 priority="1036"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.41/hl7v2:CE.5"
                 priority="1035"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.41/hl7v2:CE.6"
                 priority="1034"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.42"
                 priority="1032"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1369') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1369') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1369' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70375') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70375') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Table MOET 'HL70375' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Artificial Blood') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Artificial Blood') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Artificial Blood' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.42/hl7v2:CE.1"
                 priority="1030"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.42/hl7v2:CE.2"
                 priority="1029"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.42/hl7v2:CE.3"
                 priority="1028"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.42/hl7v2:CE.4"
                 priority="1026"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.42/hl7v2:CE.5"
                 priority="1025"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.42/hl7v2:CE.6"
                 priority="1024"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.43"
                 priority="1022"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1370') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1370') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1370' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70376') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70376') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Table MOET 'HL70376' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Special Handling Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Special Handling Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Special Handling Code' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.43/hl7v2:CWE.1"
                 priority="1020"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.43/hl7v2:CWE.2"
                 priority="1019"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.43/hl7v2:CWE.3"
                 priority="1018"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.43/hl7v2:CWE.4"
                 priority="1016"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.43/hl7v2:CWE.5"
                 priority="1015"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.43/hl7v2:CWE.6"
                 priority="1014"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.43/hl7v2:CWE.7"
                 priority="1012"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.43/hl7v2:CWE.8"
                 priority="1011"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.43/hl7v2:CWE.9"
                 priority="1010"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.44"
                 priority="1009"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6) &lt;= 1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1371') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item) = ('1371') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Item MOET '1371' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Item"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70377') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70377') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van Table MOET 'HL70377' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Other Environmental Factors') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Other Environmental Factors') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van LongName MOET 'Other Environmental Factors' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.44/hl7v2:CE.1"
                 priority="1007"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.44/hl7v2:CE.2"
                 priority="1006"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.44/hl7v2:CE.3"
                 priority="1005"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.44/hl7v2:CE.4"
                 priority="1003"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.44/hl7v2:CE.5"
                 priority="1002"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.44/hl7v2:CE.6"
                 priority="1001"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@MaxLength"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type) = ('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Type"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table) = ('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@Table"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
                  <xsl:value-of select="@LongName"/>
                  <xsl:text/>"</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M14"/>
   <xsl:template match="@*|node()" priority="-2" mode="M14">
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701-closedLab2Lab Aanvraagbevestigingbericht (ORL^O22)-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">Lab2Lab Aanvraagbevestigingbericht (ORL^O22)</svrl:text>

	  <!--RULE d20e23176-true-d1038237e0-->
   <xsl:template match="/*[not(self::hl7v2:MSH | self::hl7v2:MSA | self::hl7v2:ERR | self::hl7v2:SFT | self::hl7v2:NTE | self::hl7v2:ORL_O22.RESPONSE)]"
                 priority="1440"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d20e23176-true-d1038237e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:MSH | hl7v2:MSA | hl7v2:ERR | hl7v2:SFT | hl7v2:NTE | hl7v2:ORL_O22.RESPONSE (rule-reference: d20e23176-true-d1038237e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e23189-true-d1038267e0-->
   <xsl:template match="/hl7v2:MSH/*[not(self::hl7v2:MSH.1 | self::hl7v2:MSH.2 | self::hl7v2:MSH.3 | self::hl7v2:MSH.4 | self::hl7v2:MSH.5 | self::hl7v2:MSH.6 | self::hl7v2:MSH.7 | self::hl7v2:MSH.8 | self::hl7v2:MSH.9 | self::hl7v2:MSH.10 | self::hl7v2:MSH.11 | self::hl7v2:MSH.12 | self::hl7v2:MSH.13 | self::hl7v2:MSH.14 | self::hl7v2:MSH.15 | self::hl7v2:MSH.16 | self::hl7v2:MSH.17 | self::hl7v2:MSH.18 | self::hl7v2:MSH.19 | self::hl7v2:MSH.20 | self::hl7v2:MSH.21)]"
                 priority="1439"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d20e23189-true-d1038267e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:MSH.1 | hl7v2:MSH.2 | hl7v2:MSH.3 | hl7v2:MSH.4 | hl7v2:MSH.5 | hl7v2:MSH.6 | hl7v2:MSH.7 | hl7v2:MSH.8 | hl7v2:MSH.9 | hl7v2:MSH.10 | hl7v2:MSH.11 | hl7v2:MSH.12 | hl7v2:MSH.13 | hl7v2:MSH.14 | hl7v2:MSH.15 | hl7v2:MSH.16 | hl7v2:MSH.17 | hl7v2:MSH.18 | hl7v2:MSH.19 | hl7v2:MSH.20 | hl7v2:MSH.21 (rule-reference: d20e23189-true-d1038267e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1038242e35-true-d1038291e0-->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.3/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1438"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1038242e35-true-d1038291e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d1038242e35-true-d1038291e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1038242e61-true-d1038321e0-->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.4/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1437"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1038242e61-true-d1038321e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d1038242e61-true-d1038321e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1038242e99-true-d1038351e0-->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.5/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1436"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1038242e99-true-d1038351e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d1038242e99-true-d1038351e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1038242e128-true-d1038381e0-->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.6/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1435"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1038242e128-true-d1038381e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d1038242e128-true-d1038381e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1038242e166-true-d1038410e0-->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.7/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1434"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1038242e166-true-d1038410e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1038242e166-true-d1038410e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1038242e212-true-d1038440e0-->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.9/*[not(self::hl7v2:MSG.1 | self::hl7v2:MSG.2 | self::hl7v2:MSG.3)]"
                 priority="1433"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1038242e212-true-d1038440e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:MSG.1 | hl7v2:MSG.2 | hl7v2:MSG.3 (rule-reference: d1038242e212-true-d1038440e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1038242e259-true-d1038475e0-->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.11/*[not(self::hl7v2:PT.1 | self::hl7v2:PT.2)]"
                 priority="1432"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1038242e259-true-d1038475e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:PT.1 | hl7v2:PT.2 (rule-reference: d1038242e259-true-d1038475e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1038242e286-true-d1038499e0-->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.12/*[not(self::hl7v2:VID.1 | self::hl7v2:VID.2 | self::hl7v2:VID.3)]"
                 priority="1431"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1038242e286-true-d1038499e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:VID.1 | hl7v2:VID.2 | hl7v2:VID.3 (rule-reference: d1038242e286-true-d1038499e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1038491e36-true-d1038520e0-->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.2/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1430"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1038491e36-true-d1038520e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1038491e36-true-d1038520e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1038491e55-true-d1038571e0-->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.3/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1429"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1038491e55-true-d1038571e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1038491e55-true-d1038571e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1038242e464-true-d1038658e0-->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.19/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1428"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1038242e464-true-d1038658e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1038242e464-true-d1038658e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1038242e499-true-d1038713e0-->
   <xsl:template match="/hl7v2:MSH/hl7v2:MSH.21/*[not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1427"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1038242e499-true-d1038713e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d1038242e499-true-d1038713e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e23191-true-d1038752e0-->
   <xsl:template match="/hl7v2:MSA/*[not(self::hl7v2:MSA.1 | self::hl7v2:MSA.2 | self::hl7v2:MSA.3 | self::hl7v2:MSA.4 | self::hl7v2:MSA.5 | self::hl7v2:MSA.6)]"
                 priority="1426"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d20e23191-true-d1038752e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:MSA.1 | hl7v2:MSA.2 | hl7v2:MSA.3 | hl7v2:MSA.4 | hl7v2:MSA.5 | hl7v2:MSA.6 (rule-reference: d20e23191-true-d1038752e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1038742e58-true-d1038797e0-->
   <xsl:template match="/hl7v2:MSA/hl7v2:MSA.6/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1425"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1038742e58-true-d1038797e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1038742e58-true-d1038797e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e23193-true-d1038854e0-->
   <xsl:template match="/hl7v2:ERR/*[not(self::hl7v2:ERR.1 | self::hl7v2:ERR.2 | self::hl7v2:ERR.3 | self::hl7v2:ERR.4 | self::hl7v2:ERR.5 | self::hl7v2:ERR.6 | self::hl7v2:ERR.7 | self::hl7v2:ERR.8 | self::hl7v2:ERR.9 | self::hl7v2:ERR.10 | self::hl7v2:ERR.11 | self::hl7v2:ERR.12)]"
                 priority="1424"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d20e23193-true-d1038854e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:ERR.1 | hl7v2:ERR.2 | hl7v2:ERR.3 | hl7v2:ERR.4 | hl7v2:ERR.5 | hl7v2:ERR.6 | hl7v2:ERR.7 | hl7v2:ERR.8 | hl7v2:ERR.9 | hl7v2:ERR.10 | hl7v2:ERR.11 | hl7v2:ERR.12 (rule-reference: d20e23193-true-d1038854e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1038837e8-true-d1038867e0-->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.1/*[not(self::hl7v2:ELD.1 | self::hl7v2:ELD.2 | self::hl7v2:ELD.3 | self::hl7v2:ELD.4)]"
                 priority="1423"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1038837e8-true-d1038867e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:ELD.1 | hl7v2:ELD.2 | hl7v2:ELD.3 | hl7v2:ELD.4 (rule-reference: d1038837e8-true-d1038867e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1038858e48-true-d1038900e0-->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.1/hl7v2:ELD.4/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1422"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1038858e48-true-d1038900e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1038858e48-true-d1038900e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1038837e19-true-d1038951e0-->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.2/*[not(self::hl7v2:ERL.1 | self::hl7v2:ERL.2 | self::hl7v2:ERL.3 | self::hl7v2:ERL.4 | self::hl7v2:ERL.5 | self::hl7v2:ERL.6)]"
                 priority="1421"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1038837e19-true-d1038951e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:ERL.1 | hl7v2:ERL.2 | hl7v2:ERL.3 | hl7v2:ERL.4 | hl7v2:ERL.5 | hl7v2:ERL.6 (rule-reference: d1038837e19-true-d1038951e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1038837e30-true-d1039005e0-->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.3/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1420"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1038837e30-true-d1039005e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d1038837e30-true-d1039005e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1038837e56-true-d1039083e0-->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.5/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1419"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1038837e56-true-d1039083e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d1038837e56-true-d1039083e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1038837e81-true-d1039153e0-->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.7/*[not(self::hl7v2:escape)]"
                 priority="1418"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1038837e81-true-d1039153e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d1038837e81-true-d1039153e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1039147e15-true-d1039163e0-->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.7/hl7v2:escape/*[not(self::hl7v2:escape)]"
                 priority="1417"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1039147e15-true-d1039163e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d1039147e15-true-d1039163e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1039157e5-true-d1039173e0-->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.7/hl7v2:escape/hl7v2:escape/*[not(self::hl7v2:escape)]"
                 priority="1416"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1039157e5-true-d1039173e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d1039157e5-true-d1039173e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1038837e92-true-d1039187e0-->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.8/*[not(self::hl7v2:escape)]"
                 priority="1415"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1038837e92-true-d1039187e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d1038837e92-true-d1039187e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1039181e15-true-d1039197e0-->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.8/hl7v2:escape/*[not(self::hl7v2:escape)]"
                 priority="1414"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1039181e15-true-d1039197e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d1039181e15-true-d1039197e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1039191e5-true-d1039207e0-->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.8/hl7v2:escape/hl7v2:escape/*[not(self::hl7v2:escape)]"
                 priority="1413"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1039191e5-true-d1039207e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d1039191e5-true-d1039207e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1038837e116-true-d1039235e0-->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.10/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1412"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1038837e116-true-d1039235e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d1038837e116-true-d1039235e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1038837e129-true-d1039307e0-->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.11/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1411"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1038837e129-true-d1039307e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d1038837e129-true-d1039307e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1038837e142-true-d1039382e0-->
   <xsl:template match="/hl7v2:ERR/hl7v2:ERR.12/*[not(self::hl7v2:XTN.1 | self::hl7v2:XTN.2 | self::hl7v2:XTN.3 | self::hl7v2:XTN.4 | self::hl7v2:XTN.5 | self::hl7v2:XTN.6 | self::hl7v2:XTN.7 | self::hl7v2:XTN.8 | self::hl7v2:XTN.9 | self::hl7v2:XTN.10 | self::hl7v2:XTN.11 | self::hl7v2:XTN.12)]"
                 priority="1410"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1038837e142-true-d1039382e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XTN.1 | hl7v2:XTN.2 | hl7v2:XTN.3 | hl7v2:XTN.4 | hl7v2:XTN.5 | hl7v2:XTN.6 | hl7v2:XTN.7 | hl7v2:XTN.8 | hl7v2:XTN.9 | hl7v2:XTN.10 | hl7v2:XTN.11 | hl7v2:XTN.12 (rule-reference: d1038837e142-true-d1039382e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e23202-true-d1039469e0-->
   <xsl:template match="/hl7v2:SFT/*[not(self::hl7v2:SFT.1 | self::hl7v2:SFT.2 | self::hl7v2:SFT.3 | self::hl7v2:SFT.4 | self::hl7v2:SFT.5 | self::hl7v2:SFT.6)]"
                 priority="1409"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d20e23202-true-d1039469e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:SFT.1 | hl7v2:SFT.2 | hl7v2:SFT.3 | hl7v2:SFT.4 | hl7v2:SFT.5 | hl7v2:SFT.6 (rule-reference: d20e23202-true-d1039469e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1039459e1-true-d1039488e0-->
   <xsl:template match="/hl7v2:SFT/hl7v2:SFT.1/*[not(self::hl7v2:XON.1 | self::hl7v2:XON.2 | self::hl7v2:XON.3 | self::hl7v2:XON.4 | self::hl7v2:XON.5 | self::hl7v2:XON.6 | self::hl7v2:XON.7 | self::hl7v2:XON.8 | self::hl7v2:XON.9 | self::hl7v2:XON.10)]"
                 priority="1408"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1039459e1-true-d1039488e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XON.1 | hl7v2:XON.2 | hl7v2:XON.3 | hl7v2:XON.4 | hl7v2:XON.5 | hl7v2:XON.6 | hl7v2:XON.7 | hl7v2:XON.8 | hl7v2:XON.9 | hl7v2:XON.10 (rule-reference: d1039459e1-true-d1039488e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1039473e80-true-d1039530e0-->
   <xsl:template match="/hl7v2:SFT/hl7v2:SFT.1/hl7v2:XON.6/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1407"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1039473e80-true-d1039530e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d1039473e80-true-d1039530e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1039473e119-true-d1039566e0-->
   <xsl:template match="/hl7v2:SFT/hl7v2:SFT.1/hl7v2:XON.8/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1406"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1039473e119-true-d1039566e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d1039473e119-true-d1039566e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1039459e45-true-d1039624e0-->
   <xsl:template match="/hl7v2:SFT/hl7v2:SFT.5/*[not(self::hl7v2:escape)]"
                 priority="1405"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1039459e45-true-d1039624e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d1039459e45-true-d1039624e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1039618e15-true-d1039634e0-->
   <xsl:template match="/hl7v2:SFT/hl7v2:SFT.5/hl7v2:escape/*[not(self::hl7v2:escape)]"
                 priority="1404"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1039618e15-true-d1039634e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d1039618e15-true-d1039634e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1039628e5-true-d1039644e0-->
   <xsl:template match="/hl7v2:SFT/hl7v2:SFT.5/hl7v2:escape/hl7v2:escape/*[not(self::hl7v2:escape)]"
                 priority="1403"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1039628e5-true-d1039644e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d1039628e5-true-d1039644e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1039459e56-true-d1039659e0-->
   <xsl:template match="/hl7v2:SFT/hl7v2:SFT.6/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1402"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1039459e56-true-d1039659e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1039459e56-true-d1039659e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e23204-true-d1039684e0-->
   <xsl:template match="/hl7v2:NTE/*[not(self::hl7v2:NTE.1 | self::hl7v2:NTE.2 | self::hl7v2:NTE.3 | self::hl7v2:NTE.4)]"
                 priority="1401"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d20e23204-true-d1039684e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:NTE.1 | hl7v2:NTE.2 | hl7v2:NTE.3 | hl7v2:NTE.4 (rule-reference: d20e23204-true-d1039684e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1039676e25-true-d1039706e0-->
   <xsl:template match="/hl7v2:NTE/hl7v2:NTE.3/*[not(self::hl7v2:escape)]"
                 priority="1400"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1039676e25-true-d1039706e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d1039676e25-true-d1039706e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1039700e24-true-d1039716e0-->
   <xsl:template match="/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/*[not(self::hl7v2:escape)]"
                 priority="1399"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1039700e24-true-d1039716e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d1039700e24-true-d1039716e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1039710e5-true-d1039726e0-->
   <xsl:template match="/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/hl7v2:escape/*[not(self::hl7v2:escape)]"
                 priority="1398"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1039710e5-true-d1039726e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d1039710e5-true-d1039726e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1039676e45-true-d1039745e0-->
   <xsl:template match="/hl7v2:NTE/hl7v2:NTE.4/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1397"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1039676e45-true-d1039745e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1039676e45-true-d1039745e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e23206-true-d1039788e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/*[not(self::hl7v2:ORL_O22.PATIENT)]"
                 priority="1396"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d20e23206-true-d1039788e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:ORL_O22.PATIENT (rule-reference: d20e23206-true-d1039788e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e23214-true-d1039797e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/*[not(self::hl7v2:PID | self::hl7v2:ORL_O22.ORDER)]"
                 priority="1395"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d20e23214-true-d1039797e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:PID | hl7v2:ORL_O22.ORDER (rule-reference: d20e23214-true-d1039797e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e23216-true-d1039845e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/*[not(self::hl7v2:PID.1 | self::hl7v2:PID.2 | self::hl7v2:PID.3 | self::hl7v2:PID.4 | self::hl7v2:PID.5 | self::hl7v2:PID.6 | self::hl7v2:PID.7 | self::hl7v2:PID.8 | self::hl7v2:PID.9 | self::hl7v2:PID.10 | self::hl7v2:PID.11 | self::hl7v2:PID.12 | self::hl7v2:PID.13 | self::hl7v2:PID.14 | self::hl7v2:PID.15 | self::hl7v2:PID.16 | self::hl7v2:PID.17 | self::hl7v2:PID.18 | self::hl7v2:PID.19 | self::hl7v2:PID.20 | self::hl7v2:PID.21 | self::hl7v2:PID.22 | self::hl7v2:PID.23 | self::hl7v2:PID.24 | self::hl7v2:PID.25 | self::hl7v2:PID.26 | self::hl7v2:PID.27 | self::hl7v2:PID.28 | self::hl7v2:PID.29 | self::hl7v2:PID.30 | self::hl7v2:PID.31 | self::hl7v2:PID.32 | self::hl7v2:PID.33 | self::hl7v2:PID.34 | self::hl7v2:PID.35 | self::hl7v2:PID.36 | self::hl7v2:PID.37 | self::hl7v2:PID.38 | self::hl7v2:PID.39)]"
                 priority="1394"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d20e23216-true-d1039845e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:PID.1 | hl7v2:PID.2 | hl7v2:PID.3 | hl7v2:PID.4 | hl7v2:PID.5 | hl7v2:PID.6 | hl7v2:PID.7 | hl7v2:PID.8 | hl7v2:PID.9 | hl7v2:PID.10 | hl7v2:PID.11 | hl7v2:PID.12 | hl7v2:PID.13 | hl7v2:PID.14 | hl7v2:PID.15 | hl7v2:PID.16 | hl7v2:PID.17 | hl7v2:PID.18 | hl7v2:PID.19 | hl7v2:PID.20 | hl7v2:PID.21 | hl7v2:PID.22 | hl7v2:PID.23 | hl7v2:PID.24 | hl7v2:PID.25 | hl7v2:PID.26 | hl7v2:PID.27 | hl7v2:PID.28 | hl7v2:PID.29 | hl7v2:PID.30 | hl7v2:PID.31 | hl7v2:PID.32 | hl7v2:PID.33 | hl7v2:PID.34 | hl7v2:PID.35 | hl7v2:PID.36 | hl7v2:PID.37 | hl7v2:PID.38 | hl7v2:PID.39 (rule-reference: d20e23216-true-d1039845e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1039802e15-true-d1039870e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.2/*[not(self::hl7v2:CX.1 | self::hl7v2:CX.2 | self::hl7v2:CX.3 | self::hl7v2:CX.4 | self::hl7v2:CX.5 | self::hl7v2:CX.6 | self::hl7v2:CX.7 | self::hl7v2:CX.8 | self::hl7v2:CX.9 | self::hl7v2:CX.10)]"
                 priority="1393"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1039802e15-true-d1039870e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CX.1 | hl7v2:CX.2 | hl7v2:CX.3 | hl7v2:CX.4 | hl7v2:CX.5 | hl7v2:CX.6 | hl7v2:CX.7 | hl7v2:CX.8 | hl7v2:CX.9 | hl7v2:CX.10 (rule-reference: d1039802e15-true-d1039870e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1039855e221-true-d1039900e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.4/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1392"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1039855e221-true-d1039900e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d1039855e221-true-d1039900e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1039855e263-true-d1039936e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.6/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1391"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1039855e263-true-d1039936e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d1039855e263-true-d1039936e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1039855e305-true-d1039984e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1390"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1039855e305-true-d1039984e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d1039855e305-true-d1039984e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1039855e334-true-d1040056e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1389"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1039855e334-true-d1040056e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d1039855e334-true-d1040056e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1039802e26-true-d1040129e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.3/*[not(self::hl7v2:CX.1 | self::hl7v2:CX.2 | self::hl7v2:CX.3 | self::hl7v2:CX.4 | self::hl7v2:CX.5 | self::hl7v2:CX.6 | self::hl7v2:CX.7 | self::hl7v2:CX.8 | self::hl7v2:CX.9 | self::hl7v2:CX.10)]"
                 priority="1388"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1039802e26-true-d1040129e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CX.1 | hl7v2:CX.2 | hl7v2:CX.3 | hl7v2:CX.4 | hl7v2:CX.5 | hl7v2:CX.6 | hl7v2:CX.7 | hl7v2:CX.8 | hl7v2:CX.9 | hl7v2:CX.10 (rule-reference: d1039802e26-true-d1040129e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1040114e245-true-d1040159e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.4/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1387"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1040114e245-true-d1040159e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d1040114e245-true-d1040159e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1040114e287-true-d1040195e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.6/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1386"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1040114e287-true-d1040195e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d1040114e287-true-d1040195e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1040114e329-true-d1040243e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1385"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1040114e329-true-d1040243e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d1040114e329-true-d1040243e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1040114e358-true-d1040315e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1384"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1040114e358-true-d1040315e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d1040114e358-true-d1040315e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1039802e61-true-d1040388e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.4/*[not(self::hl7v2:CX.1 | self::hl7v2:CX.2 | self::hl7v2:CX.3 | self::hl7v2:CX.4 | self::hl7v2:CX.5 | self::hl7v2:CX.6 | self::hl7v2:CX.7 | self::hl7v2:CX.8 | self::hl7v2:CX.9 | self::hl7v2:CX.10)]"
                 priority="1383"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1039802e61-true-d1040388e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CX.1 | hl7v2:CX.2 | hl7v2:CX.3 | hl7v2:CX.4 | hl7v2:CX.5 | hl7v2:CX.6 | hl7v2:CX.7 | hl7v2:CX.8 | hl7v2:CX.9 | hl7v2:CX.10 (rule-reference: d1039802e61-true-d1040388e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1040373e221-true-d1040418e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.4/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1382"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1040373e221-true-d1040418e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d1040373e221-true-d1040418e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1040373e263-true-d1040454e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.6/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1381"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1040373e263-true-d1040454e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d1040373e263-true-d1040454e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1040373e305-true-d1040502e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1380"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1040373e305-true-d1040502e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d1040373e305-true-d1040502e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1040373e334-true-d1040574e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1379"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1040373e334-true-d1040574e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d1040373e334-true-d1040574e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1039802e72-true-d1040651e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.5/*[not(self::hl7v2:XPN.1 | self::hl7v2:XPN.2 | self::hl7v2:XPN.3 | self::hl7v2:XPN.4 | self::hl7v2:XPN.5 | self::hl7v2:XPN.6 | self::hl7v2:XPN.7 | self::hl7v2:XPN.8 | self::hl7v2:XPN.9 | self::hl7v2:XPN.10 | self::hl7v2:XPN.11 | self::hl7v2:XPN.12 | self::hl7v2:XPN.13 | self::hl7v2:XPN.14)]"
                 priority="1378"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1039802e72-true-d1040651e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XPN.1 | hl7v2:XPN.2 | hl7v2:XPN.3 | hl7v2:XPN.4 | hl7v2:XPN.5 | hl7v2:XPN.6 | hl7v2:XPN.7 | hl7v2:XPN.8 | hl7v2:XPN.9 | hl7v2:XPN.10 | hl7v2:XPN.11 | hl7v2:XPN.12 | hl7v2:XPN.13 | hl7v2:XPN.14 (rule-reference: d1039802e72-true-d1040651e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1040632e23-true-d1040665e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.1/*[not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="1377"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1040632e23-true-d1040665e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d1040632e23-true-d1040665e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1040632e151-true-d1040752e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.9/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1376"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1040632e151-true-d1040752e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1040632e151-true-d1040752e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1040632e164-true-d1040799e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.10/*[not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1375"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1040632e164-true-d1040799e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d1040632e164-true-d1040799e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1040792e17-true-d1040810e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.10/hl7v2:DR.1/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1374"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1040792e17-true-d1040810e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1040792e17-true-d1040810e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1040792e28-true-d1040833e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.10/hl7v2:DR.2/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1373"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1040792e28-true-d1040833e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1040792e28-true-d1040833e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1040632e194-true-d1040862e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.12/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1372"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1040632e194-true-d1040862e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1040632e194-true-d1040862e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1040632e205-true-d1040885e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.13/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1371"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1040632e205-true-d1040885e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1040632e205-true-d1040885e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1039802e92-true-d1040926e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.6/*[not(self::hl7v2:XPN.1 | self::hl7v2:XPN.2 | self::hl7v2:XPN.3 | self::hl7v2:XPN.4 | self::hl7v2:XPN.5 | self::hl7v2:XPN.6 | self::hl7v2:XPN.7 | self::hl7v2:XPN.8 | self::hl7v2:XPN.9 | self::hl7v2:XPN.10 | self::hl7v2:XPN.11 | self::hl7v2:XPN.12 | self::hl7v2:XPN.13 | self::hl7v2:XPN.14)]"
                 priority="1370"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1039802e92-true-d1040926e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XPN.1 | hl7v2:XPN.2 | hl7v2:XPN.3 | hl7v2:XPN.4 | hl7v2:XPN.5 | hl7v2:XPN.6 | hl7v2:XPN.7 | hl7v2:XPN.8 | hl7v2:XPN.9 | hl7v2:XPN.10 | hl7v2:XPN.11 | hl7v2:XPN.12 | hl7v2:XPN.13 | hl7v2:XPN.14 (rule-reference: d1039802e92-true-d1040926e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1040907e15-true-d1040940e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.1/*[not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="1369"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1040907e15-true-d1040940e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d1040907e15-true-d1040940e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1040907e142-true-d1041027e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.9/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1368"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1040907e142-true-d1041027e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1040907e142-true-d1041027e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1040907e155-true-d1041074e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.10/*[not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1367"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1040907e155-true-d1041074e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d1040907e155-true-d1041074e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1041067e17-true-d1041085e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.10/hl7v2:DR.1/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1366"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1041067e17-true-d1041085e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1041067e17-true-d1041085e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1041067e28-true-d1041108e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.10/hl7v2:DR.2/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1365"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1041067e28-true-d1041108e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1041067e28-true-d1041108e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1040907e186-true-d1041137e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.12/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1364"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1040907e186-true-d1041137e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1040907e186-true-d1041137e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1040907e197-true-d1041160e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.13/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1363"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1040907e197-true-d1041160e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1040907e197-true-d1041160e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1039802e103-true-d1041189e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.7/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1362"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1039802e103-true-d1041189e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1039802e103-true-d1041189e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1039802e138-true-d1041230e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.9/*[not(self::hl7v2:XPN.1 | self::hl7v2:XPN.2 | self::hl7v2:XPN.3 | self::hl7v2:XPN.4 | self::hl7v2:XPN.5 | self::hl7v2:XPN.6 | self::hl7v2:XPN.7 | self::hl7v2:XPN.8 | self::hl7v2:XPN.9 | self::hl7v2:XPN.10 | self::hl7v2:XPN.11 | self::hl7v2:XPN.12 | self::hl7v2:XPN.13 | self::hl7v2:XPN.14)]"
                 priority="1361"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1039802e138-true-d1041230e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XPN.1 | hl7v2:XPN.2 | hl7v2:XPN.3 | hl7v2:XPN.4 | hl7v2:XPN.5 | hl7v2:XPN.6 | hl7v2:XPN.7 | hl7v2:XPN.8 | hl7v2:XPN.9 | hl7v2:XPN.10 | hl7v2:XPN.11 | hl7v2:XPN.12 | hl7v2:XPN.13 | hl7v2:XPN.14 (rule-reference: d1039802e138-true-d1041230e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1041211e15-true-d1041244e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.1/*[not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="1360"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1041211e15-true-d1041244e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d1041211e15-true-d1041244e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1041211e142-true-d1041331e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.9/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1359"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1041211e142-true-d1041331e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1041211e142-true-d1041331e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1041211e155-true-d1041378e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.10/*[not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1358"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1041211e155-true-d1041378e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d1041211e155-true-d1041378e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1041371e17-true-d1041389e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.10/hl7v2:DR.1/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1357"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1041371e17-true-d1041389e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1041371e17-true-d1041389e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1041371e28-true-d1041412e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.10/hl7v2:DR.2/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1356"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1041371e28-true-d1041412e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1041371e28-true-d1041412e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1041211e186-true-d1041441e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.12/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1355"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1041211e186-true-d1041441e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1041211e186-true-d1041441e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1041211e197-true-d1041464e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.13/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1354"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1041211e197-true-d1041464e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1041211e197-true-d1041464e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1039802e149-true-d1041497e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.10/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1353"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1039802e149-true-d1041497e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1039802e149-true-d1041497e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1039802e162-true-d1041556e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.11/*[not(self::hl7v2:XAD.1 | self::hl7v2:XAD.2 | self::hl7v2:XAD.3 | self::hl7v2:XAD.4 | self::hl7v2:XAD.5 | self::hl7v2:XAD.6 | self::hl7v2:XAD.7 | self::hl7v2:XAD.8 | self::hl7v2:XAD.9 | self::hl7v2:XAD.10 | self::hl7v2:XAD.11 | self::hl7v2:XAD.12 | self::hl7v2:XAD.13 | self::hl7v2:XAD.14)]"
                 priority="1352"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1039802e162-true-d1041556e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XAD.1 | hl7v2:XAD.2 | hl7v2:XAD.3 | hl7v2:XAD.4 | hl7v2:XAD.5 | hl7v2:XAD.6 | hl7v2:XAD.7 | hl7v2:XAD.8 | hl7v2:XAD.9 | hl7v2:XAD.10 | hl7v2:XAD.11 | hl7v2:XAD.12 | hl7v2:XAD.13 | hl7v2:XAD.14 (rule-reference: d1039802e162-true-d1041556e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1041537e26-true-d1041568e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.1/*[not(self::hl7v2:SAD.1 | self::hl7v2:SAD.2 | self::hl7v2:SAD.3)]"
                 priority="1351"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1041537e26-true-d1041568e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:SAD.1 | hl7v2:SAD.2 | hl7v2:SAD.3 (rule-reference: d1041537e26-true-d1041568e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1041537e225-true-d1041657e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.12/*[not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1350"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1041537e225-true-d1041657e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d1041537e225-true-d1041657e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1041650e23-true-d1041668e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.12/hl7v2:DR.1/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1349"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1041650e23-true-d1041668e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1041650e23-true-d1041668e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1041650e34-true-d1041691e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.12/hl7v2:DR.2/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1348"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1041650e34-true-d1041691e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1041650e34-true-d1041691e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1041537e245-true-d1041714e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.13/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1347"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1041537e245-true-d1041714e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1041537e245-true-d1041714e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1041537e259-true-d1041737e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.14/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1346"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1041537e259-true-d1041737e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1041537e259-true-d1041737e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1039802e199-true-d1041776e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.13/*[not(self::hl7v2:XTN.1 | self::hl7v2:XTN.2 | self::hl7v2:XTN.3 | self::hl7v2:XTN.4 | self::hl7v2:XTN.5 | self::hl7v2:XTN.6 | self::hl7v2:XTN.7 | self::hl7v2:XTN.8 | self::hl7v2:XTN.9 | self::hl7v2:XTN.10 | self::hl7v2:XTN.11 | self::hl7v2:XTN.12)]"
                 priority="1345"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1039802e199-true-d1041776e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XTN.1 | hl7v2:XTN.2 | hl7v2:XTN.3 | hl7v2:XTN.4 | hl7v2:XTN.5 | hl7v2:XTN.6 | hl7v2:XTN.7 | hl7v2:XTN.8 | hl7v2:XTN.9 | hl7v2:XTN.10 | hl7v2:XTN.11 | hl7v2:XTN.12 (rule-reference: d1039802e199-true-d1041776e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1039802e213-true-d1041869e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.14/*[not(self::hl7v2:XTN.1 | self::hl7v2:XTN.2 | self::hl7v2:XTN.3 | self::hl7v2:XTN.4 | self::hl7v2:XTN.5 | self::hl7v2:XTN.6 | self::hl7v2:XTN.7 | self::hl7v2:XTN.8 | self::hl7v2:XTN.9 | self::hl7v2:XTN.10 | self::hl7v2:XTN.11 | self::hl7v2:XTN.12)]"
                 priority="1344"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1039802e213-true-d1041869e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XTN.1 | hl7v2:XTN.2 | hl7v2:XTN.3 | hl7v2:XTN.4 | hl7v2:XTN.5 | hl7v2:XTN.6 | hl7v2:XTN.7 | hl7v2:XTN.8 | hl7v2:XTN.9 | hl7v2:XTN.10 | hl7v2:XTN.11 | hl7v2:XTN.12 (rule-reference: d1039802e213-true-d1041869e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1039802e227-true-d1041956e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.15/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1343"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1039802e227-true-d1041956e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1039802e227-true-d1041956e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1039802e240-true-d1042007e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.16/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1342"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1039802e240-true-d1042007e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1039802e240-true-d1042007e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1039802e257-true-d1042058e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.17/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1341"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1039802e257-true-d1042058e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1039802e257-true-d1042058e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1039802e270-true-d1042113e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.18/*[not(self::hl7v2:CX.1 | self::hl7v2:CX.2 | self::hl7v2:CX.3 | self::hl7v2:CX.4 | self::hl7v2:CX.5 | self::hl7v2:CX.6 | self::hl7v2:CX.7 | self::hl7v2:CX.8 | self::hl7v2:CX.9 | self::hl7v2:CX.10)]"
                 priority="1340"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1039802e270-true-d1042113e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CX.1 | hl7v2:CX.2 | hl7v2:CX.3 | hl7v2:CX.4 | hl7v2:CX.5 | hl7v2:CX.6 | hl7v2:CX.7 | hl7v2:CX.8 | hl7v2:CX.9 | hl7v2:CX.10 (rule-reference: d1039802e270-true-d1042113e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1042098e221-true-d1042143e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.4/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1339"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1042098e221-true-d1042143e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d1042098e221-true-d1042143e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1042098e263-true-d1042179e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.6/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1338"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1042098e263-true-d1042179e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d1042098e263-true-d1042179e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1042098e305-true-d1042227e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1337"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1042098e305-true-d1042227e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d1042098e305-true-d1042227e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1042098e334-true-d1042299e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1336"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1042098e334-true-d1042299e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d1042098e334-true-d1042299e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1039802e292-true-d1042371e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.20/*[not(self::hl7v2:DLN.1 | self::hl7v2:DLN.2 | self::hl7v2:DLN.3)]"
                 priority="1335"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1039802e292-true-d1042371e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DLN.1 | hl7v2:DLN.2 | hl7v2:DLN.3 (rule-reference: d1039802e292-true-d1042371e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1039802e303-true-d1042408e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.21/*[not(self::hl7v2:CX.1 | self::hl7v2:CX.2 | self::hl7v2:CX.3 | self::hl7v2:CX.4 | self::hl7v2:CX.5 | self::hl7v2:CX.6 | self::hl7v2:CX.7 | self::hl7v2:CX.8 | self::hl7v2:CX.9 | self::hl7v2:CX.10)]"
                 priority="1334"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1039802e303-true-d1042408e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CX.1 | hl7v2:CX.2 | hl7v2:CX.3 | hl7v2:CX.4 | hl7v2:CX.5 | hl7v2:CX.6 | hl7v2:CX.7 | hl7v2:CX.8 | hl7v2:CX.9 | hl7v2:CX.10 (rule-reference: d1039802e303-true-d1042408e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1042393e221-true-d1042438e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.4/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1333"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1042393e221-true-d1042438e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d1042393e221-true-d1042438e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1042393e263-true-d1042474e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.6/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1332"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1042393e263-true-d1042474e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d1042393e263-true-d1042474e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1042393e305-true-d1042522e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1331"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1042393e305-true-d1042522e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d1042393e305-true-d1042522e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1042393e334-true-d1042594e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1330"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1042393e334-true-d1042594e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d1042393e334-true-d1042594e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1039802e314-true-d1042663e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.22/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1329"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1039802e314-true-d1042663e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1039802e314-true-d1042663e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1039802e363-true-d1042732e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.26/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1328"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1039802e363-true-d1042732e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1039802e363-true-d1042732e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1039802e376-true-d1042783e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.27/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1327"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1039802e376-true-d1042783e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1039802e376-true-d1042783e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1039802e389-true-d1042834e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.28/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1326"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1039802e389-true-d1042834e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1039802e389-true-d1042834e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1039802e402-true-d1042881e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.29/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1325"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1039802e402-true-d1042881e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1039802e402-true-d1042881e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1039802e452-true-d1042922e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.33/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1324"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1039802e452-true-d1042922e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1039802e452-true-d1042922e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1039802e464-true-d1042946e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.34/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1323"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1039802e464-true-d1042946e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d1039802e464-true-d1042946e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1039802e475-true-d1042979e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.35/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1322"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1039802e475-true-d1042979e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1039802e475-true-d1042979e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1039802e488-true-d1043030e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.36/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1321"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1039802e488-true-d1043030e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1039802e488-true-d1043030e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1039802e512-true-d1043087e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.38/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1320"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1039802e512-true-d1043087e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1039802e512-true-d1043087e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1039802e525-true-d1043141e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:PID/hl7v2:PID.39/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1319"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1039802e525-true-d1043141e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d1039802e525-true-d1043141e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e23218-true-d1043204e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/*[not(self::hl7v2:ORC | self::hl7v2:ORL_O22.TIMING | self::hl7v2:ORL_O22.OBSERVATION_REQUEST)]"
                 priority="1318"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d20e23218-true-d1043204e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:ORC | hl7v2:ORL_O22.TIMING | hl7v2:ORL_O22.OBSERVATION_REQUEST (rule-reference: d20e23218-true-d1043204e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e23220-true-d1043243e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/*[not(self::hl7v2:ORC.1 | self::hl7v2:ORC.2 | self::hl7v2:ORC.3 | self::hl7v2:ORC.4 | self::hl7v2:ORC.5 | self::hl7v2:ORC.6 | self::hl7v2:ORC.7 | self::hl7v2:ORC.8 | self::hl7v2:ORC.9 | self::hl7v2:ORC.10 | self::hl7v2:ORC.11 | self::hl7v2:ORC.12 | self::hl7v2:ORC.13 | self::hl7v2:ORC.14 | self::hl7v2:ORC.15 | self::hl7v2:ORC.16 | self::hl7v2:ORC.17 | self::hl7v2:ORC.18 | self::hl7v2:ORC.19 | self::hl7v2:ORC.20 | self::hl7v2:ORC.21 | self::hl7v2:ORC.22 | self::hl7v2:ORC.23 | self::hl7v2:ORC.24 | self::hl7v2:ORC.25 | self::hl7v2:ORC.26 | self::hl7v2:ORC.27 | self::hl7v2:ORC.28 | self::hl7v2:ORC.29 | self::hl7v2:ORC.30)]"
                 priority="1317"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d20e23220-true-d1043243e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:ORC.1 | hl7v2:ORC.2 | hl7v2:ORC.3 | hl7v2:ORC.4 | hl7v2:ORC.5 | hl7v2:ORC.6 | hl7v2:ORC.7 | hl7v2:ORC.8 | hl7v2:ORC.9 | hl7v2:ORC.10 | hl7v2:ORC.11 | hl7v2:ORC.12 | hl7v2:ORC.13 | hl7v2:ORC.14 | hl7v2:ORC.15 | hl7v2:ORC.16 | hl7v2:ORC.17 | hl7v2:ORC.18 | hl7v2:ORC.19 | hl7v2:ORC.20 | hl7v2:ORC.21 | hl7v2:ORC.22 | hl7v2:ORC.23 | hl7v2:ORC.24 | hl7v2:ORC.25 | hl7v2:ORC.26 | hl7v2:ORC.27 | hl7v2:ORC.28 | hl7v2:ORC.29 | hl7v2:ORC.30 (rule-reference: d20e23220-true-d1043243e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1043209e102-true-d1043262e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.2/*[not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1316"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1043209e102-true-d1043262e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d1043209e102-true-d1043262e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1043209e119-true-d1043299e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.3/*[not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1315"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1043209e119-true-d1043299e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d1043209e119-true-d1043299e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1043209e136-true-d1043336e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.4/*[not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1314"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1043209e136-true-d1043336e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d1043209e136-true-d1043336e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1043209e179-true-d1043393e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.7/*[not(self::hl7v2:TQ.1 | self::hl7v2:TQ.2 | self::hl7v2:TQ.3 | self::hl7v2:TQ.4 | self::hl7v2:TQ.5 | self::hl7v2:TQ.6 | self::hl7v2:TQ.7 | self::hl7v2:TQ.8 | self::hl7v2:TQ.9 | self::hl7v2:TQ.10 | self::hl7v2:TQ.11 | self::hl7v2:TQ.12)]"
                 priority="1313"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1043209e179-true-d1043393e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TQ.1 | hl7v2:TQ.2 | hl7v2:TQ.3 | hl7v2:TQ.4 | hl7v2:TQ.5 | hl7v2:TQ.6 | hl7v2:TQ.7 | hl7v2:TQ.8 | hl7v2:TQ.9 | hl7v2:TQ.10 | hl7v2:TQ.11 | hl7v2:TQ.12 (rule-reference: d1043209e179-true-d1043393e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1043376e15-true-d1043404e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/*[not(self::hl7v2:CQ.1 | self::hl7v2:CQ.2)]"
                 priority="1312"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1043376e15-true-d1043404e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CQ.1 | hl7v2:CQ.2 (rule-reference: d1043376e15-true-d1043404e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1043397e31-true-d1043425e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/hl7v2:CQ.2/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1311"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1043397e31-true-d1043425e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1043397e31-true-d1043425e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1043376e35-true-d1043472e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.2/*[not(self::hl7v2:RI.1 | self::hl7v2:RI.2)]"
                 priority="1310"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1043376e35-true-d1043472e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:RI.1 | hl7v2:RI.2 (rule-reference: d1043376e35-true-d1043472e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1043376e189-true-d1043501e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.4/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1309"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1043376e189-true-d1043501e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1043376e189-true-d1043501e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1043376e206-true-d1043524e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.5/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1308"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1043376e206-true-d1043524e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1043376e206-true-d1043524e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1043376e461-true-d1043558e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.8/*[not(self::hl7v2:escape)]"
                 priority="1307"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1043376e461-true-d1043558e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d1043376e461-true-d1043558e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1043552e11-true-d1043568e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.8/hl7v2:escape/*[not(self::hl7v2:escape)]"
                 priority="1306"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1043552e11-true-d1043568e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d1043552e11-true-d1043568e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1043562e5-true-d1043578e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.8/hl7v2:escape/hl7v2:escape/*[not(self::hl7v2:escape)]"
                 priority="1305"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1043562e5-true-d1043578e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d1043562e5-true-d1043578e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1043376e485-true-d1043608e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/*[not(self::hl7v2:OSD.1 | self::hl7v2:OSD.2 | self::hl7v2:OSD.3 | self::hl7v2:OSD.4 | self::hl7v2:OSD.5 | self::hl7v2:OSD.6 | self::hl7v2:OSD.7 | self::hl7v2:OSD.8 | self::hl7v2:OSD.9 | self::hl7v2:OSD.10 | self::hl7v2:OSD.11)]"
                 priority="1304"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1043376e485-true-d1043608e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:OSD.1 | hl7v2:OSD.2 | hl7v2:OSD.3 | hl7v2:OSD.4 | hl7v2:OSD.5 | hl7v2:OSD.6 | hl7v2:OSD.7 | hl7v2:OSD.8 | hl7v2:OSD.9 | hl7v2:OSD.10 | hl7v2:OSD.11 (rule-reference: d1043376e485-true-d1043608e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1043376e505-true-d1043689e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.11/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1303"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1043376e505-true-d1043689e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1043376e505-true-d1043689e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1043209e190-true-d1043742e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.8/*[not(self::hl7v2:EIP.1 | self::hl7v2:EIP.2)]"
                 priority="1302"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1043209e190-true-d1043742e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EIP.1 | hl7v2:EIP.2 (rule-reference: d1043209e190-true-d1043742e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1043735e18-true-d1043755e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.1/*[not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1301"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1043735e18-true-d1043755e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d1043735e18-true-d1043755e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1043735e47-true-d1043792e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.2/*[not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1300"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1043735e47-true-d1043792e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d1043735e47-true-d1043792e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1043209e204-true-d1043827e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.9/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1299"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1043209e204-true-d1043827e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1043209e204-true-d1043827e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1043209e215-true-d1043871e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/*[not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="1298"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1043209e215-true-d1043871e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d1043209e215-true-d1043871e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1043843e32-true-d1043891e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.2/*[not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="1297"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1043843e32-true-d1043891e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d1043843e32-true-d1043891e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1043843e123-true-d1043969e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.9/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1296"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1043843e123-true-d1043969e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d1043843e123-true-d1043969e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1043843e215-true-d1044023e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.14/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1295"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1043843e215-true-d1044023e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d1043843e215-true-d1044023e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1043843e275-true-d1044062e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.16/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1294"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1043843e275-true-d1044062e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1043843e275-true-d1044062e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1043843e288-true-d1044109e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.17/*[not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1293"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1043843e288-true-d1044109e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d1043843e288-true-d1044109e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1044102e17-true-d1044120e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.17/hl7v2:DR.1/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1292"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1044102e17-true-d1044120e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1044102e17-true-d1044120e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1044102e28-true-d1044143e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.17/hl7v2:DR.2/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1291"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1044102e28-true-d1044143e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1044102e28-true-d1044143e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1043843e318-true-d1044172e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.19/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1290"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1043843e318-true-d1044172e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1043843e318-true-d1044172e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1043843e329-true-d1044195e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.20/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1289"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1043843e329-true-d1044195e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1043843e329-true-d1044195e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1043843e351-true-d1044231e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1288"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1043843e351-true-d1044231e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d1043843e351-true-d1044231e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1043843e369-true-d1044303e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1287"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1043843e369-true-d1044303e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d1043843e369-true-d1044303e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1043209e226-true-d1044389e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/*[not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="1286"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1043209e226-true-d1044389e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d1043209e226-true-d1044389e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1044361e32-true-d1044409e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.2/*[not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="1285"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1044361e32-true-d1044409e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d1044361e32-true-d1044409e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1044361e123-true-d1044487e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.9/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1284"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1044361e123-true-d1044487e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d1044361e123-true-d1044487e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1044361e215-true-d1044541e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.14/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1283"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1044361e215-true-d1044541e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d1044361e215-true-d1044541e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1044361e275-true-d1044580e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.16/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1282"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1044361e275-true-d1044580e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1044361e275-true-d1044580e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1044361e288-true-d1044627e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.17/*[not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1281"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1044361e288-true-d1044627e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d1044361e288-true-d1044627e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1044620e17-true-d1044638e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.17/hl7v2:DR.1/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1280"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1044620e17-true-d1044638e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1044620e17-true-d1044638e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1044620e28-true-d1044661e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.17/hl7v2:DR.2/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1279"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1044620e28-true-d1044661e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1044620e28-true-d1044661e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1044361e318-true-d1044690e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.19/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1278"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1044361e318-true-d1044690e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1044361e318-true-d1044690e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1044361e329-true-d1044713e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.20/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1277"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1044361e329-true-d1044713e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1044361e329-true-d1044713e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1044361e351-true-d1044749e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1276"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1044361e351-true-d1044749e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d1044361e351-true-d1044749e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1044361e369-true-d1044821e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1275"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1044361e369-true-d1044821e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d1044361e369-true-d1044821e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1043209e238-true-d1044907e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/*[not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="1274"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1043209e238-true-d1044907e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d1043209e238-true-d1044907e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1044879e32-true-d1044927e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.2/*[not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="1273"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1044879e32-true-d1044927e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d1044879e32-true-d1044927e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1044879e123-true-d1045005e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.9/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1272"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1044879e123-true-d1045005e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d1044879e123-true-d1045005e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1044879e215-true-d1045059e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.14/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1271"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1044879e215-true-d1045059e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d1044879e215-true-d1045059e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1044879e275-true-d1045098e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.16/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1270"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1044879e275-true-d1045098e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1044879e275-true-d1045098e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1044879e288-true-d1045145e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.17/*[not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1269"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1044879e288-true-d1045145e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d1044879e288-true-d1045145e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1045138e17-true-d1045156e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.17/hl7v2:DR.1/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1268"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1045138e17-true-d1045156e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1045138e17-true-d1045156e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1045138e28-true-d1045179e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.17/hl7v2:DR.2/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1267"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1045138e28-true-d1045179e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1045138e28-true-d1045179e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1044879e318-true-d1045208e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.19/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1266"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1044879e318-true-d1045208e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1044879e318-true-d1045208e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1044879e329-true-d1045231e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.20/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1265"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1044879e329-true-d1045231e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1044879e329-true-d1045231e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1044879e351-true-d1045267e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1264"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1044879e351-true-d1045267e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d1044879e351-true-d1045267e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1044879e369-true-d1045339e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1263"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1044879e369-true-d1045339e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d1044879e369-true-d1045339e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1043209e249-true-d1045413e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.13/*[not(self::hl7v2:PL.1 | self::hl7v2:PL.2 | self::hl7v2:PL.3 | self::hl7v2:PL.4 | self::hl7v2:PL.5 | self::hl7v2:PL.6 | self::hl7v2:PL.7 | self::hl7v2:PL.8 | self::hl7v2:PL.9 | self::hl7v2:PL.10 | self::hl7v2:PL.11)]"
                 priority="1262"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1043209e249-true-d1045413e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:PL.1 | hl7v2:PL.2 | hl7v2:PL.3 | hl7v2:PL.4 | hl7v2:PL.5 | hl7v2:PL.6 | hl7v2:PL.7 | hl7v2:PL.8 | hl7v2:PL.9 | hl7v2:PL.10 | hl7v2:PL.11 (rule-reference: d1043209e249-true-d1045413e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1045397e48-true-d1045443e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.4/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1261"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1045397e48-true-d1045443e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d1045397e48-true-d1045443e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1045397e125-true-d1045504e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.10/*[not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1260"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1045397e125-true-d1045504e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d1045397e125-true-d1045504e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1045397e134-true-d1045540e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.11/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1259"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1045397e134-true-d1045540e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d1045397e134-true-d1045540e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1043209e260-true-d1045579e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.14/*[not(self::hl7v2:XTN.1 | self::hl7v2:XTN.2 | self::hl7v2:XTN.3 | self::hl7v2:XTN.4 | self::hl7v2:XTN.5 | self::hl7v2:XTN.6 | self::hl7v2:XTN.7 | self::hl7v2:XTN.8 | self::hl7v2:XTN.9 | self::hl7v2:XTN.10 | self::hl7v2:XTN.11 | self::hl7v2:XTN.12)]"
                 priority="1258"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1043209e260-true-d1045579e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XTN.1 | hl7v2:XTN.2 | hl7v2:XTN.3 | hl7v2:XTN.4 | hl7v2:XTN.5 | hl7v2:XTN.6 | hl7v2:XTN.7 | hl7v2:XTN.8 | hl7v2:XTN.9 | hl7v2:XTN.10 | hl7v2:XTN.11 | hl7v2:XTN.12 (rule-reference: d1043209e260-true-d1045579e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1043209e271-true-d1045662e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.15/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1257"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1043209e271-true-d1045662e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1043209e271-true-d1045662e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1043209e282-true-d1045689e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.16/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1256"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1043209e282-true-d1045689e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1043209e282-true-d1045689e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1043209e296-true-d1045740e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.17/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1255"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1043209e296-true-d1045740e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1043209e296-true-d1045740e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1043209e307-true-d1045791e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.18/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1254"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1043209e307-true-d1045791e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1043209e307-true-d1045791e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1043209e318-true-d1045859e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/*[not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="1253"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1043209e318-true-d1045859e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d1043209e318-true-d1045859e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1045831e32-true-d1045879e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.2/*[not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="1252"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1045831e32-true-d1045879e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d1045831e32-true-d1045879e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1045831e123-true-d1045957e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.9/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1251"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1045831e123-true-d1045957e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d1045831e123-true-d1045957e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1045831e215-true-d1046011e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.14/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1250"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1045831e215-true-d1046011e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d1045831e215-true-d1046011e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1045831e275-true-d1046050e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.16/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1249"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1045831e275-true-d1046050e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1045831e275-true-d1046050e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1045831e288-true-d1046097e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.17/*[not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1248"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1045831e288-true-d1046097e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d1045831e288-true-d1046097e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1046090e17-true-d1046108e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.17/hl7v2:DR.1/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1247"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1046090e17-true-d1046108e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1046090e17-true-d1046108e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1046090e28-true-d1046131e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.17/hl7v2:DR.2/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1246"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1046090e28-true-d1046131e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1046090e28-true-d1046131e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1045831e318-true-d1046160e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.19/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1245"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1045831e318-true-d1046160e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1045831e318-true-d1046160e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1045831e329-true-d1046183e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.20/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1244"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1045831e329-true-d1046183e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1045831e329-true-d1046183e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1045831e351-true-d1046219e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1243"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1045831e351-true-d1046219e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d1045831e351-true-d1046219e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1045831e369-true-d1046291e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1242"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1045831e369-true-d1046291e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d1045831e369-true-d1046291e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1043209e329-true-d1046360e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.20/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1241"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1043209e329-true-d1046360e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1043209e329-true-d1046360e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1043209e342-true-d1046415e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.21/*[not(self::hl7v2:XON.1 | self::hl7v2:XON.2 | self::hl7v2:XON.3 | self::hl7v2:XON.4 | self::hl7v2:XON.5 | self::hl7v2:XON.6 | self::hl7v2:XON.7 | self::hl7v2:XON.8 | self::hl7v2:XON.9 | self::hl7v2:XON.10)]"
                 priority="1240"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1043209e342-true-d1046415e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XON.1 | hl7v2:XON.2 | hl7v2:XON.3 | hl7v2:XON.4 | hl7v2:XON.5 | hl7v2:XON.6 | hl7v2:XON.7 | hl7v2:XON.8 | hl7v2:XON.9 | hl7v2:XON.10 (rule-reference: d1043209e342-true-d1046415e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1046400e80-true-d1046457e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.6/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1239"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1046400e80-true-d1046457e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d1046400e80-true-d1046457e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1046400e119-true-d1046493e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.8/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1238"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1046400e119-true-d1046493e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d1046400e119-true-d1046493e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1043209e353-true-d1046546e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.22/*[not(self::hl7v2:XAD.1 | self::hl7v2:XAD.2 | self::hl7v2:XAD.3 | self::hl7v2:XAD.4 | self::hl7v2:XAD.5 | self::hl7v2:XAD.6 | self::hl7v2:XAD.7 | self::hl7v2:XAD.8 | self::hl7v2:XAD.9 | self::hl7v2:XAD.10 | self::hl7v2:XAD.11 | self::hl7v2:XAD.12 | self::hl7v2:XAD.13 | self::hl7v2:XAD.14)]"
                 priority="1237"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1043209e353-true-d1046546e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XAD.1 | hl7v2:XAD.2 | hl7v2:XAD.3 | hl7v2:XAD.4 | hl7v2:XAD.5 | hl7v2:XAD.6 | hl7v2:XAD.7 | hl7v2:XAD.8 | hl7v2:XAD.9 | hl7v2:XAD.10 | hl7v2:XAD.11 | hl7v2:XAD.12 | hl7v2:XAD.13 | hl7v2:XAD.14 (rule-reference: d1043209e353-true-d1046546e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1046527e15-true-d1046558e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.1/*[not(self::hl7v2:SAD.1 | self::hl7v2:SAD.2 | self::hl7v2:SAD.3)]"
                 priority="1236"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1046527e15-true-d1046558e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:SAD.1 | hl7v2:SAD.2 | hl7v2:SAD.3 (rule-reference: d1046527e15-true-d1046558e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1046527e214-true-d1046647e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.12/*[not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1235"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1046527e214-true-d1046647e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d1046527e214-true-d1046647e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1046640e23-true-d1046658e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.12/hl7v2:DR.1/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1234"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1046640e23-true-d1046658e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1046640e23-true-d1046658e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1046640e34-true-d1046681e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.12/hl7v2:DR.2/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1233"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1046640e34-true-d1046681e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1046640e34-true-d1046681e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1046527e234-true-d1046704e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.13/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1232"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1046527e234-true-d1046704e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1046527e234-true-d1046704e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1046527e248-true-d1046727e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.14/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1231"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1046527e248-true-d1046727e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1046527e248-true-d1046727e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1043209e365-true-d1046760e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.23/*[not(self::hl7v2:XTN.1 | self::hl7v2:XTN.2 | self::hl7v2:XTN.3 | self::hl7v2:XTN.4 | self::hl7v2:XTN.5 | self::hl7v2:XTN.6 | self::hl7v2:XTN.7 | self::hl7v2:XTN.8 | self::hl7v2:XTN.9 | self::hl7v2:XTN.10 | self::hl7v2:XTN.11 | self::hl7v2:XTN.12)]"
                 priority="1230"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1043209e365-true-d1046760e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XTN.1 | hl7v2:XTN.2 | hl7v2:XTN.3 | hl7v2:XTN.4 | hl7v2:XTN.5 | hl7v2:XTN.6 | hl7v2:XTN.7 | hl7v2:XTN.8 | hl7v2:XTN.9 | hl7v2:XTN.10 | hl7v2:XTN.11 | hl7v2:XTN.12 (rule-reference: d1043209e365-true-d1046760e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1043209e376-true-d1046855e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.24/*[not(self::hl7v2:XAD.1 | self::hl7v2:XAD.2 | self::hl7v2:XAD.3 | self::hl7v2:XAD.4 | self::hl7v2:XAD.5 | self::hl7v2:XAD.6 | self::hl7v2:XAD.7 | self::hl7v2:XAD.8 | self::hl7v2:XAD.9 | self::hl7v2:XAD.10 | self::hl7v2:XAD.11 | self::hl7v2:XAD.12 | self::hl7v2:XAD.13 | self::hl7v2:XAD.14)]"
                 priority="1229"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1043209e376-true-d1046855e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XAD.1 | hl7v2:XAD.2 | hl7v2:XAD.3 | hl7v2:XAD.4 | hl7v2:XAD.5 | hl7v2:XAD.6 | hl7v2:XAD.7 | hl7v2:XAD.8 | hl7v2:XAD.9 | hl7v2:XAD.10 | hl7v2:XAD.11 | hl7v2:XAD.12 | hl7v2:XAD.13 | hl7v2:XAD.14 (rule-reference: d1043209e376-true-d1046855e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1046836e15-true-d1046867e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.1/*[not(self::hl7v2:SAD.1 | self::hl7v2:SAD.2 | self::hl7v2:SAD.3)]"
                 priority="1228"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1046836e15-true-d1046867e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:SAD.1 | hl7v2:SAD.2 | hl7v2:SAD.3 (rule-reference: d1046836e15-true-d1046867e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1046836e214-true-d1046956e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.12/*[not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1227"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1046836e214-true-d1046956e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d1046836e214-true-d1046956e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1046949e23-true-d1046967e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.12/hl7v2:DR.1/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1226"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1046949e23-true-d1046967e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1046949e23-true-d1046967e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1046949e34-true-d1046990e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.12/hl7v2:DR.2/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1225"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1046949e34-true-d1046990e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1046949e34-true-d1046990e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1046836e234-true-d1047013e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.13/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1224"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1046836e234-true-d1047013e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1046836e234-true-d1047013e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1046836e248-true-d1047036e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.14/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1223"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1046836e248-true-d1047036e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1046836e248-true-d1047036e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1043209e387-true-d1047066e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.25/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1222"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1043209e387-true-d1047066e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d1043209e387-true-d1047066e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1043209e398-true-d1047138e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.26/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1221"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1043209e398-true-d1047138e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d1043209e398-true-d1047138e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1043209e411-true-d1047203e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.27/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1220"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1043209e411-true-d1047203e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1043209e411-true-d1047203e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1043209e422-true-d1047233e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.28/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1219"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1043209e422-true-d1047233e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d1043209e422-true-d1047233e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1043209e435-true-d1047305e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.29/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1218"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1043209e435-true-d1047305e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d1043209e435-true-d1047305e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1043209e448-true-d1047377e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORC/hl7v2:ORC.30/*[not(self::hl7v2:CNE.1 | self::hl7v2:CNE.2 | self::hl7v2:CNE.3 | self::hl7v2:CNE.4 | self::hl7v2:CNE.5 | self::hl7v2:CNE.6 | self::hl7v2:CNE.7 | self::hl7v2:CNE.8 | self::hl7v2:CNE.9)]"
                 priority="1217"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1043209e448-true-d1047377e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CNE.1 | hl7v2:CNE.2 | hl7v2:CNE.3 | hl7v2:CNE.4 | hl7v2:CNE.5 | hl7v2:CNE.6 | hl7v2:CNE.7 | hl7v2:CNE.8 | hl7v2:CNE.9 (rule-reference: d1043209e448-true-d1047377e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e23222-true-d1047439e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/*[not(self::hl7v2:TQ1 | self::hl7v2:TQ2)]"
                 priority="1216"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d20e23222-true-d1047439e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TQ1 | hl7v2:TQ2 (rule-reference: d20e23222-true-d1047439e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e23224-true-d1047462e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/*[not(self::hl7v2:TQ1.1 | self::hl7v2:TQ1.2 | self::hl7v2:TQ1.3 | self::hl7v2:TQ1.4 | self::hl7v2:TQ1.5 | self::hl7v2:TQ1.6 | self::hl7v2:TQ1.7 | self::hl7v2:TQ1.8 | self::hl7v2:TQ1.9 | self::hl7v2:TQ1.10 | self::hl7v2:TQ1.11 | self::hl7v2:TQ1.12 | self::hl7v2:TQ1.13 | self::hl7v2:TQ1.14)]"
                 priority="1215"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d20e23224-true-d1047462e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TQ1.1 | hl7v2:TQ1.2 | hl7v2:TQ1.3 | hl7v2:TQ1.4 | hl7v2:TQ1.5 | hl7v2:TQ1.6 | hl7v2:TQ1.7 | hl7v2:TQ1.8 | hl7v2:TQ1.9 | hl7v2:TQ1.10 | hl7v2:TQ1.11 | hl7v2:TQ1.12 | hl7v2:TQ1.13 | hl7v2:TQ1.14 (rule-reference: d20e23224-true-d1047462e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1047444e12-true-d1047479e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.2/*[not(self::hl7v2:CQ.1 | self::hl7v2:CQ.2)]"
                 priority="1214"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1047444e12-true-d1047479e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CQ.1 | hl7v2:CQ.2 (rule-reference: d1047444e12-true-d1047479e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1047472e26-true-d1047500e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.2/hl7v2:CQ.2/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1213"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1047472e26-true-d1047500e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1047472e26-true-d1047500e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1047444e23-true-d1047556e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.3/*[not(self::hl7v2:RPT.1 | self::hl7v2:RPT.2 | self::hl7v2:RPT.3 | self::hl7v2:RPT.4 | self::hl7v2:RPT.5 | self::hl7v2:RPT.6 | self::hl7v2:RPT.7 | self::hl7v2:RPT.8 | self::hl7v2:RPT.9 | self::hl7v2:RPT.10 | self::hl7v2:RPT.11)]"
                 priority="1212"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1047444e23-true-d1047556e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:RPT.1 | hl7v2:RPT.2 | hl7v2:RPT.3 | hl7v2:RPT.4 | hl7v2:RPT.5 | hl7v2:RPT.6 | hl7v2:RPT.7 | hl7v2:RPT.8 | hl7v2:RPT.9 | hl7v2:RPT.10 | hl7v2:RPT.11 (rule-reference: d1047444e23-true-d1047556e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1047540e18-true-d1047574e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1211"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1047540e18-true-d1047574e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d1047540e18-true-d1047574e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1047444e47-true-d1047705e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.5/*[not(self::hl7v2:CQ.1 | self::hl7v2:CQ.2)]"
                 priority="1210"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1047444e47-true-d1047705e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CQ.1 | hl7v2:CQ.2 (rule-reference: d1047444e47-true-d1047705e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1047698e26-true-d1047726e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.5/hl7v2:CQ.2/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1209"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1047698e26-true-d1047726e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1047698e26-true-d1047726e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1047444e58-true-d1047773e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.6/*[not(self::hl7v2:CQ.1 | self::hl7v2:CQ.2)]"
                 priority="1208"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1047444e58-true-d1047773e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CQ.1 | hl7v2:CQ.2 (rule-reference: d1047444e58-true-d1047773e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1047766e26-true-d1047794e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.6/hl7v2:CQ.2/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1207"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1047766e26-true-d1047794e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1047766e26-true-d1047794e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1047444e69-true-d1047841e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.7/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1206"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1047444e69-true-d1047841e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1047444e69-true-d1047841e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1047444e80-true-d1047864e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.8/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1205"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1047444e80-true-d1047864e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1047444e80-true-d1047864e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1047444e91-true-d1047894e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.9/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1204"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1047444e91-true-d1047894e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d1047444e91-true-d1047894e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1047444e104-true-d1047958e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.10/*[not(self::hl7v2:escape)]"
                 priority="1203"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1047444e104-true-d1047958e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d1047444e104-true-d1047958e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1047952e15-true-d1047968e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.10/hl7v2:escape/*[not(self::hl7v2:escape)]"
                 priority="1202"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1047952e15-true-d1047968e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d1047952e15-true-d1047968e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1047962e5-true-d1047978e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.10/hl7v2:escape/hl7v2:escape/*[not(self::hl7v2:escape)]"
                 priority="1201"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1047962e5-true-d1047978e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d1047962e5-true-d1047978e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1047444e115-true-d1047992e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.11/*[not(self::hl7v2:escape)]"
                 priority="1200"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1047444e115-true-d1047992e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d1047444e115-true-d1047992e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1047986e15-true-d1048002e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.11/hl7v2:escape/*[not(self::hl7v2:escape)]"
                 priority="1199"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1047986e15-true-d1048002e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d1047986e15-true-d1048002e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1047996e5-true-d1048012e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.11/hl7v2:escape/hl7v2:escape/*[not(self::hl7v2:escape)]"
                 priority="1198"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1047996e5-true-d1048012e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d1047996e5-true-d1048012e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1047444e140-true-d1048033e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.13/*[not(self::hl7v2:CQ.1 | self::hl7v2:CQ.2)]"
                 priority="1197"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1047444e140-true-d1048033e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CQ.1 | hl7v2:CQ.2 (rule-reference: d1047444e140-true-d1048033e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1048026e26-true-d1048054e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ1/hl7v2:TQ1.13/hl7v2:CQ.2/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1196"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1048026e26-true-d1048054e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1048026e26-true-d1048054e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e23226-true-d1048115e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ2/*[not(self::hl7v2:TQ2.1 | self::hl7v2:TQ2.2 | self::hl7v2:TQ2.3 | self::hl7v2:TQ2.4 | self::hl7v2:TQ2.5 | self::hl7v2:TQ2.6 | self::hl7v2:TQ2.7 | self::hl7v2:TQ2.8 | self::hl7v2:TQ2.9 | self::hl7v2:TQ2.10)]"
                 priority="1195"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d20e23226-true-d1048115e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TQ2.1 | hl7v2:TQ2.2 | hl7v2:TQ2.3 | hl7v2:TQ2.4 | hl7v2:TQ2.5 | hl7v2:TQ2.6 | hl7v2:TQ2.7 | hl7v2:TQ2.8 | hl7v2:TQ2.9 | hl7v2:TQ2.10 (rule-reference: d20e23226-true-d1048115e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1048101e25-true-d1048140e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ2/hl7v2:TQ2.3/*[not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1194"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1048101e25-true-d1048140e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d1048101e25-true-d1048140e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1048101e36-true-d1048177e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ2/hl7v2:TQ2.4/*[not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1193"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1048101e36-true-d1048177e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d1048101e36-true-d1048177e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1048101e47-true-d1048214e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ2/hl7v2:TQ2.5/*[not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1192"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1048101e47-true-d1048214e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d1048101e47-true-d1048214e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1048101e84-true-d1048261e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ2/hl7v2:TQ2.8/*[not(self::hl7v2:CQ.1 | self::hl7v2:CQ.2)]"
                 priority="1191"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1048101e84-true-d1048261e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CQ.1 | hl7v2:CQ.2 (rule-reference: d1048101e84-true-d1048261e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1048254e26-true-d1048282e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.TIMING/hl7v2:TQ2/hl7v2:TQ2.8/hl7v2:CQ.2/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1190"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1048254e26-true-d1048282e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1048254e26-true-d1048282e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e23229-true-d1048338e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/*[not(self::hl7v2:OBR | self::hl7v2:ORL_O22.SPECIMEN)]"
                 priority="1189"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d20e23229-true-d1048338e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:OBR | hl7v2:ORL_O22.SPECIMEN (rule-reference: d20e23229-true-d1048338e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e23231-true-d1048396e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/*[not(self::hl7v2:OBR.1 | self::hl7v2:OBR.2 | self::hl7v2:OBR.3 | self::hl7v2:OBR.4 | self::hl7v2:OBR.5 | self::hl7v2:OBR.6 | self::hl7v2:OBR.7 | self::hl7v2:OBR.8 | self::hl7v2:OBR.9 | self::hl7v2:OBR.10 | self::hl7v2:OBR.11 | self::hl7v2:OBR.12 | self::hl7v2:OBR.13 | self::hl7v2:OBR.14 | self::hl7v2:OBR.15 | self::hl7v2:OBR.16 | self::hl7v2:OBR.17 | self::hl7v2:OBR.18 | self::hl7v2:OBR.19 | self::hl7v2:OBR.20 | self::hl7v2:OBR.21 | self::hl7v2:OBR.22 | self::hl7v2:OBR.23 | self::hl7v2:OBR.24 | self::hl7v2:OBR.25 | self::hl7v2:OBR.26 | self::hl7v2:OBR.27 | self::hl7v2:OBR.28 | self::hl7v2:OBR.29 | self::hl7v2:OBR.30 | self::hl7v2:OBR.31 | self::hl7v2:OBR.32 | self::hl7v2:OBR.33 | self::hl7v2:OBR.34 | self::hl7v2:OBR.35 | self::hl7v2:OBR.36 | self::hl7v2:OBR.37 | self::hl7v2:OBR.38 | self::hl7v2:OBR.39 | self::hl7v2:OBR.40 | self::hl7v2:OBR.41 | self::hl7v2:OBR.42 | self::hl7v2:OBR.43 | self::hl7v2:OBR.44 | self::hl7v2:OBR.45 | self::hl7v2:OBR.46 | self::hl7v2:OBR.47 | self::hl7v2:OBR.48 | self::hl7v2:OBR.49)]"
                 priority="1188"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d20e23231-true-d1048396e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:OBR.1 | hl7v2:OBR.2 | hl7v2:OBR.3 | hl7v2:OBR.4 | hl7v2:OBR.5 | hl7v2:OBR.6 | hl7v2:OBR.7 | hl7v2:OBR.8 | hl7v2:OBR.9 | hl7v2:OBR.10 | hl7v2:OBR.11 | hl7v2:OBR.12 | hl7v2:OBR.13 | hl7v2:OBR.14 | hl7v2:OBR.15 | hl7v2:OBR.16 | hl7v2:OBR.17 | hl7v2:OBR.18 | hl7v2:OBR.19 | hl7v2:OBR.20 | hl7v2:OBR.21 | hl7v2:OBR.22 | hl7v2:OBR.23 | hl7v2:OBR.24 | hl7v2:OBR.25 | hl7v2:OBR.26 | hl7v2:OBR.27 | hl7v2:OBR.28 | hl7v2:OBR.29 | hl7v2:OBR.30 | hl7v2:OBR.31 | hl7v2:OBR.32 | hl7v2:OBR.33 | hl7v2:OBR.34 | hl7v2:OBR.35 | hl7v2:OBR.36 | hl7v2:OBR.37 | hl7v2:OBR.38 | hl7v2:OBR.39 | hl7v2:OBR.40 | hl7v2:OBR.41 | hl7v2:OBR.42 | hl7v2:OBR.43 | hl7v2:OBR.44 | hl7v2:OBR.45 | hl7v2:OBR.46 | hl7v2:OBR.47 | hl7v2:OBR.48 | hl7v2:OBR.49 (rule-reference: d20e23231-true-d1048396e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1048343e15-true-d1048415e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.2/*[not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1187"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1048343e15-true-d1048415e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d1048343e15-true-d1048415e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1048343e29-true-d1048452e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.3/*[not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1186"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1048343e29-true-d1048452e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d1048343e29-true-d1048452e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1048343e43-true-d1048491e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.4/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1185"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1048343e43-true-d1048491e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1048343e43-true-d1048491e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1048343e89-true-d1048544e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.6/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1184"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1048343e89-true-d1048544e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1048343e89-true-d1048544e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1048343e109-true-d1048567e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.7/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1183"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1048343e109-true-d1048567e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1048343e109-true-d1048567e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1048343e120-true-d1048590e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.8/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1182"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1048343e120-true-d1048590e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1048343e120-true-d1048590e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1048343e131-true-d1048613e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.9/*[not(self::hl7v2:CQ.1 | self::hl7v2:CQ.2)]"
                 priority="1181"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1048343e131-true-d1048613e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CQ.1 | hl7v2:CQ.2 (rule-reference: d1048343e131-true-d1048613e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1048606e26-true-d1048634e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.9/hl7v2:CQ.2/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1180"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1048606e26-true-d1048634e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1048606e26-true-d1048634e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1048343e142-true-d1048702e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/*[not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="1179"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1048343e142-true-d1048702e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d1048343e142-true-d1048702e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1048674e32-true-d1048722e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.2/*[not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="1178"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1048674e32-true-d1048722e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d1048674e32-true-d1048722e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1048674e123-true-d1048800e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.9/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1177"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1048674e123-true-d1048800e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d1048674e123-true-d1048800e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1048674e215-true-d1048854e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.14/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1176"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1048674e215-true-d1048854e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d1048674e215-true-d1048854e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1048674e275-true-d1048893e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.16/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1175"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1048674e275-true-d1048893e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1048674e275-true-d1048893e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1048674e288-true-d1048940e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.17/*[not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1174"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1048674e288-true-d1048940e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d1048674e288-true-d1048940e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1048933e17-true-d1048951e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.17/hl7v2:DR.1/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1173"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1048933e17-true-d1048951e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1048933e17-true-d1048951e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1048933e28-true-d1048974e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.17/hl7v2:DR.2/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1172"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1048933e28-true-d1048974e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1048933e28-true-d1048974e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1048674e318-true-d1049003e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.19/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1171"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1048674e318-true-d1049003e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1048674e318-true-d1049003e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1048674e329-true-d1049026e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.20/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1170"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1048674e329-true-d1049026e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1048674e329-true-d1049026e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1048674e351-true-d1049062e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1169"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1048674e351-true-d1049062e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d1048674e351-true-d1049062e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1048674e369-true-d1049134e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1168"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1048674e369-true-d1049134e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d1048674e369-true-d1049134e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1048343e167-true-d1049209e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.12/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1167"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1048343e167-true-d1049209e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1048343e167-true-d1049209e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1048343e189-true-d1049262e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.14/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1166"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1048343e189-true-d1049262e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1048343e189-true-d1049262e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1048343e221-true-d1049290e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/*[not(self::hl7v2:SPS.1 | self::hl7v2:SPS.2 | self::hl7v2:SPS.3 | self::hl7v2:SPS.4 | self::hl7v2:SPS.5 | self::hl7v2:SPS.6 | self::hl7v2:SPS.7)]"
                 priority="1165"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1048343e221-true-d1049290e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:SPS.1 | hl7v2:SPS.2 | hl7v2:SPS.3 | hl7v2:SPS.4 | hl7v2:SPS.5 | hl7v2:SPS.6 | hl7v2:SPS.7 (rule-reference: d1048343e221-true-d1049290e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1049278e24-true-d1049308e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1164"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1049278e24-true-d1049308e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d1049278e24-true-d1049308e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1049278e53-true-d1049380e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1163"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1049278e53-true-d1049380e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d1049278e53-true-d1049380e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1049278e66-true-d1049444e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.3/*[not(self::hl7v2:escape)]"
                 priority="1162"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1049278e66-true-d1049444e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d1049278e66-true-d1049444e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1049438e11-true-d1049454e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.3/hl7v2:escape/*[not(self::hl7v2:escape)]"
                 priority="1161"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1049438e11-true-d1049454e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d1049438e11-true-d1049454e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1049448e5-true-d1049464e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.3/hl7v2:escape/hl7v2:escape/*[not(self::hl7v2:escape)]"
                 priority="1160"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1049448e5-true-d1049464e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d1049448e5-true-d1049464e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1049278e77-true-d1049486e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1159"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1049278e77-true-d1049486e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d1049278e77-true-d1049486e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1049278e102-true-d1049558e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1158"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1049278e102-true-d1049558e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d1049278e102-true-d1049558e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1049278e115-true-d1049630e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1157"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1049278e115-true-d1049630e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d1049278e115-true-d1049630e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1049278e126-true-d1049702e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1156"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1049278e126-true-d1049702e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d1049278e126-true-d1049702e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1048343e241-true-d1049788e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/*[not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="1155"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1048343e241-true-d1049788e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d1048343e241-true-d1049788e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1049760e32-true-d1049808e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.2/*[not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="1154"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1049760e32-true-d1049808e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d1049760e32-true-d1049808e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1049760e123-true-d1049886e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.9/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1153"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1049760e123-true-d1049886e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d1049760e123-true-d1049886e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1049760e215-true-d1049940e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.14/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1152"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1049760e215-true-d1049940e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d1049760e215-true-d1049940e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1049760e275-true-d1049979e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.16/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1151"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1049760e275-true-d1049979e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1049760e275-true-d1049979e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1049760e288-true-d1050026e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.17/*[not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1150"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1049760e288-true-d1050026e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d1049760e288-true-d1050026e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1050019e17-true-d1050037e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.17/hl7v2:DR.1/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1149"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1050019e17-true-d1050037e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1050019e17-true-d1050037e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1050019e28-true-d1050060e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.17/hl7v2:DR.2/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1148"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1050019e28-true-d1050060e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1050019e28-true-d1050060e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1049760e318-true-d1050089e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.19/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1147"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1049760e318-true-d1050089e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1049760e318-true-d1050089e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1049760e329-true-d1050112e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.20/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1146"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1049760e329-true-d1050112e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1049760e329-true-d1050112e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1049760e351-true-d1050148e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1145"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1049760e351-true-d1050148e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d1049760e351-true-d1050148e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1049760e369-true-d1050220e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1144"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1049760e369-true-d1050220e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d1049760e369-true-d1050220e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1048343e252-true-d1050295e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.17/*[not(self::hl7v2:XTN.1 | self::hl7v2:XTN.2 | self::hl7v2:XTN.3 | self::hl7v2:XTN.4 | self::hl7v2:XTN.5 | self::hl7v2:XTN.6 | self::hl7v2:XTN.7 | self::hl7v2:XTN.8 | self::hl7v2:XTN.9 | self::hl7v2:XTN.10 | self::hl7v2:XTN.11 | self::hl7v2:XTN.12)]"
                 priority="1143"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1048343e252-true-d1050295e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XTN.1 | hl7v2:XTN.2 | hl7v2:XTN.3 | hl7v2:XTN.4 | hl7v2:XTN.5 | hl7v2:XTN.6 | hl7v2:XTN.7 | hl7v2:XTN.8 | hl7v2:XTN.9 | hl7v2:XTN.10 | hl7v2:XTN.11 | hl7v2:XTN.12 (rule-reference: d1048343e252-true-d1050295e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1048343e307-true-d1050402e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.22/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1142"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1048343e307-true-d1050402e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1048343e307-true-d1050402e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1048343e319-true-d1050425e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.23/*[not(self::hl7v2:MOC.1 | self::hl7v2:MOC.2)]"
                 priority="1141"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1048343e319-true-d1050425e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:MOC.1 | hl7v2:MOC.2 (rule-reference: d1048343e319-true-d1050425e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1050418e15-true-d1050436e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.1/*[not(self::hl7v2:MO.1 | self::hl7v2:MO.2)]"
                 priority="1140"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1050418e15-true-d1050436e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:MO.1 | hl7v2:MO.2 (rule-reference: d1050418e15-true-d1050436e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1050418e26-true-d1050463e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.2/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1139"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1050418e26-true-d1050463e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1050418e26-true-d1050463e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1048343e363-true-d1050523e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.26/*[not(self::hl7v2:PRL.1 | self::hl7v2:PRL.2 | self::hl7v2:PRL.3)]"
                 priority="1138"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1048343e363-true-d1050523e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:PRL.1 | hl7v2:PRL.2 | hl7v2:PRL.3 (rule-reference: d1048343e363-true-d1050523e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1050515e42-true-d1050538e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.1/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1137"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1050515e42-true-d1050538e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1050515e42-true-d1050538e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1050515e64-true-d1050590e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.3/*[not(self::hl7v2:escape)]"
                 priority="1136"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1050515e64-true-d1050590e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d1050515e64-true-d1050590e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1050584e17-true-d1050600e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.3/hl7v2:escape/*[not(self::hl7v2:escape)]"
                 priority="1135"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1050584e17-true-d1050600e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d1050584e17-true-d1050600e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1050594e5-true-d1050610e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.3/hl7v2:escape/hl7v2:escape/*[not(self::hl7v2:escape)]"
                 priority="1134"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1050594e5-true-d1050610e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d1050594e5-true-d1050610e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1048343e401-true-d1050635e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/*[not(self::hl7v2:TQ.1 | self::hl7v2:TQ.2 | self::hl7v2:TQ.3 | self::hl7v2:TQ.4 | self::hl7v2:TQ.5 | self::hl7v2:TQ.6 | self::hl7v2:TQ.7 | self::hl7v2:TQ.8 | self::hl7v2:TQ.9 | self::hl7v2:TQ.10 | self::hl7v2:TQ.11 | self::hl7v2:TQ.12)]"
                 priority="1133"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1048343e401-true-d1050635e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TQ.1 | hl7v2:TQ.2 | hl7v2:TQ.3 | hl7v2:TQ.4 | hl7v2:TQ.5 | hl7v2:TQ.6 | hl7v2:TQ.7 | hl7v2:TQ.8 | hl7v2:TQ.9 | hl7v2:TQ.10 | hl7v2:TQ.11 | hl7v2:TQ.12 (rule-reference: d1048343e401-true-d1050635e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1050618e36-true-d1050646e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/*[not(self::hl7v2:CQ.1 | self::hl7v2:CQ.2)]"
                 priority="1132"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1050618e36-true-d1050646e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CQ.1 | hl7v2:CQ.2 (rule-reference: d1050618e36-true-d1050646e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1050639e31-true-d1050667e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/hl7v2:CQ.2/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1131"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1050639e31-true-d1050667e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1050639e31-true-d1050667e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1050618e56-true-d1050714e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.2/*[not(self::hl7v2:RI.1 | self::hl7v2:RI.2)]"
                 priority="1130"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1050618e56-true-d1050714e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:RI.1 | hl7v2:RI.2 (rule-reference: d1050618e56-true-d1050714e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1050618e210-true-d1050743e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.4/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1129"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1050618e210-true-d1050743e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1050618e210-true-d1050743e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1050618e227-true-d1050766e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.5/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1128"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1050618e227-true-d1050766e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1050618e227-true-d1050766e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1050618e482-true-d1050800e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.8/*[not(self::hl7v2:escape)]"
                 priority="1127"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1050618e482-true-d1050800e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d1050618e482-true-d1050800e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1050794e11-true-d1050810e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.8/hl7v2:escape/*[not(self::hl7v2:escape)]"
                 priority="1126"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1050794e11-true-d1050810e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d1050794e11-true-d1050810e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1050804e5-true-d1050820e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.8/hl7v2:escape/hl7v2:escape/*[not(self::hl7v2:escape)]"
                 priority="1125"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1050804e5-true-d1050820e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d1050804e5-true-d1050820e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1050618e507-true-d1050850e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/*[not(self::hl7v2:OSD.1 | self::hl7v2:OSD.2 | self::hl7v2:OSD.3 | self::hl7v2:OSD.4 | self::hl7v2:OSD.5 | self::hl7v2:OSD.6 | self::hl7v2:OSD.7 | self::hl7v2:OSD.8 | self::hl7v2:OSD.9 | self::hl7v2:OSD.10 | self::hl7v2:OSD.11)]"
                 priority="1124"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1050618e507-true-d1050850e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:OSD.1 | hl7v2:OSD.2 | hl7v2:OSD.3 | hl7v2:OSD.4 | hl7v2:OSD.5 | hl7v2:OSD.6 | hl7v2:OSD.7 | hl7v2:OSD.8 | hl7v2:OSD.9 | hl7v2:OSD.10 | hl7v2:OSD.11 (rule-reference: d1050618e507-true-d1050850e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1050618e527-true-d1050931e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.11/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1123"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1050618e527-true-d1050931e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1050618e527-true-d1050931e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1048343e433-true-d1051005e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/*[not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="1122"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1048343e433-true-d1051005e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d1048343e433-true-d1051005e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1050977e32-true-d1051025e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.2/*[not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="1121"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1050977e32-true-d1051025e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d1050977e32-true-d1051025e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1050977e123-true-d1051103e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.9/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1120"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1050977e123-true-d1051103e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d1050977e123-true-d1051103e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1050977e215-true-d1051157e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.14/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1119"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1050977e215-true-d1051157e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d1050977e215-true-d1051157e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1050977e275-true-d1051196e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.16/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1118"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1050977e275-true-d1051196e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1050977e275-true-d1051196e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1050977e288-true-d1051243e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.17/*[not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1117"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1050977e288-true-d1051243e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d1050977e288-true-d1051243e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1051236e17-true-d1051254e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.17/hl7v2:DR.1/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1116"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1051236e17-true-d1051254e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1051236e17-true-d1051254e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1051236e28-true-d1051277e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.17/hl7v2:DR.2/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1115"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1051236e28-true-d1051277e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1051236e28-true-d1051277e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1050977e318-true-d1051306e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.19/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1114"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1050977e318-true-d1051306e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1050977e318-true-d1051306e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1050977e329-true-d1051329e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.20/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1113"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1050977e329-true-d1051329e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1050977e329-true-d1051329e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1050977e351-true-d1051365e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1112"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1050977e351-true-d1051365e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d1050977e351-true-d1051365e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1050977e369-true-d1051437e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1111"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1050977e369-true-d1051437e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d1050977e369-true-d1051437e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1048343e444-true-d1051502e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.29/*[not(self::hl7v2:EIP.1 | self::hl7v2:EIP.2)]"
                 priority="1110"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1048343e444-true-d1051502e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EIP.1 | hl7v2:EIP.2 (rule-reference: d1048343e444-true-d1051502e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1051495e18-true-d1051515e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.1/*[not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1109"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1051495e18-true-d1051515e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d1051495e18-true-d1051515e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1051495e47-true-d1051552e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.2/*[not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1108"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1051495e47-true-d1051552e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d1051495e47-true-d1051552e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1048343e471-true-d1051597e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.31/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1107"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1048343e471-true-d1051597e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1048343e471-true-d1051597e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1048343e482-true-d1051653e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/*[not(self::hl7v2:NDL.1 | self::hl7v2:NDL.2 | self::hl7v2:NDL.3 | self::hl7v2:NDL.4 | self::hl7v2:NDL.5 | self::hl7v2:NDL.6 | self::hl7v2:NDL.7 | self::hl7v2:NDL.8 | self::hl7v2:NDL.9 | self::hl7v2:NDL.10 | self::hl7v2:NDL.11)]"
                 priority="1106"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1048343e482-true-d1051653e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:NDL.1 | hl7v2:NDL.2 | hl7v2:NDL.3 | hl7v2:NDL.4 | hl7v2:NDL.5 | hl7v2:NDL.6 | hl7v2:NDL.7 | hl7v2:NDL.8 | hl7v2:NDL.9 | hl7v2:NDL.10 | hl7v2:NDL.11 (rule-reference: d1048343e482-true-d1051653e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1051637e15-true-d1051673e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/*[not(self::hl7v2:CNN.1 | self::hl7v2:CNN.2 | self::hl7v2:CNN.3 | self::hl7v2:CNN.4 | self::hl7v2:CNN.5 | self::hl7v2:CNN.6 | self::hl7v2:CNN.7 | self::hl7v2:CNN.8 | self::hl7v2:CNN.9 | self::hl7v2:CNN.10 | self::hl7v2:CNN.11)]"
                 priority="1105"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1051637e15-true-d1051673e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CNN.1 | hl7v2:CNN.2 | hl7v2:CNN.3 | hl7v2:CNN.4 | hl7v2:CNN.5 | hl7v2:CNN.6 | hl7v2:CNN.7 | hl7v2:CNN.8 | hl7v2:CNN.9 | hl7v2:CNN.10 | hl7v2:CNN.11 (rule-reference: d1051637e15-true-d1051673e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1051637e26-true-d1051750e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.2/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1104"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1051637e26-true-d1051750e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1051637e26-true-d1051750e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1051637e37-true-d1051773e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.3/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1103"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1051637e37-true-d1051773e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1051637e37-true-d1051773e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1051637e87-true-d1051815e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.7/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1102"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1051637e87-true-d1051815e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d1051637e87-true-d1051815e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1048343e493-true-d1051877e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/*[not(self::hl7v2:NDL.1 | self::hl7v2:NDL.2 | self::hl7v2:NDL.3 | self::hl7v2:NDL.4 | self::hl7v2:NDL.5 | self::hl7v2:NDL.6 | self::hl7v2:NDL.7 | self::hl7v2:NDL.8 | self::hl7v2:NDL.9 | self::hl7v2:NDL.10 | self::hl7v2:NDL.11)]"
                 priority="1101"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1048343e493-true-d1051877e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:NDL.1 | hl7v2:NDL.2 | hl7v2:NDL.3 | hl7v2:NDL.4 | hl7v2:NDL.5 | hl7v2:NDL.6 | hl7v2:NDL.7 | hl7v2:NDL.8 | hl7v2:NDL.9 | hl7v2:NDL.10 | hl7v2:NDL.11 (rule-reference: d1048343e493-true-d1051877e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1051861e15-true-d1051897e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/*[not(self::hl7v2:CNN.1 | self::hl7v2:CNN.2 | self::hl7v2:CNN.3 | self::hl7v2:CNN.4 | self::hl7v2:CNN.5 | self::hl7v2:CNN.6 | self::hl7v2:CNN.7 | self::hl7v2:CNN.8 | self::hl7v2:CNN.9 | self::hl7v2:CNN.10 | self::hl7v2:CNN.11)]"
                 priority="1100"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1051861e15-true-d1051897e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CNN.1 | hl7v2:CNN.2 | hl7v2:CNN.3 | hl7v2:CNN.4 | hl7v2:CNN.5 | hl7v2:CNN.6 | hl7v2:CNN.7 | hl7v2:CNN.8 | hl7v2:CNN.9 | hl7v2:CNN.10 | hl7v2:CNN.11 (rule-reference: d1051861e15-true-d1051897e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1051861e26-true-d1051974e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.2/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1099"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1051861e26-true-d1051974e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1051861e26-true-d1051974e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1051861e37-true-d1051997e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.3/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1098"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1051861e37-true-d1051997e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1051861e37-true-d1051997e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1051861e87-true-d1052039e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.7/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1097"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1051861e87-true-d1052039e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d1051861e87-true-d1052039e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1048343e505-true-d1052101e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/*[not(self::hl7v2:NDL.1 | self::hl7v2:NDL.2 | self::hl7v2:NDL.3 | self::hl7v2:NDL.4 | self::hl7v2:NDL.5 | self::hl7v2:NDL.6 | self::hl7v2:NDL.7 | self::hl7v2:NDL.8 | self::hl7v2:NDL.9 | self::hl7v2:NDL.10 | self::hl7v2:NDL.11)]"
                 priority="1096"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1048343e505-true-d1052101e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:NDL.1 | hl7v2:NDL.2 | hl7v2:NDL.3 | hl7v2:NDL.4 | hl7v2:NDL.5 | hl7v2:NDL.6 | hl7v2:NDL.7 | hl7v2:NDL.8 | hl7v2:NDL.9 | hl7v2:NDL.10 | hl7v2:NDL.11 (rule-reference: d1048343e505-true-d1052101e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1052085e15-true-d1052121e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/*[not(self::hl7v2:CNN.1 | self::hl7v2:CNN.2 | self::hl7v2:CNN.3 | self::hl7v2:CNN.4 | self::hl7v2:CNN.5 | self::hl7v2:CNN.6 | self::hl7v2:CNN.7 | self::hl7v2:CNN.8 | self::hl7v2:CNN.9 | self::hl7v2:CNN.10 | self::hl7v2:CNN.11)]"
                 priority="1095"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1052085e15-true-d1052121e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CNN.1 | hl7v2:CNN.2 | hl7v2:CNN.3 | hl7v2:CNN.4 | hl7v2:CNN.5 | hl7v2:CNN.6 | hl7v2:CNN.7 | hl7v2:CNN.8 | hl7v2:CNN.9 | hl7v2:CNN.10 | hl7v2:CNN.11 (rule-reference: d1052085e15-true-d1052121e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1052085e26-true-d1052198e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.2/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1094"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1052085e26-true-d1052198e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1052085e26-true-d1052198e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1052085e37-true-d1052221e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.3/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1093"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1052085e37-true-d1052221e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1052085e37-true-d1052221e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1052085e87-true-d1052263e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.7/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1092"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1052085e87-true-d1052263e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d1052085e87-true-d1052263e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1048343e516-true-d1052325e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/*[not(self::hl7v2:NDL.1 | self::hl7v2:NDL.2 | self::hl7v2:NDL.3 | self::hl7v2:NDL.4 | self::hl7v2:NDL.5 | self::hl7v2:NDL.6 | self::hl7v2:NDL.7 | self::hl7v2:NDL.8 | self::hl7v2:NDL.9 | self::hl7v2:NDL.10 | self::hl7v2:NDL.11)]"
                 priority="1091"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1048343e516-true-d1052325e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:NDL.1 | hl7v2:NDL.2 | hl7v2:NDL.3 | hl7v2:NDL.4 | hl7v2:NDL.5 | hl7v2:NDL.6 | hl7v2:NDL.7 | hl7v2:NDL.8 | hl7v2:NDL.9 | hl7v2:NDL.10 | hl7v2:NDL.11 (rule-reference: d1048343e516-true-d1052325e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1052309e15-true-d1052345e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/*[not(self::hl7v2:CNN.1 | self::hl7v2:CNN.2 | self::hl7v2:CNN.3 | self::hl7v2:CNN.4 | self::hl7v2:CNN.5 | self::hl7v2:CNN.6 | self::hl7v2:CNN.7 | self::hl7v2:CNN.8 | self::hl7v2:CNN.9 | self::hl7v2:CNN.10 | self::hl7v2:CNN.11)]"
                 priority="1090"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1052309e15-true-d1052345e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CNN.1 | hl7v2:CNN.2 | hl7v2:CNN.3 | hl7v2:CNN.4 | hl7v2:CNN.5 | hl7v2:CNN.6 | hl7v2:CNN.7 | hl7v2:CNN.8 | hl7v2:CNN.9 | hl7v2:CNN.10 | hl7v2:CNN.11 (rule-reference: d1052309e15-true-d1052345e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1052309e26-true-d1052422e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.2/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1089"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1052309e26-true-d1052422e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1052309e26-true-d1052422e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1052309e37-true-d1052445e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.3/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1088"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1052309e37-true-d1052445e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1052309e37-true-d1052445e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1052309e87-true-d1052487e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.7/*[not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1087"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1052309e87-true-d1052487e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d1052309e87-true-d1052487e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1048343e527-true-d1052540e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.36/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1086"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1048343e527-true-d1052540e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1048343e527-true-d1052540e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1048343e549-true-d1052573e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.38/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1085"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1048343e549-true-d1052573e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1048343e549-true-d1052573e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1048343e560-true-d1052624e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.39/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1084"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1048343e560-true-d1052624e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1048343e560-true-d1052624e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1048343e571-true-d1052675e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.40/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1083"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1048343e571-true-d1052675e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1048343e571-true-d1052675e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1048343e608-true-d1052738e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.43/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1082"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1048343e608-true-d1052738e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1048343e608-true-d1052738e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1048343e619-true-d1052789e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.44/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1081"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1048343e619-true-d1052789e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1048343e619-true-d1052789e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1048343e633-true-d1052840e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.45/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1080"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1048343e633-true-d1052840e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1048343e633-true-d1052840e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1048343e646-true-d1052891e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.46/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1079"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1048343e646-true-d1052891e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1048343e646-true-d1052891e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1048343e659-true-d1052942e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.47/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1078"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1048343e659-true-d1052942e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1048343e659-true-d1052942e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1048343e672-true-d1052996e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.48/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1077"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1048343e672-true-d1052996e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d1048343e672-true-d1052996e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e23233-true-d1053064e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/*[not(self::hl7v2:SPM | self::hl7v2:SAC)]"
                 priority="1076"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d20e23233-true-d1053064e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:SPM | hl7v2:SAC (rule-reference: d20e23233-true-d1053064e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e23235-true-d1053102e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/*[not(self::hl7v2:SPM.1 | self::hl7v2:SPM.2 | self::hl7v2:SPM.3 | self::hl7v2:SPM.4 | self::hl7v2:SPM.5 | self::hl7v2:SPM.6 | self::hl7v2:SPM.7 | self::hl7v2:SPM.8 | self::hl7v2:SPM.9 | self::hl7v2:SPM.10 | self::hl7v2:SPM.11 | self::hl7v2:SPM.12 | self::hl7v2:SPM.13 | self::hl7v2:SPM.14 | self::hl7v2:SPM.15 | self::hl7v2:SPM.16 | self::hl7v2:SPM.17 | self::hl7v2:SPM.18 | self::hl7v2:SPM.19 | self::hl7v2:SPM.20 | self::hl7v2:SPM.21 | self::hl7v2:SPM.22 | self::hl7v2:SPM.23 | self::hl7v2:SPM.24 | self::hl7v2:SPM.25 | self::hl7v2:SPM.26 | self::hl7v2:SPM.27 | self::hl7v2:SPM.28 | self::hl7v2:SPM.29)]"
                 priority="1075"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d20e23235-true-d1053102e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:SPM.1 | hl7v2:SPM.2 | hl7v2:SPM.3 | hl7v2:SPM.4 | hl7v2:SPM.5 | hl7v2:SPM.6 | hl7v2:SPM.7 | hl7v2:SPM.8 | hl7v2:SPM.9 | hl7v2:SPM.10 | hl7v2:SPM.11 | hl7v2:SPM.12 | hl7v2:SPM.13 | hl7v2:SPM.14 | hl7v2:SPM.15 | hl7v2:SPM.16 | hl7v2:SPM.17 | hl7v2:SPM.18 | hl7v2:SPM.19 | hl7v2:SPM.20 | hl7v2:SPM.21 | hl7v2:SPM.22 | hl7v2:SPM.23 | hl7v2:SPM.24 | hl7v2:SPM.25 | hl7v2:SPM.26 | hl7v2:SPM.27 | hl7v2:SPM.28 | hl7v2:SPM.29 (rule-reference: d20e23235-true-d1053102e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1053069e12-true-d1053119e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2/*[not(self::hl7v2:EIP.1 | self::hl7v2:EIP.2)]"
                 priority="1074"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1053069e12-true-d1053119e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EIP.1 | hl7v2:EIP.2 (rule-reference: d1053069e12-true-d1053119e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1053112e18-true-d1053132e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2/hl7v2:EIP.1/*[not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1073"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1053112e18-true-d1053132e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d1053112e18-true-d1053132e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1053112e47-true-d1053169e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2/hl7v2:EIP.2/*[not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1072"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1053112e47-true-d1053169e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d1053112e47-true-d1053169e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1053069e26-true-d1053204e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3/*[not(self::hl7v2:EIP.1 | self::hl7v2:EIP.2)]"
                 priority="1071"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1053069e26-true-d1053204e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EIP.1 | hl7v2:EIP.2 (rule-reference: d1053069e26-true-d1053204e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1053197e39-true-d1053217e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3/hl7v2:EIP.1/*[not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1070"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1053197e39-true-d1053217e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d1053197e39-true-d1053217e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1053197e68-true-d1053254e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3/hl7v2:EIP.2/*[not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1069"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1053197e68-true-d1053254e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d1053197e68-true-d1053254e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1053069e62-true-d1053296e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.4/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1068"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1053069e62-true-d1053296e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d1053069e62-true-d1053296e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1053069e88-true-d1053368e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.5/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1067"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1053069e88-true-d1053368e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d1053069e88-true-d1053368e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1053069e111-true-d1053440e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.6/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1066"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1053069e111-true-d1053440e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d1053069e111-true-d1053440e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1053069e124-true-d1053512e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.7/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1065"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1053069e124-true-d1053512e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d1053069e124-true-d1053512e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1053069e150-true-d1053584e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.8/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1064"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1053069e150-true-d1053584e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d1053069e150-true-d1053584e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1053069e174-true-d1053656e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.9/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1063"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1053069e174-true-d1053656e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d1053069e174-true-d1053656e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1053069e187-true-d1053728e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.10/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1062"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1053069e187-true-d1053728e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d1053069e187-true-d1053728e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1053069e210-true-d1053800e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.11/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1061"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1053069e210-true-d1053800e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d1053069e210-true-d1053800e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1053069e224-true-d1053865e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.12/*[not(self::hl7v2:CQ.1 | self::hl7v2:CQ.2)]"
                 priority="1060"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1053069e224-true-d1053865e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CQ.1 | hl7v2:CQ.2 (rule-reference: d1053069e224-true-d1053865e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1053858e29-true-d1053886e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.12/hl7v2:CQ.2/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1059"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1053858e29-true-d1053886e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1053858e29-true-d1053886e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1053069e260-true-d1053952e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.15/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1058"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1053069e260-true-d1053952e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d1053069e260-true-d1053952e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1053069e273-true-d1054024e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.16/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1057"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1053069e273-true-d1054024e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d1053069e273-true-d1054024e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1053069e286-true-d1054089e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.17/*[not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1056"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1053069e286-true-d1054089e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d1053069e286-true-d1054089e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1054082e21-true-d1054100e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.17/hl7v2:DR.1/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1055"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1054082e21-true-d1054100e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1054082e21-true-d1054100e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1054082e32-true-d1054123e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.17/hl7v2:DR.2/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1054"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1054082e32-true-d1054123e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1054082e32-true-d1054123e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1053069e304-true-d1054146e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.18/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1053"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1053069e304-true-d1054146e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1053069e304-true-d1054146e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1053069e318-true-d1054169e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.19/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1052"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1053069e318-true-d1054169e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1053069e318-true-d1054169e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1053069e342-true-d1054205e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.21/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1051"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1053069e342-true-d1054205e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d1053069e342-true-d1054205e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1053069e355-true-d1054277e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.22/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1050"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1053069e355-true-d1054277e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d1053069e355-true-d1054277e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1053069e369-true-d1054349e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.23/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1049"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1053069e369-true-d1054349e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d1053069e369-true-d1054349e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1053069e382-true-d1054421e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.24/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1048"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1053069e382-true-d1054421e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d1053069e382-true-d1054421e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1053069e395-true-d1054486e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.25/*[not(self::hl7v2:CQ.1 | self::hl7v2:CQ.2)]"
                 priority="1047"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1053069e395-true-d1054486e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CQ.1 | hl7v2:CQ.2 (rule-reference: d1053069e395-true-d1054486e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1054479e26-true-d1054507e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.25/hl7v2:CQ.2/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1046"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1054479e26-true-d1054507e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1054479e26-true-d1054507e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1053069e417-true-d1054567e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.27/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1045"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1053069e417-true-d1054567e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d1053069e417-true-d1054567e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1053069e428-true-d1054639e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.28/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1044"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1053069e428-true-d1054639e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d1053069e428-true-d1054639e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1053069e441-true-d1054711e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.29/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1043"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1053069e441-true-d1054711e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d1053069e441-true-d1054711e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e23237-true-d1054818e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/*[not(self::hl7v2:SAC.1 | self::hl7v2:SAC.2 | self::hl7v2:SAC.3 | self::hl7v2:SAC.4 | self::hl7v2:SAC.5 | self::hl7v2:SAC.6 | self::hl7v2:SAC.7 | self::hl7v2:SAC.8 | self::hl7v2:SAC.9 | self::hl7v2:SAC.10 | self::hl7v2:SAC.11 | self::hl7v2:SAC.12 | self::hl7v2:SAC.13 | self::hl7v2:SAC.14 | self::hl7v2:SAC.15 | self::hl7v2:SAC.16 | self::hl7v2:SAC.17 | self::hl7v2:SAC.18 | self::hl7v2:SAC.19 | self::hl7v2:SAC.20 | self::hl7v2:SAC.21 | self::hl7v2:SAC.22 | self::hl7v2:SAC.23 | self::hl7v2:SAC.24 | self::hl7v2:SAC.25 | self::hl7v2:SAC.26 | self::hl7v2:SAC.27 | self::hl7v2:SAC.28 | self::hl7v2:SAC.29 | self::hl7v2:SAC.30 | self::hl7v2:SAC.31 | self::hl7v2:SAC.32 | self::hl7v2:SAC.33 | self::hl7v2:SAC.34 | self::hl7v2:SAC.35 | self::hl7v2:SAC.36 | self::hl7v2:SAC.37 | self::hl7v2:SAC.38 | self::hl7v2:SAC.39 | self::hl7v2:SAC.40 | self::hl7v2:SAC.41 | self::hl7v2:SAC.42 | self::hl7v2:SAC.43 | self::hl7v2:SAC.44)]"
                 priority="1042"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d20e23237-true-d1054818e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:SAC.1 | hl7v2:SAC.2 | hl7v2:SAC.3 | hl7v2:SAC.4 | hl7v2:SAC.5 | hl7v2:SAC.6 | hl7v2:SAC.7 | hl7v2:SAC.8 | hl7v2:SAC.9 | hl7v2:SAC.10 | hl7v2:SAC.11 | hl7v2:SAC.12 | hl7v2:SAC.13 | hl7v2:SAC.14 | hl7v2:SAC.15 | hl7v2:SAC.16 | hl7v2:SAC.17 | hl7v2:SAC.18 | hl7v2:SAC.19 | hl7v2:SAC.20 | hl7v2:SAC.21 | hl7v2:SAC.22 | hl7v2:SAC.23 | hl7v2:SAC.24 | hl7v2:SAC.25 | hl7v2:SAC.26 | hl7v2:SAC.27 | hl7v2:SAC.28 | hl7v2:SAC.29 | hl7v2:SAC.30 | hl7v2:SAC.31 | hl7v2:SAC.32 | hl7v2:SAC.33 | hl7v2:SAC.34 | hl7v2:SAC.35 | hl7v2:SAC.36 | hl7v2:SAC.37 | hl7v2:SAC.38 | hl7v2:SAC.39 | hl7v2:SAC.40 | hl7v2:SAC.41 | hl7v2:SAC.42 | hl7v2:SAC.43 | hl7v2:SAC.44 (rule-reference: d20e23237-true-d1054818e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1054770e1-true-d1054831e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.1/*[not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1041"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1054770e1-true-d1054831e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d1054770e1-true-d1054831e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1054770e12-true-d1054868e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.2/*[not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1040"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1054770e12-true-d1054868e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d1054770e12-true-d1054868e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1054770e23-true-d1054905e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.3/*[not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1039"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1054770e23-true-d1054905e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d1054770e23-true-d1054905e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1054770e34-true-d1054942e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.4/*[not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1038"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1054770e34-true-d1054942e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d1054770e34-true-d1054942e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1054770e45-true-d1054979e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.5/*[not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1037"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1054770e45-true-d1054979e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d1054770e45-true-d1054979e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1054770e56-true-d1055019e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/*[not(self::hl7v2:SPS.1 | self::hl7v2:SPS.2 | self::hl7v2:SPS.3 | self::hl7v2:SPS.4 | self::hl7v2:SPS.5 | self::hl7v2:SPS.6 | self::hl7v2:SPS.7)]"
                 priority="1036"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1054770e56-true-d1055019e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:SPS.1 | hl7v2:SPS.2 | hl7v2:SPS.3 | hl7v2:SPS.4 | hl7v2:SPS.5 | hl7v2:SPS.6 | hl7v2:SPS.7 (rule-reference: d1054770e56-true-d1055019e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1055007e15-true-d1055037e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.1/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1035"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1055007e15-true-d1055037e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d1055007e15-true-d1055037e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1055007e44-true-d1055109e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.2/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1034"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1055007e44-true-d1055109e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d1055007e44-true-d1055109e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1055007e57-true-d1055173e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.3/*[not(self::hl7v2:escape)]"
                 priority="1033"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1055007e57-true-d1055173e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d1055007e57-true-d1055173e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1055167e11-true-d1055183e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.3/hl7v2:escape/*[not(self::hl7v2:escape)]"
                 priority="1032"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1055167e11-true-d1055183e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d1055167e11-true-d1055183e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1055177e5-true-d1055193e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.3/hl7v2:escape/hl7v2:escape/*[not(self::hl7v2:escape)]"
                 priority="1031"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1055177e5-true-d1055193e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d1055177e5-true-d1055193e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1055007e68-true-d1055215e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.4/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1030"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1055007e68-true-d1055215e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d1055007e68-true-d1055215e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1055007e93-true-d1055287e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.5/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1029"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1055007e93-true-d1055287e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d1055007e93-true-d1055287e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1055007e106-true-d1055359e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.6/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1028"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1055007e106-true-d1055359e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d1055007e106-true-d1055359e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1055007e117-true-d1055431e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.7/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1027"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1055007e117-true-d1055431e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d1055007e117-true-d1055431e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1054770e67-true-d1055496e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.7/*[not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1026"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1054770e67-true-d1055496e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d1054770e67-true-d1055496e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1054770e78-true-d1055523e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.8/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1025"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1054770e78-true-d1055523e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1054770e78-true-d1055523e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1054770e91-true-d1055574e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.9/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1024"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1054770e91-true-d1055574e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1054770e91-true-d1055574e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1054770e104-true-d1055623e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.10/*[not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1023"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1054770e104-true-d1055623e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d1054770e104-true-d1055623e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1054770e115-true-d1055660e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.11/*[not(self::hl7v2:NA.1 | self::hl7v2:NA.2 | self::hl7v2:NA.3 | self::hl7v2:NA.4)]"
                 priority="1022"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1054770e115-true-d1055660e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:NA.1 | hl7v2:NA.2 | hl7v2:NA.3 | hl7v2:NA.4 (rule-reference: d1054770e115-true-d1055660e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1054770e127-true-d1055699e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.12/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1021"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1054770e127-true-d1055699e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1054770e127-true-d1055699e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1054770e140-true-d1055748e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.13/*[not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1020"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1054770e140-true-d1055748e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d1054770e140-true-d1055748e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1054770e151-true-d1055785e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.14/*[not(self::hl7v2:NA.1 | self::hl7v2:NA.2 | self::hl7v2:NA.3 | self::hl7v2:NA.4)]"
                 priority="1019"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1054770e151-true-d1055785e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:NA.1 | hl7v2:NA.2 | hl7v2:NA.3 | hl7v2:NA.4 (rule-reference: d1054770e151-true-d1055785e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1054770e162-true-d1055824e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.15/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1018"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1054770e162-true-d1055824e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1054770e162-true-d1055824e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1054770e217-true-d1055899e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.20/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1017"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1054770e217-true-d1055899e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1054770e217-true-d1055899e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1054770e262-true-d1055968e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.24/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1016"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1054770e262-true-d1055968e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1054770e262-true-d1055968e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1054770e273-true-d1056019e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.25/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1015"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1054770e273-true-d1056019e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1054770e273-true-d1056019e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1054770e286-true-d1056070e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.26/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1014"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1054770e286-true-d1056070e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1054770e286-true-d1056070e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1054770e299-true-d1056124e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.27/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1013"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1054770e299-true-d1056124e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d1054770e299-true-d1056124e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1054770e312-true-d1056193e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.28/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1012"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1054770e312-true-d1056193e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1054770e312-true-d1056193e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1054770e323-true-d1056242e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.29/*[not(self::hl7v2:SN.1 | self::hl7v2:SN.2 | self::hl7v2:SN.3 | self::hl7v2:SN.4)]"
                 priority="1011"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1054770e323-true-d1056242e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:SN.1 | hl7v2:SN.2 | hl7v2:SN.3 | hl7v2:SN.4 (rule-reference: d1054770e323-true-d1056242e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1054770e334-true-d1056281e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.30/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1010"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1054770e334-true-d1056281e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1054770e334-true-d1056281e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1054770e347-true-d1056330e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.31/*[not(self::hl7v2:SN.1 | self::hl7v2:SN.2 | self::hl7v2:SN.3 | self::hl7v2:SN.4)]"
                 priority="1009"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1054770e347-true-d1056330e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:SN.1 | hl7v2:SN.2 | hl7v2:SN.3 | hl7v2:SN.4 (rule-reference: d1054770e347-true-d1056330e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1054770e369-true-d1056375e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.33/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1008"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1054770e369-true-d1056375e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1054770e369-true-d1056375e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1054770e392-true-d1056432e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.35/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1007"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1054770e392-true-d1056432e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1054770e392-true-d1056432e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1054770e414-true-d1056489e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.37/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1006"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1054770e414-true-d1056489e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1054770e414-true-d1056489e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1054770e436-true-d1056546e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.39/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1005"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1054770e436-true-d1056546e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1054770e436-true-d1056546e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1054770e447-true-d1056597e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.40/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1004"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1054770e447-true-d1056597e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1054770e447-true-d1056597e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1054770e460-true-d1056648e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.41/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1003"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1054770e460-true-d1056648e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1054770e460-true-d1056648e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1054770e473-true-d1056699e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.42/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1002"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1054770e473-true-d1056699e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1054770e473-true-d1056699e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1054770e486-true-d1056753e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.43/*[not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1001"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1054770e486-true-d1056753e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d1054770e486-true-d1056753e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d1054770e499-true-d1056822e0-->
   <xsl:template match="/hl7v2:ORL_O22.RESPONSE/hl7v2:ORL_O22.PATIENT/hl7v2:ORL_O22.ORDER/hl7v2:ORL_O22.OBSERVATION_REQUEST/hl7v2:ORL_O22.SPECIMEN/hl7v2:SAC/hl7v2:SAC.44/*[not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1000"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(.)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20190206T142539/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.57-2018-12-03T091701.html</xsl:attribute>
               <xsl:attribute name="role">warning</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORL_O22_Lab2Lab)/d1054770e499-true-d1056822e0: dit element '<xsl:text/>
                  <xsl:value-of select="name(.)"/>
                  <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d1054770e499-true-d1056822e0)</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M15"/>
   <xsl:template match="@*|node()" priority="-2" mode="M15">
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>
</xsl:stylesheet>
